@@ -16,10 +16,10 @@
 
 #include "EbAppConfig.h"
 
-int32_t read_y4m_header(EbConfig *cfg);
+EbErrorType read_y4m_header(EbConfig *cfg);
 
 void read_and_skip_y4m_header(FILE *input_file);
 
-void read_y4m_frame_delimiter(FILE *input_file, FILE *error_log_file);
+size_t read_y4m_frame_delimiter(FILE *input_file, FILE *error_log_file);
 
-EbBool check_if_y4m(EbConfig *cfg);
+Bool check_if_y4m(EbConfig *cfg);
