@@ -68,10 +68,6 @@ void log_error_output(FILE *error_log_file, uint32_t error_code) {
         break;
 
         // EB_ENC_PM_ERRORS:
-    case EB_ENC_PM_ERROR1:
-        fprintf(error_log_file, "Error: EbPictureManager: dependent_count underflow!\n");
-        break;
-
     case EB_ENC_PM_ERROR10:
         fprintf(error_log_file,
                 "Error: picture_manager_kernel: reference_entry_ptr should never be null!\n");
