@@ -169,10 +169,8 @@ void dec_svt_av1_highbd_warp_affine_avx2(const int32_t *mat, const uint16_t *ref
                         __m256i v_ref = _mm256_permute4x64_epi64(v_refl, 0xEE);
 
                         __m256i v_refu = _mm256_alignr_epi8(v_ref, v_refl, 2); // R8R15R14...R2R1
-                        v_refl         = _mm256_inserti128_si256(
-                            v_refl, _mm256_extracti128_si256(v_refu, 0), 1);
-                        v_refu = _mm256_inserti128_si256(
-                            v_refu, _mm256_extracti128_si256(v_ref, 0), 0);
+                        v_refl = _mm256_inserti128_si256(v_refl, _mm256_castsi256_si128(v_refu), 1);
+                        v_refu = _mm256_inserti128_si256(v_refu, _mm256_castsi256_si128(v_ref), 0);
 
                         __m256i v_sum  = _mm256_set1_epi32(ohoriz);
                         __m256i parsum = _mm256_madd_epi16(
@@ -235,10 +233,8 @@ void dec_svt_av1_highbd_warp_affine_avx2(const int32_t *mat, const uint16_t *ref
 
                         __m256i v_refu = _mm256_alignr_epi8(v_ref, v_refl, 2); // R8R15R14...R2R1
 
-                        v_refl = _mm256_inserti128_si256(
-                            v_refl, _mm256_extracti128_si256(v_refu, 0), 1);
-                        v_refu = _mm256_inserti128_si256(
-                            v_refu, _mm256_extracti128_si256(v_ref, 0), 0);
+                        v_refl = _mm256_inserti128_si256(v_refl, _mm256_castsi256_si128(v_refu), 1);
+                        v_refu = _mm256_inserti128_si256(v_refu, _mm256_castsi256_si128(v_ref), 0);
 
                         __m256i v_sum  = _mm256_set1_epi32(ohoriz);
                         __m256i parsum = _mm256_madd_epi16(v_c01,
@@ -338,10 +334,8 @@ void dec_svt_av1_highbd_warp_affine_avx2(const int32_t *mat, const uint16_t *ref
 
                         __m256i v_refu = _mm256_alignr_epi8(v_ref, v_refl, 2); // R8R15R14...R2R1
 
-                        v_refl = _mm256_inserti128_si256(
-                            v_refl, _mm256_extracti128_si256(v_refu, 0), 1);
-                        v_refu = _mm256_inserti128_si256(
-                            v_refu, _mm256_extracti128_si256(v_ref, 0), 0);
+                        v_refl = _mm256_inserti128_si256(v_refl, _mm256_castsi256_si128(v_refu), 1);
+                        v_refu = _mm256_inserti128_si256(v_refu, _mm256_castsi256_si128(v_ref), 0);
 
                         __m256i v_sum  = _mm256_set1_epi32(ohoriz);
                         __m256i parsum = _mm256_madd_epi16(
@@ -461,10 +455,8 @@ void dec_svt_av1_highbd_warp_affine_avx2(const int32_t *mat, const uint16_t *ref
 
                         __m256i v_refu = _mm256_alignr_epi8(v_ref, v_refl, 2); // R8R15R14...R2R1
 
-                        v_refl = _mm256_inserti128_si256(
-                            v_refl, _mm256_extracti128_si256(v_refu, 0), 1);
-                        v_refu = _mm256_inserti128_si256(
-                            v_refu, _mm256_extracti128_si256(v_ref, 0), 0);
+                        v_refl = _mm256_inserti128_si256(v_refl, _mm256_castsi256_si128(v_refu), 1);
+                        v_refu = _mm256_inserti128_si256(v_refu, _mm256_castsi256_si128(v_ref), 0);
 
                         __m256i v_sum  = _mm256_set1_epi32(ohoriz);
                         __m256i parsum = _mm256_madd_epi16(v_c01,
@@ -602,11 +594,11 @@ void dec_svt_av1_highbd_warp_affine_avx2(const int32_t *mat, const uint16_t *ref
                         __m256i v_sum16 = _mm256_packus_epi32(v_sum1, v_sum1);
                         v_sum16         = _mm256_permute4x64_epi64(v_sum16, 0xD8);
                         v_sum16         = _mm256_min_epi16(v_sum16, clip_pixel);
-                        _mm_storeu_si128(dst16, _mm256_extracti128_si256(v_sum16, 0));
+                        _mm_storeu_si128(dst16, _mm256_castsi256_si128(v_sum16));
                     } else {
                         v_sum           = _mm256_packus_epi32(v_sum, v_sum);
                         __m256i v_sum16 = _mm256_permute4x64_epi64(v_sum, 0xD8);
-                        _mm_storeu_si128(p, _mm256_extracti128_si256(v_sum16, 0));
+                        _mm_storeu_si128(p, _mm256_castsi256_si128(v_sum16));
                     }
                 } else {
                     // Round and pack into 8 bits
@@ -625,7 +617,7 @@ void dec_svt_av1_highbd_warp_affine_avx2(const int32_t *mat, const uint16_t *ref
 
                     __m128i *const p = (__m128i *)&pred[(i + k + 4) * p_stride + j];
 
-                    _mm_storeu_si128(p, _mm256_extracti128_si256(v_sum16, 0));
+                    _mm_storeu_si128(p, _mm256_castsi256_si128(v_sum16));
                 }
             }
         }
@@ -738,7 +730,7 @@ void svt_av1_highbd_warp_affine_avx2(const int32_t *mat, const uint8_t *ref8b, c
                         int32_t sum = 1 << offset_bits_horiz;
                         for (int m = 0; m < 8; ++m) {
                             const int sample_x = clamp(ix + m, 0, width - 1);
-                            uint16_t ref = (ref8b[iy * stride8b + sample_x] << 2) |
+                            uint16_t  ref      = (ref8b[iy * stride8b + sample_x] << 2) |
                                 ((ref2b[iy * stride2b + sample_x] >> 6) & 3);
                             sum += ref * coeffs[m];
                         }
@@ -770,13 +762,11 @@ void svt_av1_highbd_warp_affine_avx2(const int32_t *mat, const uint8_t *ref8b, c
                                                        &ref2b[iy * stride2b + ix4 - 7],
                                                        &ref8b[iy * stride8b + ix4 + 1],
                                                        &ref2b[iy * stride2b + ix4 + 1]);
-                        __m256i v_ref = _mm256_permute4x64_epi64(v_refl, 0xEE);
+                        __m256i v_ref  = _mm256_permute4x64_epi64(v_refl, 0xEE);
 
                         __m256i v_refu = _mm256_alignr_epi8(v_ref, v_refl, 2); // R8R15R14...R2R1
-                        v_refl         = _mm256_inserti128_si256(
-                            v_refl, _mm256_extracti128_si256(v_refu, 0), 1);
-                        v_refu = _mm256_inserti128_si256(
-                            v_refu, _mm256_extracti128_si256(v_ref, 0), 0);
+                        v_refl = _mm256_inserti128_si256(v_refl, _mm256_castsi256_si128(v_refu), 1);
+                        v_refu = _mm256_inserti128_si256(v_refu, _mm256_castsi256_si128(v_ref), 0);
 
                         __m256i v_sum  = _mm256_set1_epi32(ohoriz);
                         __m256i parsum = _mm256_madd_epi16(
@@ -829,14 +819,12 @@ void svt_av1_highbd_warp_affine_avx2(const int32_t *mat, const uint8_t *ref8b, c
                                                        &ref2b[iy * stride2b + ix4 - 7],
                                                        &ref8b[iy * stride8b + ix4 + 1],
                                                        &ref2b[iy * stride2b + ix4 + 1]);
-                        __m256i v_ref = _mm256_permute4x64_epi64(v_refl, 0xEE);
+                        __m256i v_ref  = _mm256_permute4x64_epi64(v_refl, 0xEE);
 
                         __m256i v_refu = _mm256_alignr_epi8(v_ref, v_refl, 2); // R8R15R14...R2R1
 
-                        v_refl = _mm256_inserti128_si256(
-                            v_refl, _mm256_extracti128_si256(v_refu, 0), 1);
-                        v_refu = _mm256_inserti128_si256(
-                            v_refu, _mm256_extracti128_si256(v_ref, 0), 0);
+                        v_refl = _mm256_inserti128_si256(v_refl, _mm256_castsi256_si128(v_refu), 1);
+                        v_refu = _mm256_inserti128_si256(v_refu, _mm256_castsi256_si128(v_ref), 0);
 
                         __m256i v_sum  = _mm256_set1_epi32(ohoriz);
                         __m256i parsum = _mm256_madd_epi16(v_c01,
@@ -930,10 +918,8 @@ void svt_av1_highbd_warp_affine_avx2(const int32_t *mat, const uint8_t *ref8b, c
 
                         __m256i v_refu = _mm256_alignr_epi8(v_ref, v_refl, 2); // R8R15R14...R2R1
 
-                        v_refl = _mm256_inserti128_si256(
-                            v_refl, _mm256_extracti128_si256(v_refu, 0), 1);
-                        v_refu = _mm256_inserti128_si256(
-                            v_refu, _mm256_extracti128_si256(v_ref, 0), 0);
+                        v_refl = _mm256_inserti128_si256(v_refl, _mm256_castsi256_si128(v_refu), 1);
+                        v_refu = _mm256_inserti128_si256(v_refu, _mm256_castsi256_si128(v_ref), 0);
 
                         __m256i v_sum  = _mm256_set1_epi32(ohoriz);
                         __m256i parsum = _mm256_madd_epi16(
@@ -1042,14 +1028,12 @@ void svt_av1_highbd_warp_affine_avx2(const int32_t *mat, const uint8_t *ref8b, c
                                                        &ref2b[iy * stride2b + ix4 - 7],
                                                        &ref8b[iy * stride8b + ix4 + 1],
                                                        &ref2b[iy * stride2b + ix4 + 1]);
-                        __m256i v_ref = _mm256_permute4x64_epi64(v_refl, 0xEE);
+                        __m256i v_ref  = _mm256_permute4x64_epi64(v_refl, 0xEE);
 
                         __m256i v_refu = _mm256_alignr_epi8(v_ref, v_refl, 2); // R8R15R14...R2R1
 
-                        v_refl = _mm256_inserti128_si256(
-                            v_refl, _mm256_extracti128_si256(v_refu, 0), 1);
-                        v_refu = _mm256_inserti128_si256(
-                            v_refu, _mm256_extracti128_si256(v_ref, 0), 0);
+                        v_refl = _mm256_inserti128_si256(v_refl, _mm256_castsi256_si128(v_refu), 1);
+                        v_refu = _mm256_inserti128_si256(v_refu, _mm256_castsi256_si128(v_ref), 0);
 
                         __m256i v_sum  = _mm256_set1_epi32(ohoriz);
                         __m256i parsum = _mm256_madd_epi16(v_c01,
@@ -1187,11 +1171,11 @@ void svt_av1_highbd_warp_affine_avx2(const int32_t *mat, const uint8_t *ref8b, c
                         __m256i v_sum16 = _mm256_packus_epi32(v_sum1, v_sum1);
                         v_sum16         = _mm256_permute4x64_epi64(v_sum16, 0xD8);
                         v_sum16         = _mm256_min_epi16(v_sum16, clip_pixel);
-                        _mm_storeu_si128(dst16, _mm256_extracti128_si256(v_sum16, 0));
+                        _mm_storeu_si128(dst16, _mm256_castsi256_si128(v_sum16));
                     } else {
                         v_sum           = _mm256_packus_epi32(v_sum, v_sum);
                         __m256i v_sum16 = _mm256_permute4x64_epi64(v_sum, 0xD8);
-                        _mm_storeu_si128(p, _mm256_extracti128_si256(v_sum16, 0));
+                        _mm_storeu_si128(p, _mm256_castsi256_si128(v_sum16));
                     }
                 } else {
                     // Round and pack into 8 bits
@@ -1210,7 +1194,7 @@ void svt_av1_highbd_warp_affine_avx2(const int32_t *mat, const uint8_t *ref8b, c
 
                     __m128i *const p = (__m128i *)&pred[(i + k + 4) * p_stride + j];
 
-                    _mm_storeu_si128(p, _mm256_extracti128_si256(v_sum16, 0));
+                    _mm_storeu_si128(p, _mm256_castsi256_si128(v_sum16));
                 }
             }
         }
