@@ -17,7 +17,7 @@
 #include "EbDefinitions.h"
 
 static INLINE __m256i _mm256_unpacklo_epi128(const __m256i in0, const __m256i in1) {
-    return _mm256_inserti128_si256(in0, _mm256_extracti128_si256(in1, 0), 1);
+    return _mm256_inserti128_si256(in0, _mm256_castsi256_si128(in1), 1);
 }
 
 static INLINE __m256i _mm256_unpackhi_epi128(const __m256i in0, const __m256i in1) {
@@ -110,8 +110,8 @@ static INLINE void transpose_64bit_4x4_avx2(const __m256i *const in, __m256i *co
     // out[1]: 01 11 21 31
     // out[2]: 02 12 22 32
     // out[3]: 03 13 23 33
-    out[0] = _mm256_inserti128_si256(a0, _mm256_extracti128_si256(a1, 0), 1);
-    out[1] = _mm256_inserti128_si256(a2, _mm256_extracti128_si256(a3, 0), 1);
+    out[0] = _mm256_inserti128_si256(a0, _mm256_castsi256_si128(a1), 1);
+    out[1] = _mm256_inserti128_si256(a2, _mm256_castsi256_si128(a3), 1);
     out[2] = _mm256_inserti128_si256(a1, _mm256_extracti128_si256(a0, 1), 0);
     out[3] = _mm256_inserti128_si256(a3, _mm256_extracti128_si256(a2, 1), 0);
 }
