@@ -934,7 +934,7 @@ void svt_av1_highbd_wiener_convolve_add_src_avx2(
                     yy_storeu_256(dst16 + i * dst_stride + j, res_16bit_clamped);
                 } else {
                     _mm_storeu_si128((__m128i*)(dst16 + i * dst_stride + j),
-                                     _mm256_extracti128_si256(res_16bit_clamped, 0));
+                                     _mm256_castsi256_si128(res_16bit_clamped));
                 }
             }
         }
