@@ -21,10 +21,6 @@ extern "C" {
 /**************************************************
     * Assembly Declarations
     **************************************************/
-extern void picture_copy_kernel_sse2(EbByte src, uint32_t src_stride, EbByte dst,
-                                     uint32_t dst_stride, uint32_t area_width,
-                                     uint32_t area_height);
-
 void svt_picture_average_kernel_sse2(EbByte src0, uint32_t src0_stride, EbByte src1,
                                      uint32_t src1_stride, EbByte dst, uint32_t dst_stride,
                                      uint32_t area_width, uint32_t area_height);
