@@ -227,7 +227,7 @@ __attribute__((optimize("unroll-loops")))
 static void
 svt_memcpy_small(void *dst_ptr, const void *src_ptr, size_t size) {
     const unsigned char *src = src_ptr;
-    unsigned char *      dst = dst_ptr;
+    unsigned char       *dst = dst_ptr;
     size_t               i   = 0;
 
 #ifdef _INTEL_COMPILER
@@ -250,7 +250,7 @@ svt_memcpy_small(void *dst_ptr, const void *src_ptr, size_t size) {
 #define EB_MIN(a, b) (((a) < (b)) ? (a) : (b))
 static void svt_memcpy_sse(void *dst_ptr, void const *src_ptr, size_t size) {
     const unsigned char *src       = src_ptr;
-    unsigned char *      dst       = dst_ptr;
+    unsigned char       *dst       = dst_ptr;
     size_t               i         = 0;
     size_t               align_cnt = EB_MIN((64 - ((size_t)dst & 63)), size);
 
@@ -287,4 +287,147 @@ extern void svt_memcpy_intrin_sse(void *dst_ptr, void const *src_ptr, size_t siz
     else
         svt_memcpy_small(dst_ptr, src_ptr, size);
 }
+
+// Store 8 16 bit values. If the destination is 32 bits then sign extend the
+// values by multiplying by 1.
+static INLINE void store_tran_low(__m128i a, int32_t *b) {
+    const __m128i one  = _mm_set1_epi16(1);
+    const __m128i a_hi = _mm_mulhi_epi16(a, one);
+    const __m128i a_lo = _mm_mullo_epi16(a, one);
+    const __m128i a_1  = _mm_unpacklo_epi16(a_lo, a_hi);
+    const __m128i a_2  = _mm_unpackhi_epi16(a_lo, a_hi);
+    _mm_store_si128((__m128i *)(b), a_1);
+    _mm_store_si128((__m128i *)(b + 4), a_2);
+}
+
+static INLINE void hadamard_col8_sse2(__m128i *in, int iter) {
+    __m128i a0 = in[0];
+    __m128i a1 = in[1];
+    __m128i a2 = in[2];
+    __m128i a3 = in[3];
+    __m128i a4 = in[4];
+    __m128i a5 = in[5];
+    __m128i a6 = in[6];
+    __m128i a7 = in[7];
+
+    __m128i b0 = _mm_add_epi16(a0, a1);
+    __m128i b1 = _mm_sub_epi16(a0, a1);
+    __m128i b2 = _mm_add_epi16(a2, a3);
+    __m128i b3 = _mm_sub_epi16(a2, a3);
+    __m128i b4 = _mm_add_epi16(a4, a5);
+    __m128i b5 = _mm_sub_epi16(a4, a5);
+    __m128i b6 = _mm_add_epi16(a6, a7);
+    __m128i b7 = _mm_sub_epi16(a6, a7);
+
+    a0 = _mm_add_epi16(b0, b2);
+    a1 = _mm_add_epi16(b1, b3);
+    a2 = _mm_sub_epi16(b0, b2);
+    a3 = _mm_sub_epi16(b1, b3);
+    a4 = _mm_add_epi16(b4, b6);
+    a5 = _mm_add_epi16(b5, b7);
+    a6 = _mm_sub_epi16(b4, b6);
+    a7 = _mm_sub_epi16(b5, b7);
+
+    if (iter == 0) {
+        b0 = _mm_add_epi16(a0, a4);
+        b7 = _mm_add_epi16(a1, a5);
+        b3 = _mm_add_epi16(a2, a6);
+        b4 = _mm_add_epi16(a3, a7);
+        b2 = _mm_sub_epi16(a0, a4);
+        b6 = _mm_sub_epi16(a1, a5);
+        b1 = _mm_sub_epi16(a2, a6);
+        b5 = _mm_sub_epi16(a3, a7);
+
+        a0 = _mm_unpacklo_epi16(b0, b1);
+        a1 = _mm_unpacklo_epi16(b2, b3);
+        a2 = _mm_unpackhi_epi16(b0, b1);
+        a3 = _mm_unpackhi_epi16(b2, b3);
+        a4 = _mm_unpacklo_epi16(b4, b5);
+        a5 = _mm_unpacklo_epi16(b6, b7);
+        a6 = _mm_unpackhi_epi16(b4, b5);
+        a7 = _mm_unpackhi_epi16(b6, b7);
+
+        b0 = _mm_unpacklo_epi32(a0, a1);
+        b1 = _mm_unpacklo_epi32(a4, a5);
+        b2 = _mm_unpackhi_epi32(a0, a1);
+        b3 = _mm_unpackhi_epi32(a4, a5);
+        b4 = _mm_unpacklo_epi32(a2, a3);
+        b5 = _mm_unpacklo_epi32(a6, a7);
+        b6 = _mm_unpackhi_epi32(a2, a3);
+        b7 = _mm_unpackhi_epi32(a6, a7);
+
+        in[0] = _mm_unpacklo_epi64(b0, b1);
+        in[1] = _mm_unpackhi_epi64(b0, b1);
+        in[2] = _mm_unpacklo_epi64(b2, b3);
+        in[3] = _mm_unpackhi_epi64(b2, b3);
+        in[4] = _mm_unpacklo_epi64(b4, b5);
+        in[5] = _mm_unpackhi_epi64(b4, b5);
+        in[6] = _mm_unpacklo_epi64(b6, b7);
+        in[7] = _mm_unpackhi_epi64(b6, b7);
+    } else {
+        in[0] = _mm_add_epi16(a0, a4);
+        in[7] = _mm_add_epi16(a1, a5);
+        in[3] = _mm_add_epi16(a2, a6);
+        in[4] = _mm_add_epi16(a3, a7);
+        in[2] = _mm_sub_epi16(a0, a4);
+        in[6] = _mm_sub_epi16(a1, a5);
+        in[1] = _mm_sub_epi16(a2, a6);
+        in[5] = _mm_sub_epi16(a3, a7);
+    }
+}
+
+static INLINE void hadamard_8x8_sse2(const int16_t *src_diff, ptrdiff_t src_stride, int32_t *coeff,
+                                     int is_final) {
+    __m128i src[8];
+    src[0] = _mm_load_si128((const __m128i *)src_diff);
+    src[1] = _mm_load_si128((const __m128i *)(src_diff += src_stride));
+    src[2] = _mm_load_si128((const __m128i *)(src_diff += src_stride));
+    src[3] = _mm_load_si128((const __m128i *)(src_diff += src_stride));
+    src[4] = _mm_load_si128((const __m128i *)(src_diff += src_stride));
+    src[5] = _mm_load_si128((const __m128i *)(src_diff += src_stride));
+    src[6] = _mm_load_si128((const __m128i *)(src_diff += src_stride));
+    src[7] = _mm_load_si128((const __m128i *)(src_diff += src_stride));
+
+    hadamard_col8_sse2(src, 0);
+    hadamard_col8_sse2(src, 1);
+
+    if (is_final) {
+        store_tran_low(src[0], coeff);
+        coeff += 8;
+        store_tran_low(src[1], coeff);
+        coeff += 8;
+        store_tran_low(src[2], coeff);
+        coeff += 8;
+        store_tran_low(src[3], coeff);
+        coeff += 8;
+        store_tran_low(src[4], coeff);
+        coeff += 8;
+        store_tran_low(src[5], coeff);
+        coeff += 8;
+        store_tran_low(src[6], coeff);
+        coeff += 8;
+        store_tran_low(src[7], coeff);
+    } else {
+        int16_t *coeff16 = (int16_t *)coeff;
+        _mm_store_si128((__m128i *)coeff16, src[0]);
+        coeff16 += 8;
+        _mm_store_si128((__m128i *)coeff16, src[1]);
+        coeff16 += 8;
+        _mm_store_si128((__m128i *)coeff16, src[2]);
+        coeff16 += 8;
+        _mm_store_si128((__m128i *)coeff16, src[3]);
+        coeff16 += 8;
+        _mm_store_si128((__m128i *)coeff16, src[4]);
+        coeff16 += 8;
+        _mm_store_si128((__m128i *)coeff16, src[5]);
+        coeff16 += 8;
+        _mm_store_si128((__m128i *)coeff16, src[6]);
+        coeff16 += 8;
+        _mm_store_si128((__m128i *)coeff16, src[7]);
+    }
+}
+
+void svt_aom_hadamard_8x8_sse2(const int16_t *src_diff, ptrdiff_t src_stride, int32_t *coeff) {
+    hadamard_8x8_sse2(src_diff, src_stride, coeff, 1);
+}
 #endif
