@@ -261,7 +261,7 @@ void svt_unpack_avg_c(uint16_t *ref16_l0, uint32_t ref_l0_stride, uint16_t *ref1
 
 void svt_unpack_avg_safe_sub_c(uint16_t *ref16_l0, uint32_t ref_l0_stride, uint16_t *ref16_l1,
                                uint32_t ref_l1_stride, uint8_t *dst_ptr, uint32_t dst_stride,
-                               EbBool sub_pred, uint32_t width, uint32_t height) {
+                               Bool sub_pred, uint32_t width, uint32_t height) {
     uint64_t j, k;
     uint8_t  in_pixel_l0, in_pixel_l1;
 
