@@ -101,10 +101,10 @@ static INLINE int32_t get_msb(uint32_t n) {
 extern uint32_t od_divu_small_consts[OD_DIVU_DMAX][2];
 
 /*Translate unsigned division by small divisors into multiplications.*/
-#define OD_DIVU_SMALL(_x, _d)                                                                    \
-    ((uint32_t)(                                                                                 \
-         (od_divu_small_consts[(_d)-1][0] * (uint64_t)(_x) + od_divu_small_consts[(_d)-1][1]) >> \
-         32) >>                                                                                  \
+#define OD_DIVU_SMALL(_x, _d)                                       \
+    ((uint32_t)((od_divu_small_consts[(_d)-1][0] * (uint64_t)(_x) + \
+                 od_divu_small_consts[(_d)-1][1]) >>                \
+                32) >>                                              \
      (OD_ILOG_NZ(_d) - 1))
 
 #define OD_DIVU(_x, _d) (((_d) < OD_DIVU_DMAX) ? (OD_DIVU_SMALL((_x), (_d))) : ((_x) / (_d)))
@@ -230,8 +230,8 @@ struct DaalaWriter {
     uint32_t pos;
     uint8_t *buffer;
     uint32_t buffer_size;
-    OutputBitstreamUnit *
-            buffer_parent; // save a pointer to the container holding the buffer, in case the buffer must be resized
+    OutputBitstreamUnit     *
+        buffer_parent; // save a pointer to the container holding the buffer, in case the buffer must be resized
     OdEcEnc ec;
     uint8_t allow_update_cdf;
 };
@@ -264,7 +264,7 @@ static INLINE void daala_write_symbol(DaalaWriter *w, int32_t symb, const AomCdf
 // bitwriter.h
 typedef struct DaalaWriter AomWriter;
 static INLINE void         aom_start_encode(AomWriter *bc, OutputBitstreamUnit *buffer) {
-    svt_aom_daala_start_encode(bc, buffer);
+            svt_aom_daala_start_encode(bc, buffer);
 }
 static INLINE int32_t aom_stop_encode(AomWriter *bc) { return svt_aom_daala_stop_encode(bc); }
 
