@@ -451,6 +451,16 @@ extern void RunEmms();
 #define EB_ALIGN(n)
 #endif
 
+#ifndef EB_LIKELY
+#if HAVE_BUILTIN_EXPECT
+#define EB_LIKELY(x) __builtin_expect(!!(x), 1)
+#define EB_UNLIKELY(x) __builtin_expect(!!(x), 0)
+#else
+#define EB_LIKELY(x) (x)
+#define EB_UNLIKELY(x) (x)
+#endif
+#endif
+
 #ifdef _MSC_VER
 #define AOM_FORCE_INLINE __forceinline
 #define AOM_INLINE __inline
@@ -1306,6 +1316,7 @@ enum {
     SINGLE_REFS = FWD_REFS + BWD_REFS,
 };
 
+#define REF_FRAMES_LOG2 3
 #define REFS_PER_FRAME 7
 
 #define FWD_RF_OFFSET(ref) (ref - LAST_FRAME)
@@ -1357,9 +1368,6 @@ typedef enum ATTRIBUTE_PACKED {
 // onyxc_int.h
 #define CDEF_MAX_STRENGTHS 16
 
-#define REF_FRAMES_LOG2 3
-#define REF_FRAMES (1 << REF_FRAMES_LOG2)
-
 #define UNDISP_QUEUE_SIZE (REF_FRAMES * 10)
 // 4 scratch frames for the new frames to support a maximum of 4 cores decoding
 // in parallel, 3 for scaled references on the encoder.
@@ -2310,7 +2318,6 @@ void(*error_handler)(
 //***Prediction Structure***
 #define MAX_TEMPORAL_LAYERS                         6
 #define MAX_REF_IDX                                 4
-#define INVALID_POC                                 (((uint32_t) (~0)) - (((uint32_t) (~0)) >> 1))
 #define MAX_ELAPSED_IDR_COUNT                       1024
 
 typedef enum DownSamplingMethod
