@@ -20,21 +20,28 @@
 #define DEBUG_MEMORY_USAGE
 #endif
 
-void svt_print_alloc_fail(const char* file, int line);
+#if EXCLUDE_HASH
+#define svt_print_alloc_fail(a, b) svt_print_alloc_fail_impl(a, 0)
+#else
+#define svt_print_alloc_fail(a, b) svt_print_alloc_fail_impl(a, b)
+#endif
+void svt_print_alloc_fail_impl(const char* file, int line);
 
 #ifdef DEBUG_MEMORY_USAGE
 void svt_print_memory_usage(void);
 void svt_increase_component_count(void);
 void svt_decrease_component_count(void);
-void svt_add_mem_entry(void* ptr, EbPtrType type, size_t count, const char* file, uint32_t line);
+void svt_add_mem_entry_impl(void* ptr, EbPtrType type, size_t count, const char* file,
+                            uint32_t line);
 void svt_remove_mem_entry(void* ptr, EbPtrType type);
 
 #if EXCLUDE_HASH
-#define EB_ADD_MEM_ENTRY(p, type, count) svt_add_mem_entry(p, type, count, __FILE__, 0)
+#define svt_add_mem_entry(a, b, c, d, e) svt_add_mem_entry_impl(a, b, c, d, 0)
 #else
-#define EB_ADD_MEM_ENTRY(p, type, count) svt_add_mem_entry(p, type, count, __FILE__, __LINE__)
+#define svt_add_mem_entry(a, b, c, d, e) svt_add_mem_entry_impl(a, b, c, d, e)
 #endif
 
+#define EB_ADD_MEM_ENTRY(p, type, count) svt_add_mem_entry(p, type, count, __FILE__, __LINE__)
 #define EB_REMOVE_MEM_ENTRY(p, type) svt_remove_mem_entry(p, type);
 
 #else
@@ -56,15 +63,6 @@ void svt_remove_mem_entry(void* ptr, EbPtrType type);
 
 #endif //DEBUG_MEMORY_USAGE
 
-#if EXCLUDE_HASH
-#define EB_NO_THROW_ADD_MEM(p, size, type)            \
-    do {                                              \
-        if (!p)                                       \
-            svt_print_alloc_fail(__FILE__, 0); \
-        else                                          \
-            EB_ADD_MEM_ENTRY(p, type, size);          \
-    } while (0)
-#else
 #define EB_NO_THROW_ADD_MEM(p, size, type)            \
     do {                                              \
         if (!p)                                       \
@@ -72,7 +70,6 @@ void svt_remove_mem_entry(void* ptr, EbPtrType type);
         else                                          \
             EB_ADD_MEM_ENTRY(p, type, size);          \
     } while (0)
-#endif
 
 #define EB_CHECK_MEM(p)                           \
     do {                                          \
