@@ -18,7 +18,6 @@
 #if SRM_REPORT
 #include "EbLog.h"
 #endif
-
 static void svt_fifo_dctor(EbPtr p) {
     EbFifo *obj = (EbFifo *)p;
     EB_DESTROY_SEMAPHORE(obj->counting_semaphore);
@@ -91,7 +90,7 @@ static EbErrorType svt_fifo_shutdown(EbFifo *fifo_ptr) {
 
     // Acquire lockout Mutex
     svt_block_on_mutex(fifo_ptr->lockout_mutex);
-    fifo_ptr->quit_signal = EB_TRUE;
+    fifo_ptr->quit_signal = TRUE;
     // Release Mutex
     svt_release_mutex(fifo_ptr->lockout_mutex);
     //Wake up the waiting process if any
@@ -122,11 +121,11 @@ static EbErrorType svt_circular_buffer_ctor(EbCircularBuffer *bufferPtr,
 /**************************************
  * svt_circular_buffer_empty_check
  **************************************/
-static EbBool svt_circular_buffer_empty_check(EbCircularBuffer *bufferPtr) {
+static Bool svt_circular_buffer_empty_check(EbCircularBuffer *bufferPtr) {
     return ((bufferPtr->head_index == bufferPtr->tail_index) &&
             (bufferPtr->array_ptr[bufferPtr->head_index] == NULL))
-        ? EB_TRUE
-        : EB_FALSE;
+        ? TRUE
+        : FALSE;
 }
 
 /**************************************
@@ -236,12 +235,12 @@ static EbErrorType svt_muxing_queue_ctor(EbMuxingQueue *queue_ptr, uint32_t obje
  **************************************/
 static EbErrorType svt_muxing_queue_assignation(EbMuxingQueue *queue_ptr) {
     EbErrorType      return_error = EB_ErrorNone;
-    EbFifo *         process_fifo_ptr;
+    EbFifo          *process_fifo_ptr;
     EbObjectWrapper *wrapper_ptr;
 
     // while loop
-    while ((svt_circular_buffer_empty_check(queue_ptr->object_queue) == EB_FALSE) &&
-           (svt_circular_buffer_empty_check(queue_ptr->process_queue) == EB_FALSE)) {
+    while ((svt_circular_buffer_empty_check(queue_ptr->object_queue) == FALSE) &&
+           (svt_circular_buffer_empty_check(queue_ptr->process_queue) == FALSE)) {
         // Get the next process
         svt_circular_buffer_pop_front(queue_ptr->process_queue, (void **)&process_fifo_ptr);
 
@@ -267,7 +266,7 @@ static EbErrorType svt_muxing_queue_assignation(EbMuxingQueue *queue_ptr) {
 /**************************************
  * svt_muxing_queue_object_push_back
  **************************************/
-static EbErrorType svt_muxing_queue_object_push_back(EbMuxingQueue *  queue_ptr,
+static EbErrorType svt_muxing_queue_object_push_back(EbMuxingQueue   *queue_ptr,
                                                      EbObjectWrapper *object_ptr) {
     EbErrorType return_error = EB_ErrorNone;
 
@@ -281,7 +280,7 @@ static EbErrorType svt_muxing_queue_object_push_back(EbMuxingQueue *  queue_ptr,
 /**************************************
 * svt_muxing_queue_object_push_front
 **************************************/
-static EbErrorType svt_muxing_queue_object_push_front(EbMuxingQueue *  queue_ptr,
+static EbErrorType svt_muxing_queue_object_push_front(EbMuxingQueue   *queue_ptr,
                                                       EbObjectWrapper *object_ptr) {
     EbErrorType return_error = EB_ErrorNone;
 
@@ -316,7 +315,7 @@ EbErrorType svt_object_release_enable(EbObjectWrapper *wrapper_ptr) {
 
     svt_block_on_mutex(wrapper_ptr->system_resource_ptr->empty_queue->lockout_mutex);
 
-    wrapper_ptr->release_enable = EB_TRUE;
+    wrapper_ptr->release_enable = TRUE;
 
     svt_release_mutex(wrapper_ptr->system_resource_ptr->empty_queue->lockout_mutex);
 
@@ -342,7 +341,7 @@ EbErrorType svt_object_release_disable(EbObjectWrapper *wrapper_ptr) {
 
     svt_block_on_mutex(wrapper_ptr->system_resource_ptr->empty_queue->lockout_mutex);
 
-    wrapper_ptr->release_enable = EB_FALSE;
+    wrapper_ptr->release_enable = FALSE;
 
     svt_release_mutex(wrapper_ptr->system_resource_ptr->empty_queue->lockout_mutex);
 
@@ -368,6 +367,9 @@ EbErrorType svt_object_inc_live_count(EbObjectWrapper *wrapper_ptr, uint32_t inc
 
     svt_block_on_mutex(wrapper_ptr->system_resource_ptr->empty_queue->lockout_mutex);
 
+    assert_err(wrapper_ptr->live_count != EB_ObjectWrapperReleasedValue,
+               "live_count should not be EB_ObjectWrapperReleasedValue when inc");
+
     wrapper_ptr->live_count += increment_number;
 
     svt_release_mutex(wrapper_ptr->system_resource_ptr->empty_queue->lockout_mutex);
@@ -399,7 +401,7 @@ static EbErrorType svt_object_wrapper_ctor(EbObjectWrapper *wrapper, EbSystemRes
     EbErrorType ret;
 
     wrapper->dctor               = svt_object_wrapper_dctor;
-    wrapper->release_enable      = EB_TRUE;
+    wrapper->release_enable      = TRUE;
     wrapper->system_resource_ptr = resource;
     wrapper->object_destroyer    = object_destroyer;
     ret                          = object_creator(&wrapper->object_ptr, object_init_data_ptr);
@@ -462,10 +464,10 @@ EbErrorType svt_system_resource_ctor(EbSystemResource *resource_ptr, uint32_t ob
                object_creator,
                object_init_data_ptr,
                object_destroyer);
+
 #if SRM_REPORT
         resource_ptr->wrapper_ptr_pool[wrapper_index]->pic_number = 99999999;
 #endif
-
     }
 
     // Initialize the Empty Queue
@@ -478,11 +480,10 @@ EbErrorType svt_system_resource_ctor(EbSystemResource *resource_ptr, uint32_t ob
         svt_muxing_queue_object_push_back(resource_ptr->empty_queue,
                                           resource_ptr->wrapper_ptr_pool[wrapper_index]);
     }
-
 #if SRM_REPORT
     //at init time, the SRM is full
     resource_ptr->empty_queue->curr_count = resource_ptr->object_total_count;
-    resource_ptr->empty_queue->log = 0;
+    resource_ptr->empty_queue->log        = 0;
 #endif
     // Initialize the Full Queue
     if (consumer_process_total_count) {
@@ -578,23 +579,27 @@ EbErrorType svt_release_object(EbObjectWrapper *object_ptr) {
 
     svt_block_on_mutex(object_ptr->system_resource_ptr->empty_queue->lockout_mutex);
 
+    assert_err(object_ptr->live_count != EB_ObjectWrapperReleasedValue,
+               "live_count should not be EB_ObjectWrapperReleasedValue when release");
+
     // Decrement live_count
     object_ptr->live_count = (object_ptr->live_count == 0) ? object_ptr->live_count
                                                            : object_ptr->live_count - 1;
 
-    if ((object_ptr->release_enable == EB_TRUE) && (object_ptr->live_count == 0)) {
+    if ((object_ptr->release_enable == TRUE) && (object_ptr->live_count == 0)) {
         // Set live_count to EB_ObjectWrapperReleasedValue
         object_ptr->live_count = EB_ObjectWrapperReleasedValue;
 
         svt_muxing_queue_object_push_front(object_ptr->system_resource_ptr->empty_queue,
                                            object_ptr);
-
 #if SRM_REPORT
         object_ptr->pic_number = 99999999;
         //increment the fullness
         object_ptr->system_resource_ptr->empty_queue->curr_count++;
         if (object_ptr->system_resource_ptr->empty_queue->log)
-            SVT_LOG("SRM fullness+: %i/%i\n", object_ptr->system_resource_ptr->empty_queue->curr_count, object_ptr->system_resource_ptr->object_total_count);
+            SVT_LOG("SRM fullness+: %i/%i\n",
+                    object_ptr->system_resource_ptr->empty_queue->curr_count,
+                    object_ptr->system_resource_ptr->object_total_count);
 #endif
     }
 
@@ -603,23 +608,58 @@ EbErrorType svt_release_object(EbObjectWrapper *object_ptr) {
     return return_error;
 }
 
+EbErrorType svt_release_dual_object(EbObjectWrapper *object_ptr, EbObjectWrapper *sec_object_ptr) {
+    EbErrorType return_error = EB_ErrorNone;
+
+    svt_block_on_mutex(object_ptr->system_resource_ptr->empty_queue->lockout_mutex);
+
+    // Decrement live_count
+    object_ptr->live_count = (object_ptr->live_count == 0) ? object_ptr->live_count
+                                                           : object_ptr->live_count - 1;
+
+    if ((object_ptr->release_enable == TRUE) && (object_ptr->live_count == 0)) {
+        //release the second object
+        svt_release_object(sec_object_ptr);
+
+        // Set live_count to EB_ObjectWrapperReleasedValue
+        object_ptr->live_count = EB_ObjectWrapperReleasedValue;
+
+        svt_muxing_queue_object_push_front(object_ptr->system_resource_ptr->empty_queue,
+                                           object_ptr);
+
+#if SRM_REPORT
+
+        if (object_ptr->system_resource_ptr->empty_queue->log)
+            SVT_LOG("SRM RELEASE: %lld\n", object_ptr->pic_number);
+
+        object_ptr->pic_number = 99999999;
+        //increment the fullness
+        object_ptr->system_resource_ptr->empty_queue->curr_count++;
+        //  if (object_ptr->system_resource_ptr->empty_queue->log)
+        //      SVT_LOG("SRM fullness+: %i/%i\n", object_ptr->system_resource_ptr->empty_queue->curr_count, object_ptr->system_resource_ptr->object_total_count);
+#endif
+    }
+
+    svt_release_mutex(object_ptr->system_resource_ptr->empty_queue->lockout_mutex);
+
+    return return_error;
+}
 #if SRM_REPORT
 /*
   dump pictures occuping the SRM
 */
-EbErrorType dump_srm_content(EbSystemResource *resource_ptr, uint8_t log)
-{
+EbErrorType dump_srm_content(EbSystemResource *resource_ptr, uint8_t log) {
     EbErrorType return_error = EB_ErrorNone;
     if (log) {
         SVT_LOG("SRM content:\n\n");
-        for (uint32_t wrapper_index = 0; wrapper_index < resource_ptr->object_total_count; ++wrapper_index) {
+        for (uint32_t wrapper_index = 0; wrapper_index < resource_ptr->object_total_count;
+             ++wrapper_index) {
             SVT_LOG("%lld ", resource_ptr->wrapper_ptr_pool[wrapper_index]->pic_number);
         }
     }
     return return_error;
 }
 #endif
-
 /*********************************************************************
  * EbSystemResourceGetEmptyObject
  *   Dequeues an empty EbObjectWrapper from the SystemResource.  This
@@ -654,14 +694,20 @@ EbErrorType svt_get_empty_object(EbFifo *empty_fifo_ptr, EbObjectWrapper **wrapp
     //decrement the fullness
     empty_fifo_ptr->queue_ptr->curr_count--;
     if (empty_fifo_ptr->queue_ptr->log)
-        printf("SRM fullness-: %i/%i\n", empty_fifo_ptr->queue_ptr->curr_count, (*wrapper_dbl_ptr)->system_resource_ptr->object_total_count);
+        printf("SRM fullness-: %i/%i\n",
+               empty_fifo_ptr->queue_ptr->curr_count,
+               (*wrapper_dbl_ptr)->system_resource_ptr->object_total_count);
 #endif
 
+    assert_err((*wrapper_dbl_ptr)->live_count == 0 ||
+                   (*wrapper_dbl_ptr)->live_count == EB_ObjectWrapperReleasedValue,
+               "live_count should be 0 or EB_ObjectWrapperReleasedValue when get");
+
     // Reset the wrapper's live_count
     (*wrapper_dbl_ptr)->live_count = 0;
 
     // Object release enable
-    (*wrapper_dbl_ptr)->release_enable = EB_TRUE;
+    (*wrapper_dbl_ptr)->release_enable = TRUE;
 
     // Release Mutex
     svt_release_mutex(empty_fifo_ptr->lockout_mutex);
@@ -712,18 +758,18 @@ EbErrorType svt_get_full_object(EbFifo *full_fifo_ptr, EbObjectWrapper **wrapper
 /**************************************
 * svt_fifo_pop_front
 **************************************/
-static EbBool svt_fifo_peak_front(EbFifo *fifoPtr) {
+static Bool svt_fifo_peak_front(EbFifo *fifoPtr) {
     // Set wrapper_ptr to head of BufferPool
     if (fifoPtr->first_ptr == (EbObjectWrapper *)NULL)
-        return EB_TRUE;
+        return TRUE;
     else
-        return EB_FALSE;
+        return FALSE;
 }
 
-EbErrorType svt_get_full_object_non_blocking(EbFifo *          full_fifo_ptr,
+EbErrorType svt_get_full_object_non_blocking(EbFifo           *full_fifo_ptr,
                                              EbObjectWrapper **wrapper_dbl_ptr) {
     EbErrorType return_error = EB_ErrorNone;
-    EbBool      fifo_empty;
+    Bool        fifo_empty;
     // Queue the Fifo requesting the full fifo
     svt_release_process(full_fifo_ptr);
 
@@ -734,12 +780,12 @@ EbErrorType svt_get_full_object_non_blocking(EbFifo *          full_fifo_ptr,
     if (!full_fifo_ptr->quit_signal)
         fifo_empty = svt_fifo_peak_front(full_fifo_ptr);
     else
-        fifo_empty = EB_TRUE;
+        fifo_empty = TRUE;
 
     // Release Mutex
     svt_release_mutex(full_fifo_ptr->lockout_mutex);
 
-    if (fifo_empty == EB_FALSE)
+    if (fifo_empty == FALSE)
         svt_get_full_object(full_fifo_ptr, wrapper_dbl_ptr);
     else
         *wrapper_dbl_ptr = (EbObjectWrapper *)NULL;
