@@ -17,10 +17,14 @@
 
 #if defined(__has_feature)
 #if __has_feature(thread_sanitizer)
-#define EB_THREAD_SANITIZER_ENABLED
+#define EB_THREAD_SANITIZER_ENABLED 1
 #endif
 #endif
 
+#ifndef EB_THREAD_SANITIZER_ENABLED
+#define EB_THREAD_SANITIZER_ENABLED 0
+#endif
+
 /****************************************
  * Universal Includes
  ****************************************/
@@ -73,45 +77,55 @@ EbHandle svt_create_thread(void *thread_function(void *), void *thread_context)
         NULL); // new thread ID
 
 #else
-
-    int        ret;
-    pthread_t *th;
-
-    th = malloc(sizeof(pthread_t));
-    if (th == NULL)
-        return NULL;
-
-#if !defined(EB_THREAD_SANITIZER_ENABLED) && !DISABLE_REALTIME
     pthread_attr_t attr;
-    pthread_attr_init(&attr);
-    pthread_attr_setschedpolicy(&attr, SCHED_FIFO);
-    pthread_attr_setinheritsched(&attr, PTHREAD_EXPLICIT_SCHED);
-
-    struct sched_param param = {.sched_priority = 99};
-    pthread_attr_setschedparam(&attr, &param);
-
-    ret = pthread_create(th, &attr, thread_function, thread_context);
-    pthread_attr_destroy(&attr);
-
-    if (ret == EPERM) {
-        // When creating the thread failed because setting scheduling
-        // parameters failed, retry creating the thread without them.
-        ret = pthread_create(th, NULL, thread_function, thread_context);
+    if (pthread_attr_init(&attr)) {
+        SVT_ERROR("Failed to initalize thread attributes\n");
+        return NULL;
+    }
+    size_t stack_size;
+    if (pthread_attr_getstacksize(&attr, &stack_size)) {
+        SVT_ERROR("Failed to get thread stack size\n");
+        pthread_attr_destroy(&attr);
+        return NULL;
+    }
+    // 1 MiB in bytes for now since we can't easily change the stack size after creation
+    const size_t min_stack_size = 1024 * 1024;
+    if (stack_size < min_stack_size && pthread_attr_setstacksize(&attr, min_stack_size)) {
+        SVT_ERROR("Failed to set thread stack size\n");
+        pthread_attr_destroy(&attr);
+        return NULL;
+    }
+    pthread_t *th = malloc(sizeof(*th));
+    if (th == NULL) {
+        SVT_ERROR("Failed to allocate thread handle\n");
+        return NULL;
     }
-#else
-    // When running with thread sanitizer, we are not running as root
-    // so the above priority change will always fail, which will cause
-    // issues with the thread sanitizer.
-    // See https://github.com/google/sanitizers/issues/1088
-    // Therefore we never try this, with the thread sanitizer
-    // and just create a normal thread here.
-    ret = pthread_create(th, NULL, thread_function, thread_context);
-#endif
 
-    if (ret != 0) {
+    if (pthread_create(th, &attr, thread_function, thread_context)) {
+        SVT_ERROR("Failed to create thread: %s\n", strerror(errno));
         free(th);
         return NULL;
     }
+
+    pthread_attr_destroy(&attr);
+
+    /* We can only use realtime priority if we are running as root, so
+     * check if geteuid() == 0 (meaning either root or sudo).
+     * If we don't do this check, we will eventually run into memory
+     * issues if the encoder is uninitalized and re-initalized multiple
+     * times in one executable due to a bug in glibc.
+     * https://sourceware.org/bugzilla/show_bug.cgi?id=19511
+     *
+     * We still need to exclude the case of thread sanitizer because we
+     * run the test as root inside the container and trying to change
+     * the thread priority will __always__ fail the thread sanitizer.
+     * https://github.com/google/sanitizers/issues/1088
+     */
+    if (!EB_THREAD_SANITIZER_ENABLED && !geteuid()) {
+        if (pthread_setschedparam(*th, SCHED_FIFO, &(struct sched_param){.sched_priority = 99}))
+            SVT_WARN("Failed to set thread priority\n");
+        // ignore if this failed
+    }
     thread_handle = th;
 #endif // _WIN32
 
@@ -175,8 +189,8 @@ EbErrorType svt_destroy_thread(EbHandle thread_handle) {
     WaitForSingleObject(thread_handle, INFINITE);
     error_return = CloseHandle(thread_handle) ? EB_ErrorNone : EB_ErrorDestroyThreadFailed;
 #else
-    error_return = pthread_join(*((pthread_t *)thread_handle), NULL) ? EB_ErrorDestroyThreadFailed
-                                                                     : EB_ErrorNone;
+    error_return  = pthread_join(*((pthread_t *)thread_handle), NULL) ? EB_ErrorDestroyThreadFailed
+                                                                      : EB_ErrorNone;
     free(thread_handle);
 #endif // _WIN32
 
@@ -378,7 +392,7 @@ EbErrorType svt_create_cond_var(CondVar *cond_var) {
     return_error = EB_ErrorNone;
 #else
     pthread_mutex_init(&cond_var->m_mutex, NULL);
-    return_error = pthread_cond_init(&cond_var->m_cond, NULL);
+    return_error  = pthread_cond_init(&cond_var->m_cond, NULL);
 
 #endif
     return return_error;
