@@ -89,8 +89,8 @@ void dec_svt_av1_warp_plane(EbWarpedMotionParams *wm, int use_hbd, int bd, const
                             int p_width, int p_height, int p_stride, int subsampling_x,
                             int subsampling_y, ConvolveParams *conv_params);
 
-EbBool svt_find_projection(int np, int *pts1, int *pts2, BlockSize bsize, int mvy, int mvx,
-                           EbWarpedMotionParams *wm_params, int mi_row, int mi_col);
+Bool svt_find_projection(int np, int *pts1, int *pts2, BlockSize bsize, int mvy, int mvx,
+                         EbWarpedMotionParams *wm_params, int mi_row, int mi_col);
 
 int svt_get_shear_params(EbWarpedMotionParams *wm);
 
