@@ -33,6 +33,7 @@
 #include <errno.h>
 #include <sys/stat.h>
 #include <fcntl.h>
+#include <unistd.h>
 #endif
 
 #if defined(_MSC_VER)
@@ -49,14 +50,14 @@
 #ifdef _WIN32
 uint8_t        num_groups = 0;
 GROUP_AFFINITY group_affinity;
-EbBool         alternate_groups = 0;
+Bool           alternate_groups = 0;
 #elif defined(__linux__)
 cpu_set_t group_affinity;
 #endif
 
 EbMemoryMapEntry *svt_dec_memory_map;
-uint32_t *        svt_dec_memory_map_index;
-uint64_t *        svt_dec_total_lib_memory;
+uint32_t         *svt_dec_memory_map_index;
+uint64_t         *svt_dec_total_lib_memory;
 
 uint32_t svt_dec_lib_malloc_count = 0;
 
@@ -75,9 +76,10 @@ EbErrorType decode_multiple_obu(EbDecHandle *dec_handle_ptr, uint8_t **data, siz
                                 uint32_t is_annexb);
 
 static void dec_switch_to_real_time() {
-#if !defined(_WIN32) && !DISABLE_REALTIME
-    (void)pthread_setschedparam(
-        pthread_self(), SCHED_FIFO, &(struct sched_param){.sched_priority = 99});
+#if !defined(_WIN32)
+    if (!geteuid())
+        (void)pthread_setschedparam(
+            pthread_self(), SCHED_FIFO, &(struct sched_param){.sched_priority = 99});
 #endif
 }
 
@@ -85,7 +87,7 @@ static void dec_switch_to_real_time() {
 * Decoder Library Handle Constructor
 ************************************/
 /*TODO : Add more features*/
-static EbErrorType svt_dec_handle_ctor(EbDecHandle **   decHandleDblPtr,
+static EbErrorType svt_dec_handle_ctor(EbDecHandle    **decHandleDblPtr,
                                        EbComponentType *ebHandlePtr) {
     (void)ebHandlePtr;
     EbErrorType return_error = EB_ErrorNone;
@@ -106,7 +108,7 @@ static EbErrorType svt_dec_handle_ctor(EbDecHandle **   decHandleDblPtr,
     svt_dec_memory_map_index = &dec_handle_ptr->memory_map_index;
     svt_dec_lib_malloc_count = 0;
 
-    dec_handle_ptr->start_thread_process = EB_FALSE;
+    dec_handle_ptr->start_thread_process = FALSE;
     memory_map_start_address             = NULL;
     memory_map_end_address               = NULL;
 
@@ -133,7 +135,7 @@ static void copy_even(uint8_t *luma, uint32_t wd, uint32_t ht, uint32_t stride,
 /* Copy from recon buffer to out buffer! */
 int svt_dec_out_buf(EbDecHandle *dec_handle_ptr, EbBufferHeaderType *p_buffer) {
     EbPictureBufferDesc *recon_picture_buf = dec_handle_ptr->cur_pic_buf[0]->ps_pic_buf;
-    EbSvtIOFormat *      out_img           = (EbSvtIOFormat *)p_buffer->p_buffer;
+    EbSvtIOFormat       *out_img           = (EbSvtIOFormat *)p_buffer->p_buffer;
 
     uint8_t *luma = NULL;
     uint8_t *cb   = NULL;
@@ -227,7 +229,7 @@ int svt_dec_out_buf(EbDecHandle *dec_handle_ptr, EbBufferHeaderType *p_buffer) {
     default: assert(0);
     }
 
-    int32_t use_high_bit_depth = recon_picture_buf->bit_depth == EB_8BIT ? 0 : 1;
+    int32_t use_high_bit_depth = recon_picture_buf->bit_depth == EB_EIGHT_BIT ? 0 : 1;
 
     luma = out_img->luma +
         ((out_img->origin_y * out_img->y_stride + out_img->origin_x) << use_high_bit_depth);
@@ -244,9 +246,9 @@ int svt_dec_out_buf(EbDecHandle *dec_handle_ptr, EbBufferHeaderType *p_buffer) {
 
     /* Memcpy to dst buffer */
     {
-        if (recon_picture_buf->bit_depth == EB_8BIT) {
+        if (recon_picture_buf->bit_depth == EB_EIGHT_BIT) {
             if (dec_handle_ptr->is_16bit_pipeline) {
-                uint8_t * dst;
+                uint8_t  *dst;
                 uint16_t *pu2_src;
                 uint32_t  j;
                 ASSERT(recon_picture_buf->is_16bit_pipeline);
@@ -372,8 +374,8 @@ int svt_dec_out_buf(EbDecHandle *dec_handle_ptr, EbBufferHeaderType *p_buffer) {
         AomFilmGrain *film_grain_ptr = &dec_handle_ptr->cur_pic_buf[0]->film_grain_params;
         if (film_grain_ptr->apply_grain) {
             switch (recon_picture_buf->bit_depth) {
-            case EB_8BIT: film_grain_ptr->bit_depth = 8; break;
-            case EB_10BIT: film_grain_ptr->bit_depth = 10; break;
+            case EB_EIGHT_BIT: film_grain_ptr->bit_depth = 8; break;
+            case EB_TEN_BIT: film_grain_ptr->bit_depth = 10; break;
             default: assert(0);
             }
             copy_even(luma, wd, ht, out_img->y_stride, use_high_bit_depth);
@@ -501,7 +503,7 @@ EB_API EbErrorType svt_av1_dec_init_handle(EbComponentType **p_handle, void *p_a
     return return_error;
 }
 
-EB_API EbErrorType svt_av1_dec_set_parameter(EbComponentType *         svt_dec_component,
+EB_API EbErrorType svt_av1_dec_set_parameter(EbComponentType          *svt_dec_component,
                                              EbSvtAv1DecConfiguration *config_struct) {
     if (svt_dec_component == NULL || config_struct == NULL)
         return EB_ErrorBadParameter;
@@ -521,9 +523,9 @@ EB_API EbErrorType svt_av1_dec_init(EbComponentType *svt_dec_component) {
 
     EbDecHandle *dec_handle_ptr = (EbDecHandle *)svt_dec_component->p_component_private;
 #ifdef ARCH_X86_64
-    CPU_FLAGS cpu_flags = get_cpu_flags_to_use();
+    EbCpuFlags cpu_flags = get_cpu_flags_to_use();
 #else
-    CPU_FLAGS cpu_flags = 0;
+    EbCpuFlags cpu_flags = 0;
 #endif
     dec_handle_ptr->dec_cnt       = -1;
     dec_handle_ptr->num_frms_prll = 1;
@@ -567,8 +569,8 @@ EB_API EbErrorType svt_av1_dec_frame(EbComponentType *svt_dec_component, const u
         return EB_ErrorBadParameter;
 
     EbDecHandle *dec_handle_ptr       = (EbDecHandle *)svt_dec_component->p_component_private;
-    uint8_t *    data_start           = (uint8_t *)data;
-    uint8_t *    data_end             = (uint8_t *)data + data_size;
+    uint8_t     *data_start           = (uint8_t *)data;
+    uint8_t     *data_end             = (uint8_t *)data + data_size;
     dec_handle_ptr->seen_frame_header = 0;
 
     while (data_start < data_end) {
@@ -605,10 +607,10 @@ EB_API EbErrorType svt_av1_dec_frame(EbComponentType *svt_dec_component, const u
     return return_error;
 }
 
-EB_API EbErrorType svt_av1_dec_get_picture(EbComponentType *   svt_dec_component,
+EB_API EbErrorType svt_av1_dec_get_picture(EbComponentType    *svt_dec_component,
                                            EbBufferHeaderType *p_buffer,
-                                           EbAV1StreamInfo *   stream_info,
-                                           EbAV1FrameInfo *    frame_info) {
+                                           EbAV1StreamInfo    *stream_info,
+                                           EbAV1FrameInfo     *frame_info) {
     (void)stream_info;
     (void)frame_info;
 
