@@ -63,7 +63,7 @@ static INLINE void cfl_pad(CflCtx *cfl, int32_t width, int32_t height) {
 
     if (diff_width > 0) {
         const int min_height   = height - diff_height;
-        int16_t * recon_buf_q3 = cfl->recon_buf_q3 + (width - diff_width);
+        int16_t  *recon_buf_q3 = cfl->recon_buf_q3 + (width - diff_width);
         for (int j = 0; j < min_height; j++) {
             const int16_t last_pixel = recon_buf_q3[-1];
             assert(recon_buf_q3 + diff_width <= cfl->recon_buf_q3 + CFL_BUF_SQUARE);
@@ -186,7 +186,7 @@ static void cfl_compute_parameters(CflCtx *cfl_ctx, TxSize tx_size) {
 
 static void cfl_predict_block(PartitionInfo *xd, CflCtx *cfl_ctx, uint8_t *dst, int32_t dst_stride,
                               TxSize tx_size, int32_t plane, EbColorConfig *cc, FrameHeader *fh,
-                              EbBool is_16bit) {
+                              Bool is_16bit) {
     BlockModeInfo *mbmi                = xd->mi;
     CflAllowedType is_cfl_allowed_flag = is_cfl_allowed_with_frame_header(xd, cc, fh);
     assert(is_cfl_allowed_flag == CFL_ALLOWED);
@@ -199,7 +199,7 @@ static void cfl_predict_block(PartitionInfo *xd, CflCtx *cfl_ctx, uint8_t *dst,
         mbmi->cfl_alpha_idx, mbmi->cfl_alpha_signs, plane - 1);
     assert((tx_size_high[tx_size] - 1) * CFL_BUF_LINE + tx_size_wide[tx_size] <= CFL_BUF_SQUARE);
 
-    if ((cc->bit_depth != EB_8BIT) || is_16bit) {
+    if ((cc->bit_depth != EB_EIGHT_BIT) || is_16bit) {
         svt_cfl_predict_hbd(cfl_ctx->recon_buf_q3,
                             (uint16_t *)dst,
                             dst_stride,
@@ -283,7 +283,7 @@ static INLINE void sub8x8_adjust_offset(PartitionInfo *xd, const CflCtx *cfl_ctx
 
 void svt_cfl_store_tx(PartitionInfo *xd, CflCtx *cfl_ctx, int row, int col, TxSize tx_size,
                       BlockSize bsize, EbColorConfig *cc, uint8_t *dst_buff, uint32_t dst_stride,
-                      EbBool is_16bit) {
+                      Bool is_16bit) {
     if (block_size_high[bsize] == 4 || block_size_wide[bsize] == 4) {
         // Only dimensions of size 4 can have an odd offset.
         assert(!((col & 1) && tx_size_wide[tx_size] != 4));
@@ -291,8 +291,13 @@ void svt_cfl_store_tx(PartitionInfo *xd, CflCtx *cfl_ctx, int row, int col, TxSi
         sub8x8_adjust_offset(xd, cfl_ctx, &row, &col);
     }
 
-    cfl_store(
-        cfl_ctx, dst_buff, dst_stride, row, col, tx_size, ((cc->bit_depth != EB_8BIT) || is_16bit));
+    cfl_store(cfl_ctx,
+              dst_buff,
+              dst_stride,
+              row,
+              col,
+              tx_size,
+              ((cc->bit_depth != EB_EIGHT_BIT) || is_16bit));
 }
 //#####.....................Ending for wrapper of CFL...............................####//
 
@@ -671,7 +676,7 @@ void svtav1_predict_intra_block(PartitionInfo *xd, int32_t plane, TxSize tx_size
                                 void *pv_pred_buf, int32_t pred_stride, void *top_neigh_array,
                                 void *left_neigh_array, int32_t ref_stride, SeqHeader *seq_header,
                                 const PredictionMode mode, int32_t blk_mi_col_off,
-                                int32_t blk_mi_row_off, EbBitDepthEnum bit_depth, EbBool is_16bit) {
+                                int32_t blk_mi_row_off, EbBitDepth bit_depth, Bool is_16bit) {
     //ToDo:are_parameters_computed variable for CFL so that cal part for V plane we can skip,
     //once we compute for U plane, this parameter is block level parameter.
     const EbColorConfig *cc    = &seq_header->color_config;
@@ -750,7 +755,7 @@ void svtav1_predict_intra_block(PartitionInfo *xd, int32_t plane, TxSize tx_size
     const int32_t disable_edge_filter = !seq_header->enable_intra_edge_filter;
 
     //###..Calling all other intra predictors except CFL & pallate...//
-    if (bit_depth == EB_8BIT && !is_16bit) {
+    if (bit_depth == EB_EIGHT_BIT && !is_16bit) {
         decode_build_intra_predictors(xd,
                                       (uint8_t *)top_neigh_array, /*As per SVT Enc*/
                                       (uint8_t *)left_neigh_array,
@@ -790,16 +795,16 @@ void svtav1_predict_intra_block(PartitionInfo *xd, int32_t plane, TxSize tx_size
 
 void svt_av1_predict_intra(DecModCtxt *dec_mod_ctxt, PartitionInfo *part_info, int32_t plane,
                            TxSize tx_size, TileInfo *td, void *pv_blk_recon_buf,
-                           int32_t recon_stride, EbBitDepthEnum bit_depth, int32_t blk_mi_col_off,
+                           int32_t recon_stride, EbBitDepth bit_depth, int32_t blk_mi_col_off,
                            int32_t blk_mi_row_off) {
     void *pv_top_neighbor_array, *pv_left_neighbor_array;
 
-    EbDecHandle *        dec_handle = (EbDecHandle *)dec_mod_ctxt->dec_handle_ptr;
-    EbBool               is16b      = dec_handle->is_16bit_pipeline;
+    EbDecHandle         *dec_handle = (EbDecHandle *)dec_mod_ctxt->dec_handle_ptr;
+    Bool                 is16b      = dec_handle->is_16bit_pipeline;
     const PredictionMode mode       = (plane == AOM_PLANE_Y) ? part_info->mi->mode
                                                              : get_uv_mode(part_info->mi->uv_mode);
 
-    if (bit_depth == EB_8BIT && !is16b) {
+    if (bit_depth == EB_EIGHT_BIT && !is16b) {
         EbByte buf             = (EbByte)pv_blk_recon_buf;
         pv_top_neighbor_array  = (void *)(buf - recon_stride);
         pv_left_neighbor_array = (void *)(buf - 1);
