@@ -51,7 +51,7 @@ static INLINE void build_obmc_inter_pred_above(
     int above_tmp_stride[MAX_MB_PLANE], uint8_t *curr_blk_recon_buf[MAX_MB_PLANE],
     int32_t curr_recon_stride[MAX_MB_PLANE], const int num_planes) {
     EbPictureBufferDesc *recon_picture_buf = dec_handle->cur_pic_buf[0]->ps_pic_buf;
-    const int            is_hbd            = ((recon_picture_buf->bit_depth != EB_8BIT) ||
+    const int            is_hbd            = ((recon_picture_buf->bit_depth != EB_EIGHT_BIT) ||
                         recon_picture_buf->is_16bit_pipeline)
                               ? 1
                               : 0;
@@ -122,7 +122,7 @@ static INLINE void build_obmc_inter_pred_left(
     uint8_t *curr_blk_recon_buf[MAX_MB_PLANE], int32_t curr_recon_stride[MAX_MB_PLANE],
     const int num_planes) {
     EbPictureBufferDesc *recon_picture_buf = dec_handle->cur_pic_buf[0]->ps_pic_buf;
-    const int            is_hbd            = ((recon_picture_buf->bit_depth != EB_8BIT) ||
+    const int            is_hbd            = ((recon_picture_buf->bit_depth != EB_EIGHT_BIT) ||
                         recon_picture_buf->is_16bit_pipeline)
                               ? 1
                               : 0;
@@ -231,7 +231,8 @@ static INLINE void dec_build_prediction_by_above_pred(
         uint8_t sub_x = (plane > 0) ? backup_pi->subsampling_x : 0;
         uint8_t sub_y = (plane > 0) ? backup_pi->subsampling_y : 0;
 
-        if ((recon_picture_buf->bit_depth != EB_8BIT) || recon_picture_buf->is_16bit_pipeline) {
+        if ((recon_picture_buf->bit_depth != EB_EIGHT_BIT) ||
+            recon_picture_buf->is_16bit_pipeline) {
             tmp_recon_buf = (uint8_t *)((uint16_t *)tmp_buf[plane] +
                                         ((rel_mi_col * MI_SIZE) >> sub_x) +
                                         0 /*No y-offset for obmc above pred*/);
@@ -396,7 +397,8 @@ static INLINE void dec_build_prediction_by_left_pred(
         int32_t sub_x = (plane > 0) ? backup_pi->subsampling_x : 0;
         int32_t sub_y = (plane > 0) ? backup_pi->subsampling_y : 0;
 
-        if ((recon_picture_buf->bit_depth != EB_8BIT) || recon_picture_buf->is_16bit_pipeline) {
+        if ((recon_picture_buf->bit_depth != EB_EIGHT_BIT) ||
+            recon_picture_buf->is_16bit_pipeline) {
             tmp_recon_buf = (uint8_t *)((uint16_t *)tmp_buf[plane] +
                                         ((MI_SIZE * rel_mi_row * tmp_stride[plane]) >> sub_y) +
                                         0 /*No x offst for left obmc pred*/);
