@@ -44,7 +44,7 @@
 #include <windows.h>
 extern uint8_t        num_groups;
 extern GROUP_AFFINITY group_affinity;
-extern EbBool         alternate_groups;
+extern Bool           alternate_groups;
 #elif defined(__linux__)
 extern cpu_set_t group_affinity;
 #endif
@@ -167,8 +167,7 @@ EbErrorType dec_system_resource_init(EbDecHandle *dec_handle_ptr, TilesInfo *til
     /* Recon */
     EB_MALLOC_DEC(uint32_t *,
                   dec_mt_frame_data->sb_recon_row_map,
-                  picture_height_in_sb * tiles_info->tile_cols * sizeof(uint32_t),
-                  EB_N_PTR);
+                  picture_height_in_sb * tiles_info->tile_cols * sizeof(uint32_t));
 
     DecMtRowInfo *recon_tile_info = &dec_mt_frame_data->recon_tile_info;
     EB_CREATE_MUTEX(recon_tile_info->sbrow_mutex);
@@ -183,8 +182,7 @@ EbErrorType dec_system_resource_init(EbDecHandle *dec_handle_ptr, TilesInfo *til
 
         EB_MALLOC_DEC(DecMtParseReconTileInfo *,
                       dec_mt_frame_data->parse_recon_tile_info_array,
-                      num_tiles * sizeof(DecMtParseReconTileInfo),
-                      EB_N_PTR);
+                      num_tiles * sizeof(DecMtParseReconTileInfo));
 
         for (tiles_ctr = 0; tiles_ctr < num_tiles; tiles_ctr++) {
             int32_t   tile_row = tiles_ctr / tiles_info->tile_cols;
@@ -209,20 +207,17 @@ EbErrorType dec_system_resource_init(EbDecHandle *dec_handle_ptr, TilesInfo *til
             EB_MALLOC_DEC(
                 uint32_t *,
                 dec_mt_frame_data->parse_recon_tile_info_array[tiles_ctr].sb_recon_row_parsed,
-                tile_num_sb_rows * sizeof(uint32_t),
-                EB_N_PTR);
+                tile_num_sb_rows * sizeof(uint32_t));
 
             EB_MALLOC_DEC(
                 uint32_t *,
                 dec_mt_frame_data->parse_recon_tile_info_array[tiles_ctr].sb_recon_completed_in_row,
-                tile_num_sb_rows * sizeof(uint32_t),
-                EB_N_PTR);
+                tile_num_sb_rows * sizeof(uint32_t));
 
             EB_MALLOC_DEC(
                 uint32_t *,
                 dec_mt_frame_data->parse_recon_tile_info_array[tiles_ctr].sb_recon_row_started,
-                tile_num_sb_rows * sizeof(uint32_t),
-                EB_N_PTR);
+                tile_num_sb_rows * sizeof(uint32_t));
 
             EB_CREATE_MUTEX(
                 dec_mt_frame_data->parse_recon_tile_info_array[tiles_ctr].tile_sbrow_mutex);
@@ -235,7 +230,7 @@ EbErrorType dec_system_resource_init(EbDecHandle *dec_handle_ptr, TilesInfo *til
             //    1, /* consumer prcos cnt : 1 Q per cnt is created inside, so kept 1*/
             //    &dec_mt_frame_data->parse_recon_tile_info_array[tiles_ctr].recon_tile_sbrow_producer_fifo_ptr, /* producer_fifo */
             //    &dec_mt_frame_data->parse_recon_tile_info_array[tiles_ctr].recon_tile_sbrow_consumer_fifo_ptr, /* consumer_fifo */
-            //    EB_TRUE, /* Full Queue*/
+            //    TRUE, /* Full Queue*/
             //    dec_dummy_creator, // Removed in "dec_dummy_creator: unusedFunction"
             //    &node_idx,
             //    NULL);
@@ -245,13 +240,10 @@ EbErrorType dec_system_resource_init(EbDecHandle *dec_handle_ptr, TilesInfo *til
     /* LF */
     EB_MALLOC_DEC(int32_t *,
                   dec_mt_frame_data->lf_frame_info.sb_lf_completed_in_row,
-                  picture_height_in_sb * sizeof(int32_t),
-                  EB_N_PTR);
+                  picture_height_in_sb * sizeof(int32_t));
 
-    EB_MALLOC_DEC(uint32_t *,
-                  dec_mt_frame_data->lf_row_map,
-                  picture_height_in_sb * sizeof(uint32_t),
-                  EB_N_PTR);
+    EB_MALLOC_DEC(
+        uint32_t *, dec_mt_frame_data->lf_row_map, picture_height_in_sb * sizeof(uint32_t));
 
     DecMtRowInfo *lf_sb_row_info = &dec_mt_frame_data->lf_frame_info.lf_sb_row_info;
 
@@ -273,18 +265,14 @@ EbErrorType dec_system_resource_init(EbDecHandle *dec_handle_ptr, TilesInfo *til
 
     /*ToDo: Linebuff memory we can allocate min(sb_rows , threads)*/
     /*Currently we r allocating for every (64x64 +1 )rows*/
-    EB_MALLOC_DEC(
-        uint16_t ***, dec_mt_frame_data->cdef_linebuf, (nvfb + 1) * sizeof(uint16_t **), EB_N_PTR);
+    EB_MALLOC_DEC(uint16_t ***, dec_mt_frame_data->cdef_linebuf, (nvfb + 1) * sizeof(uint16_t **));
     for (int32_t sb_row = 0; sb_row < (nvfb + 1); sb_row++) {
         uint16_t **p_linebuf;
-        EB_MALLOC_DEC(uint16_t **,
-                      dec_mt_frame_data->cdef_linebuf[sb_row],
-                      num_planes * sizeof(uint16_t **),
-                      EB_N_PTR);
+        EB_MALLOC_DEC(
+            uint16_t **, dec_mt_frame_data->cdef_linebuf[sb_row], num_planes * sizeof(uint16_t **));
         p_linebuf = dec_mt_frame_data->cdef_linebuf[sb_row];
         for (int32_t pli = 0; pli < num_planes; pli++) {
-            EB_MALLOC_DEC(
-                uint16_t *, p_linebuf[pli], sizeof(uint16_t) * CDEF_VBORDER * stride, EB_N_PTR);
+            EB_MALLOC_DEC(uint16_t *, p_linebuf[pli], sizeof(uint16_t) * CDEF_VBORDER * stride);
         }
     }
 
@@ -293,16 +281,13 @@ EbErrorType dec_system_resource_init(EbDecHandle *dec_handle_ptr, TilesInfo *til
     to avoid to pointing junck memory, we allocate nvfb+1 64x64 blocks*/
     EB_MALLOC_DEC(uint8_t *,
                   dec_mt_frame_data->row_cdef_map,
-                  (nvfb + 1) * dec_mt_frame_data->cdef_map_stride * sizeof(uint8_t),
-                  EB_N_PTR);
+                  (nvfb + 1) * dec_mt_frame_data->cdef_map_stride * sizeof(uint8_t));
     memset(dec_mt_frame_data->row_cdef_map,
            1,
            (nvfb + 1) * dec_mt_frame_data->cdef_map_stride * sizeof(uint8_t));
 
-    EB_MALLOC_DEC(uint32_t *,
-                  dec_mt_frame_data->cdef_completed_in_row,
-                  (nvfb + 2) * sizeof(uint32_t),
-                  EB_N_PTR);
+    EB_MALLOC_DEC(
+        uint32_t *, dec_mt_frame_data->cdef_completed_in_row, (nvfb + 2) * sizeof(uint32_t));
 
     memset(dec_mt_frame_data->cdef_completed_in_row,
            0,
@@ -311,8 +296,7 @@ EbErrorType dec_system_resource_init(EbDecHandle *dec_handle_ptr, TilesInfo *til
 
     EB_MALLOC_DEC(uint32_t *,
                   dec_mt_frame_data->cdef_completed_for_row_map,
-                  picture_height_in_sb * sizeof(uint32_t),
-                  EB_N_PTR);
+                  picture_height_in_sb * sizeof(uint32_t));
 
     DecMtRowInfo *cdef_sb_row_info = &dec_mt_frame_data->cdef_sb_row_info;
 
@@ -323,13 +307,10 @@ EbErrorType dec_system_resource_init(EbDecHandle *dec_handle_ptr, TilesInfo *til
     /* LR */
     EB_MALLOC_DEC(int32_t *,
                   dec_mt_frame_data->sb_lr_completed_in_row,
-                  picture_height_in_sb * sizeof(int32_t),
-                  EB_N_PTR);
+                  picture_height_in_sb * sizeof(int32_t));
 
-    EB_MALLOC_DEC(uint32_t *,
-                  dec_mt_frame_data->lr_row_map,
-                  picture_height_in_sb * sizeof(uint32_t),
-                  EB_N_PTR);
+    EB_MALLOC_DEC(
+        uint32_t *, dec_mt_frame_data->lr_row_map, picture_height_in_sb * sizeof(uint32_t));
 
     DecMtRowInfo *lr_sb_row_info = &dec_mt_frame_data->lr_sb_row_info;
 
@@ -340,12 +321,12 @@ EbErrorType dec_system_resource_init(EbDecHandle *dec_handle_ptr, TilesInfo *til
 
     dec_mt_frame_data->temp_mutex = svt_create_mutex();
 
-    dec_mt_frame_data->start_motion_proj  = EB_FALSE;
-    dec_mt_frame_data->start_parse_frame  = EB_FALSE;
-    dec_mt_frame_data->start_decode_frame = EB_FALSE;
-    dec_mt_frame_data->start_lf_frame     = EB_FALSE;
-    dec_mt_frame_data->start_cdef_frame   = EB_FALSE;
-    dec_mt_frame_data->start_lr_frame     = EB_FALSE;
+    dec_mt_frame_data->start_motion_proj  = FALSE;
+    dec_mt_frame_data->start_parse_frame  = FALSE;
+    dec_mt_frame_data->start_decode_frame = FALSE;
+    dec_mt_frame_data->start_lf_frame     = FALSE;
+    dec_mt_frame_data->start_cdef_frame   = FALSE;
+    dec_mt_frame_data->start_lr_frame     = FALSE;
     dec_mt_frame_data->num_threads_cdefed = 0;
     dec_mt_frame_data->num_threads_lred   = 0;
 
@@ -360,8 +341,7 @@ EbErrorType dec_system_resource_init(EbDecHandle *dec_handle_ptr, TilesInfo *til
        init_dec_mod_ctxt reallocated when required */
 
     DecModCtxt **dec_mod_ctxt_arr;
-    EB_MALLOC_DEC(
-        DecModCtxt **, dec_mod_ctxt_arr, num_lib_threads * sizeof(DecModCtxt *), EB_N_PTR);
+    EB_MALLOC_DEC(DecModCtxt **, dec_mod_ctxt_arr, num_lib_threads * sizeof(DecModCtxt *));
 
     for (uint32_t i = 0; i < num_lib_threads; i++) {
         init_dec_mod_ctxt(dec_handle_ptr, (void **)&dec_mod_ctxt_arr[i]);
@@ -369,14 +349,13 @@ EbErrorType dec_system_resource_init(EbDecHandle *dec_handle_ptr, TilesInfo *til
 
     memory_map_end_address = svt_dec_memory_map;
 
-    if (EB_FALSE == dec_handle_ptr->start_thread_process) {
-        dec_mt_frame_data->end_flag           = EB_FALSE;
+    if (FALSE == dec_handle_ptr->start_thread_process) {
+        dec_mt_frame_data->end_flag           = FALSE;
         dec_mt_frame_data->num_threads_exited = 0;
 
         if (num_lib_threads > 0) {
             DecThreadCtxt *thread_ctxt_pa;
-            EB_MALLOC_DEC(
-                DecThreadCtxt *, thread_ctxt_pa, num_lib_threads * sizeof(DecThreadCtxt), EB_N_PTR);
+            EB_MALLOC_DEC(DecThreadCtxt *, thread_ctxt_pa, num_lib_threads * sizeof(DecThreadCtxt));
             dec_handle_ptr->thread_ctxt_pa = thread_ctxt_pa;
             EB_CREATE_SEMAPHORE(dec_handle_ptr->thread_semaphore, 0, 100000);
 
@@ -385,13 +364,13 @@ EbErrorType dec_system_resource_init(EbDecHandle *dec_handle_ptr, TilesInfo *til
                 thread_ctxt_pa[i].dec_handle_ptr = dec_handle_ptr;
                 thread_ctxt_pa[i].dec_mod_ctxt   = dec_mod_ctxt_arr[i];
                 EB_CREATE_SEMAPHORE(thread_ctxt_pa[i].thread_semaphore, 0, 100000);
-                int use_highbd = (dec_handle_ptr->seq_header.color_config.bit_depth > EB_8BIT ||
+                int use_highbd = (dec_handle_ptr->seq_header.color_config.bit_depth >
+                                      EB_EIGHT_BIT ||
                                   dec_handle_ptr->is_16bit_pipeline);
                 EB_MALLOC_DEC(uint8_t *,
                               thread_ctxt_pa[i].dst,
                               (MAX_SB_SIZE + 8) * RESTORATION_PROC_UNIT_SIZE * sizeof(uint8_t)
-                                  << use_highbd,
-                              EB_N_PTR);
+                                  << use_highbd);
             }
             EB_CREATE_THREAD_ARRAY(dec_handle_ptr->decode_thread_handle_array,
                                    num_lib_threads,
@@ -447,15 +426,15 @@ void svt_av1_queue_parse_jobs(EbDecHandle *dec_handle_ptr, TilesInfo *tiles_info
 
     dec_mt_frame_data->parse_tile_info.sb_row_to_process = 0;
     dec_mt_frame_data->recon_tile_info.sb_row_to_process = 0;
-    //dec_handle_ptr->start_thread_process = EB_TRUE;
+    //dec_handle_ptr->start_thread_process = TRUE;
 }
 
 EbErrorType parse_tile_job(EbDecHandle *dec_handle_ptr, int32_t tile_num) {
     EbErrorType status = EB_ErrorNone;
 
-    TilesInfo *    tiles_info      = &dec_handle_ptr->frame_header.tiles_info;
+    TilesInfo     *tiles_info      = &dec_handle_ptr->frame_header.tiles_info;
     MainParseCtxt *main_parse_ctxt = (MainParseCtxt *)dec_handle_ptr->pv_main_parse_ctxt;
-    ParseCtxt *    parse_ctxt      = &main_parse_ctxt->tile_parse_ctxt[tile_num];
+    ParseCtxt     *parse_ctxt      = &main_parse_ctxt->tile_parse_ctxt[tile_num];
 
     parse_ctxt->seq_header   = &dec_handle_ptr->seq_header;
     parse_ctxt->frame_header = &dec_handle_ptr->frame_header;
@@ -471,14 +450,14 @@ EbErrorType parse_tile_job(EbDecHandle *dec_handle_ptr, int32_t tile_num) {
 void parse_frame_tiles(EbDecHandle *dec_handle_ptr, DecThreadCtxt *thread_ctxt) {
     DecMtFrameData *dec_mt_frame_data =
         &dec_handle_ptr->main_frame_buf.cur_frame_bufs[0].dec_mt_frame_data;
-    volatile EbBool *start_parse_frame = &dec_mt_frame_data->start_parse_frame;
+    volatile Bool *start_parse_frame = &dec_mt_frame_data->start_parse_frame;
 #if MT_WAIT_PROFILE
-    FILE *            fp = dec_mt_frame_data->fp;
+    FILE             *fp = dec_mt_frame_data->fp;
     struct EbDecTimer timer;
     int               th_cnt = NULL == thread_ctxt ? 0 : thread_ctxt->thread_cnt;
     dec_timer_start(&timer);
 #endif
-    while (*start_parse_frame != EB_TRUE)
+    while (*start_parse_frame != TRUE)
         svt_block_on_semaphore(NULL == thread_ctxt ? dec_handle_ptr->thread_semaphore
                                                    : thread_ctxt->thread_semaphore);
 
@@ -491,7 +470,7 @@ void parse_frame_tiles(EbDecHandle *dec_handle_ptr, DecThreadCtxt *thread_ctxt)
 #endif
         int32_t tile_num = get_sb_row_to_process(&dec_mt_frame_data->parse_tile_info);
         if (-1 != tile_num) {
-            dec_mt_frame_data->start_decode_frame = EB_TRUE;
+            dec_mt_frame_data->start_decode_frame = TRUE;
             if (EB_ErrorNone != parse_tile_job(dec_handle_ptr, tile_num)) {
                 SVT_LOG("\nParse Issue for Tile %d", tile_num);
                 break;
@@ -515,14 +494,14 @@ EbErrorType decode_tile_job(EbDecHandle *dec_handle_ptr, int32_t tile_num,
 void decode_frame_tiles(EbDecHandle *dec_handle_ptr, DecThreadCtxt *thread_ctxt) {
     DecMtFrameData *dec_mt_frame_data =
         &dec_handle_ptr->main_frame_buf.cur_frame_bufs[0].dec_mt_frame_data;
-    volatile EbBool *start_decode_frame = &dec_mt_frame_data->start_decode_frame;
+    volatile Bool *start_decode_frame = &dec_mt_frame_data->start_decode_frame;
 #if MT_WAIT_PROFILE
-    FILE *            fp = dec_mt_frame_data->fp;
+    FILE             *fp = dec_mt_frame_data->fp;
     struct EbDecTimer timer;
     int               th_cnt = NULL == thread_ctxt ? 0 : thread_ctxt->thread_cnt;
     dec_timer_start(&timer);
 #endif
-    while (*start_decode_frame != EB_TRUE)
+    while (*start_decode_frame != TRUE)
         svt_block_on_semaphore(NULL == thread_ctxt ? dec_handle_ptr->thread_semaphore
                                                    : thread_ctxt->thread_semaphore);
 
@@ -620,22 +599,22 @@ void svt_av1_queue_lf_jobs(EbDecHandle *dec_handle_ptr) {
     EB_MEMSET(dec_mt_frame_data->lf_row_map, 0, picture_height_in_sb * sizeof(uint32_t));
 
     memset(lf_frame_info->sb_lf_completed_in_row, -1, picture_height_in_sb * sizeof(int32_t));
-    lf_frame_info->lf_info_init_done                = EB_FALSE;
+    lf_frame_info->lf_info_init_done                = FALSE;
     lf_frame_info->lf_sb_row_info.sb_row_to_process = 0;
 }
 
 /* Store LF_boundary_line req for LR */
-static INLINE void dec_save_lf_boundary_lines_sb_row(EbDecHandle *  dec_handle,
+static INLINE void dec_save_lf_boundary_lines_sb_row(EbDecHandle   *dec_handle,
                                                      Av1PixelRect **tile_rect, int32_t sb_row,
                                                      uint8_t **src, int32_t *stride,
                                                      int32_t num_planes) {
     Av1Common *cm         = &dec_handle->cm;
     FrameSize *frame_size = &dec_handle->frame_header.frame_size;
-    EbBool     sb_128     = dec_handle->seq_header.sb_size == BLOCK_128X128;
+    Bool       sb_128     = dec_handle->seq_header.sb_size == BLOCK_128X128;
     int32_t    num64s     = sb_128 ? 1 : 0;
-    const int  use_highbd = (dec_handle->seq_header.color_config.bit_depth > EB_8BIT ||
+    const int  use_highbd = (dec_handle->seq_header.color_config.bit_depth > EB_EIGHT_BIT ||
                             dec_handle->is_16bit_pipeline);
-    LrCtxt *   lr_ctxt    = (LrCtxt *)dec_handle->pv_lr_ctxt;
+    LrCtxt    *lr_ctxt    = (LrCtxt *)dec_handle->pv_lr_ctxt;
     for (int32_t p = 0; p < num_planes; ++p) {
         int32_t                      ss_x          = p ? cm->subsampling_x : 0;
         int32_t                      ss_y          = p ? cm->subsampling_y : 0;
@@ -697,15 +676,15 @@ static INLINE void dec_save_lf_boundary_lines_sb_row(EbDecHandle *  dec_handle,
 }
 
 /* Store CDEF_boundary_line req for LR */
-static INLINE void dec_save_CDEF_boundary_lines_SB_row(EbDecHandle *  dec_handle,
+static INLINE void dec_save_CDEF_boundary_lines_SB_row(EbDecHandle   *dec_handle,
                                                        Av1PixelRect **tile_rect, int32_t sb_row,
                                                        uint8_t **src, int32_t *stride,
                                                        int32_t num_planes) {
-    Av1Common *     cm         = &dec_handle->cm;
-    FrameSize *     frame_size = &dec_handle->frame_header.frame_size;
-    const int       use_highbd = (dec_handle->seq_header.color_config.bit_depth > EB_8BIT ||
+    Av1Common      *cm         = &dec_handle->cm;
+    FrameSize      *frame_size = &dec_handle->frame_header.frame_size;
+    const int       use_highbd = (dec_handle->seq_header.color_config.bit_depth > EB_EIGHT_BIT ||
                             dec_handle->is_16bit_pipeline);
-    LrCtxt *        lr_ctxt    = (LrCtxt *)dec_handle->pv_lr_ctxt;
+    LrCtxt         *lr_ctxt    = (LrCtxt *)dec_handle->pv_lr_ctxt;
     DecMtFrameData *dec_mt_frame_data =
         &dec_handle->main_frame_buf.cur_frame_bufs[0].dec_mt_frame_data;
     for (int32_t p = 0; p < num_planes; ++p) {
@@ -757,14 +736,14 @@ void dec_av1_loop_filter_frame_mt(EbDecHandle *dec_handle, EbPictureBufferDesc *
     DecMtFrameData *dec_mt_frame_data1 =
         &dec_handle->main_frame_buf.cur_frame_bufs[0].dec_mt_frame_data;
 
-    volatile EbBool *start_lf_frame = &dec_mt_frame_data1->start_lf_frame;
+    volatile Bool *start_lf_frame = &dec_mt_frame_data1->start_lf_frame;
 #if MT_WAIT_PROFILE
-    FILE *            fp = dec_mt_frame_data1->fp;
+    FILE             *fp = dec_mt_frame_data1->fp;
     struct EbDecTimer timer;
     int               th_cnt = NULL == thread_ctxt ? 0 : thread_ctxt->thread_cnt;
     dec_timer_start(&timer);
 #endif
-    while (*start_lf_frame != EB_TRUE)
+    while (*start_lf_frame != TRUE)
         svt_block_on_semaphore(NULL == thread_ctxt ? dec_handle->thread_semaphore
                                                    : thread_ctxt->thread_semaphore);
 #if MT_WAIT_PROFILE
@@ -780,14 +759,14 @@ void dec_av1_loop_filter_frame_mt(EbDecHandle *dec_handle, EbPictureBufferDesc *
     //lock mutex
     svt_block_on_mutex(dec_mt_lf_frame_info->lf_sb_row_info.sbrow_mutex);
     //Check lf_info init done or not
-    if (dec_mt_lf_frame_info->lf_info_init_done == EB_FALSE) {
+    if (dec_mt_lf_frame_info->lf_info_init_done == FALSE) {
         /*init hev threshold const vectors*/
         for (int lvl = 0; lvl <= MAX_LOOP_FILTER; lvl++)
             memset(lf_ctxt->lf_info.lfthr[lvl].hev_thr, (lvl >> 4), SIMD_WIDTH);
 
         svt_av1_loop_filter_frame_init(frm_hdr, &lf_ctxt->lf_info, plane_start, plane_end);
 
-        dec_mt_lf_frame_info->lf_info_init_done = EB_TRUE;
+        dec_mt_lf_frame_info->lf_info_init_done = TRUE;
     }
     //unlock mutex
     svt_release_mutex(dec_mt_lf_frame_info->lf_sb_row_info.sbrow_mutex);
@@ -799,10 +778,10 @@ void dec_av1_loop_filter_frame_mt(EbDecHandle *dec_handle, EbPictureBufferDesc *
     // Get the tile rectangle, with height rounded up to the next multiple of 8
     // luma pixels (only relevant for the bottom tile of the frame)
     Av1PixelRect         tile_rect[MAX_MB_PLANE];
-    Av1PixelRect *       tile_rect_p[MAX_MB_PLANE];
+    Av1PixelRect        *tile_rect_p[MAX_MB_PLANE];
     const int            num_planes  = av1_num_planes(&dec_handle->seq_header.color_config);
     EbPictureBufferDesc *cur_pic_buf = dec_handle->cur_pic_buf[0]->ps_pic_buf;
-    uint8_t *            src[MAX_MB_PLANE];
+    uint8_t             *src[MAX_MB_PLANE];
     int32_t              stride[MAX_MB_PLANE];
     for (int p = 0; p < num_planes; ++p) {
         int32_t is_uv  = p ? 1 : 0;
@@ -905,18 +884,18 @@ void svt_av1_queue_cdef_jobs(EbDecHandle *dec_handle_ptr) {
 }
 
 void svt_cdef_frame_mt(EbDecHandle *dec_handle_ptr, DecThreadCtxt *thread_ctxt) {
-    uint8_t *       curr_blk_recon_buf[MAX_MB_PLANE];
+    uint8_t        *curr_blk_recon_buf[MAX_MB_PLANE];
     int32_t         curr_recon_stride[MAX_MB_PLANE];
     DecMtFrameData *dec_mt_frame_data1 =
         &dec_handle_ptr->main_frame_buf.cur_frame_bufs[0].dec_mt_frame_data;
-    volatile EbBool *start_cdef_frame = &dec_mt_frame_data1->start_cdef_frame;
+    volatile Bool *start_cdef_frame = &dec_mt_frame_data1->start_cdef_frame;
 #if MT_WAIT_PROFILE
-    FILE *            fp = dec_mt_frame_data1->fp;
+    FILE             *fp = dec_mt_frame_data1->fp;
     struct EbDecTimer timer;
     int               th_cnt = NULL == thread_ctxt ? 0 : thread_ctxt->thread_cnt;
     dec_timer_start(&timer);
 #endif
-    while (*start_cdef_frame != EB_TRUE)
+    while (*start_cdef_frame != TRUE)
         svt_block_on_semaphore(NULL == thread_ctxt ? dec_handle_ptr->thread_semaphore
                                                    : thread_ctxt->thread_semaphore);
 
@@ -934,10 +913,10 @@ void svt_cdef_frame_mt(EbDecHandle *dec_handle_ptr, DecThreadCtxt *thread_ctxt)
     Av1PixelRect  tile_rect[MAX_MB_PLANE];
     Av1PixelRect *tile_rect_p[MAX_MB_PLANE];
 
-    EbBool no_ibc      = !dec_handle_ptr->frame_header.allow_intrabc;
-    EbBool do_upscale  = no_ibc && !av1_superres_unscaled(&dec_handle_ptr->frame_header.frame_size);
+    Bool no_ibc        = !dec_handle_ptr->frame_header.allow_intrabc;
+    Bool do_upscale    = no_ibc && !av1_superres_unscaled(&dec_handle_ptr->frame_header.frame_size);
     LrParams *lr_param = dec_handle_ptr->frame_header.lr_params;
-    EbBool    do_lr    = no_ibc &&
+    Bool      do_lr    = no_ibc &&
         (lr_param[AOM_PLANE_Y].frame_restoration_type != RESTORE_NONE ||
          lr_param[AOM_PLANE_U].frame_restoration_type != RESTORE_NONE ||
          lr_param[AOM_PLANE_V].frame_restoration_type != RESTORE_NONE);
@@ -1155,8 +1134,8 @@ void dec_av1_loop_restoration_filter_frame_mt(EbDecHandle *dec_handle, DecThread
 
     DecMtFrameData *dec_mt_frame_data =
         &dec_handle->main_frame_buf.cur_frame_bufs[0].dec_mt_frame_data;
-    volatile EbBool *start_lr_frame = &dec_mt_frame_data->start_lr_frame;
-    while (*start_lr_frame != EB_TRUE)
+    volatile Bool *start_lr_frame = &dec_mt_frame_data->start_lr_frame;
+    while (*start_lr_frame != TRUE)
         svt_block_on_semaphore(NULL == thread_ctxt ? dec_handle->thread_semaphore
                                                    : thread_ctxt->thread_semaphore);
 
@@ -1198,7 +1177,7 @@ void dec_av1_loop_restoration_filter_frame_mt(EbDecHandle *dec_handle, DecThread
     uint32_t pad_height = recon_picture_buf->origin_y;
 
     int32_t shift = 0;
-    if ((recon_picture_buf->bit_depth != EB_8BIT) || recon_picture_buf->is_16bit_pipeline)
+    if ((recon_picture_buf->bit_depth != EB_EIGHT_BIT) || recon_picture_buf->is_16bit_pipeline)
         shift = 1;
 
     int32_t recon_stride[MAX_MB_PLANE];
@@ -1208,14 +1187,14 @@ void dec_av1_loop_restoration_filter_frame_mt(EbDecHandle *dec_handle, DecThread
 
     FrameHeader *frame_header = &dec_handle->frame_header;
 
-    EbBool    no_ibc   = !frame_header->allow_intrabc;
+    Bool      no_ibc   = !frame_header->allow_intrabc;
     LrParams *lr_param = frame_header->lr_params;
-    EbBool    do_lr    = no_ibc &&
+    Bool      do_lr    = no_ibc &&
         (lr_param[AOM_PLANE_Y].frame_restoration_type != RESTORE_NONE ||
          lr_param[AOM_PLANE_U].frame_restoration_type != RESTORE_NONE ||
          lr_param[AOM_PLANE_V].frame_restoration_type != RESTORE_NONE);
-    EbBool do_upscale = no_ibc && !av1_superres_unscaled(&dec_handle->frame_header.frame_size);
-    int    th_cnt     = NULL == thread_ctxt ? 0 : thread_ctxt->thread_cnt;
+    Bool do_upscale = no_ibc && !av1_superres_unscaled(&dec_handle->frame_header.frame_size);
+    int  th_cnt     = NULL == thread_ctxt ? 0 : thread_ctxt->thread_cnt;
     while (1) {
         int32_t sb_row = get_sb_row_to_process(&dec_mt_frame_data->lr_sb_row_info);
         if (-1 != sb_row) {
@@ -1290,29 +1269,29 @@ void dec_av1_loop_restoration_filter_frame_mt(EbDecHandle *dec_handle, DecThread
     svt_block_on_mutex(dec_mt_frame_data->temp_mutex);
     dec_mt_frame_data->num_threads_lred++;
     if (dec_handle->dec_config.threads == dec_mt_frame_data->num_threads_lred) {
-        dec_mt_frame_data->start_motion_proj  = EB_FALSE;
-        dec_mt_frame_data->start_parse_frame  = EB_FALSE;
-        dec_mt_frame_data->start_decode_frame = EB_FALSE;
-        dec_mt_frame_data->start_lf_frame     = EB_FALSE;
-        dec_mt_frame_data->start_cdef_frame   = EB_FALSE;
-        dec_mt_frame_data->start_lr_frame     = EB_FALSE;
+        dec_mt_frame_data->start_motion_proj  = FALSE;
+        dec_mt_frame_data->start_parse_frame  = FALSE;
+        dec_mt_frame_data->start_decode_frame = FALSE;
+        dec_mt_frame_data->start_lf_frame     = FALSE;
+        dec_mt_frame_data->start_cdef_frame   = FALSE;
+        dec_mt_frame_data->start_lr_frame     = FALSE;
     }
     svt_release_mutex(dec_mt_frame_data->temp_mutex);
 
     volatile uint32_t *num_threads_lred = &dec_mt_frame_data->num_threads_lred;
     while (*num_threads_lred != dec_handle->dec_config.threads &&
-           EB_FALSE == dec_mt_frame_data->end_flag)
+           FALSE == dec_mt_frame_data->end_flag)
         ;
 }
 
 void *dec_all_stage_kernel(void *input_ptr) {
     // Context
-    DecThreadCtxt * thread_ctxt    = (DecThreadCtxt *)input_ptr;
-    EbDecHandle *   dec_handle_ptr = thread_ctxt->dec_handle_ptr;
+    DecThreadCtxt  *thread_ctxt    = (DecThreadCtxt *)input_ptr;
+    EbDecHandle    *dec_handle_ptr = thread_ctxt->dec_handle_ptr;
     DecMtFrameData *dec_mt_frame_data =
         &dec_handle_ptr->main_frame_buf.cur_frame_bufs[0].dec_mt_frame_data;
-    volatile EbBool *start_thread = (volatile EbBool *)&dec_handle_ptr->start_thread_process;
-    while (*start_thread == EB_FALSE)
+    volatile Bool *start_thread = (volatile Bool *)&dec_handle_ptr->start_thread_process;
+    while (*start_thread == FALSE)
         ;
 
     while (1) {
@@ -1334,7 +1313,7 @@ void *dec_all_stage_kernel(void *input_ptr) {
         /*Frame LR */
         dec_av1_loop_restoration_filter_frame_mt(dec_handle_ptr, thread_ctxt);
 
-        if (EB_TRUE == dec_mt_frame_data->end_flag) {
+        if (TRUE == dec_mt_frame_data->end_flag) {
             svt_block_on_mutex(dec_mt_frame_data->temp_mutex);
             dec_mt_frame_data->num_threads_exited++;
             svt_release_mutex(dec_mt_frame_data->temp_mutex);
@@ -1357,7 +1336,7 @@ static void svt_av1_sleep(const int milliseconds) {
 void dec_sync_all_threads(EbDecHandle *dec_handle_ptr) {
     DecMtFrameData *dec_mt_frame_data =
         &dec_handle_ptr->main_frame_buf.cur_frame_bufs[0].dec_mt_frame_data;
-    dec_mt_frame_data->end_flag = EB_TRUE;
+    dec_mt_frame_data->end_flag = TRUE;
 
     /* To make all worker exit except main thread! */
     dec_mt_frame_data->num_threads_cdefed = 1;
@@ -1366,25 +1345,25 @@ void dec_sync_all_threads(EbDecHandle *dec_handle_ptr) {
     /* To make all worker exit except main thread! */
     dec_mt_frame_data->num_threads_header          = 1;
     dec_handle_ptr->frame_header.use_ref_frame_mvs = 0;
-    dec_mt_frame_data->start_motion_proj           = EB_TRUE;
+    dec_mt_frame_data->start_motion_proj           = TRUE;
 
-    dec_mt_frame_data->start_parse_frame = EB_TRUE;
+    dec_mt_frame_data->start_parse_frame = TRUE;
     svt_post_semaphore(dec_handle_ptr->thread_semaphore);
     for (uint32_t lib_thrd = 0; lib_thrd < dec_handle_ptr->dec_config.threads - 1; lib_thrd++)
         svt_post_semaphore(dec_handle_ptr->thread_ctxt_pa[lib_thrd].thread_semaphore);
-    dec_mt_frame_data->start_decode_frame = EB_TRUE;
+    dec_mt_frame_data->start_decode_frame = TRUE;
     svt_post_semaphore(dec_handle_ptr->thread_semaphore);
     for (uint32_t lib_thrd = 0; lib_thrd < dec_handle_ptr->dec_config.threads - 1; lib_thrd++)
         svt_post_semaphore(dec_handle_ptr->thread_ctxt_pa[lib_thrd].thread_semaphore);
-    dec_mt_frame_data->start_lf_frame = EB_TRUE;
+    dec_mt_frame_data->start_lf_frame = TRUE;
     svt_post_semaphore(dec_handle_ptr->thread_semaphore);
     for (uint32_t lib_thrd = 0; lib_thrd < dec_handle_ptr->dec_config.threads - 1; lib_thrd++)
         svt_post_semaphore(dec_handle_ptr->thread_ctxt_pa[lib_thrd].thread_semaphore);
-    dec_mt_frame_data->start_cdef_frame = EB_TRUE;
+    dec_mt_frame_data->start_cdef_frame = TRUE;
     svt_post_semaphore(dec_handle_ptr->thread_semaphore);
     for (uint32_t lib_thrd = 0; lib_thrd < dec_handle_ptr->dec_config.threads - 1; lib_thrd++)
         svt_post_semaphore(dec_handle_ptr->thread_ctxt_pa[lib_thrd].thread_semaphore);
-    dec_mt_frame_data->start_lr_frame = EB_TRUE;
+    dec_mt_frame_data->start_lr_frame = TRUE;
     svt_post_semaphore(dec_handle_ptr->thread_semaphore);
     for (uint32_t lib_thrd = 0; lib_thrd < dec_handle_ptr->dec_config.threads - 1; lib_thrd++)
         svt_post_semaphore(dec_handle_ptr->thread_ctxt_pa[lib_thrd].thread_semaphore);
