@@ -122,7 +122,7 @@ void lr_pad_pic(EbPictureBufferDesc *recon_picture_buf, FrameHeader *frame_hdr,
     uint8_t    sx         = color_cfg->subsampling_x;
     uint8_t    sy         = color_cfg->subsampling_y;
 
-    if (recon_picture_buf->bit_depth == EB_8BIT && (!recon_picture_buf->is_16bit_pipeline)) {
+    if (recon_picture_buf->bit_depth == EB_EIGHT_BIT && (!recon_picture_buf->is_16bit_pipeline)) {
         // Y samples
         lr_generate_padding(recon_picture_buf->buffer_y + recon_picture_buf->origin_x +
                                 recon_picture_buf->stride_y * recon_picture_buf->origin_y,
@@ -281,19 +281,19 @@ void dec_av1_loop_restoration_filter_row(EbDecHandle *dec_handle, int32_t sb_row
                                          Av1PixelRect *tile_rect, int optimized_lr, uint8_t *dst,
                                          int thread_cnt) {
     RestorationTileLimits tile_limit;
-    RestorationUnitInfo * lr_unit;
-    LrCtxt *              lr_ctxt    = (LrCtxt *)dec_handle->pv_lr_ctxt;
+    RestorationUnitInfo  *lr_unit;
+    LrCtxt               *lr_ctxt    = (LrCtxt *)dec_handle->pv_lr_ctxt;
     const int32_t         num_planes = av1_num_planes(&dec_handle->seq_header.color_config);
     int                   bit_depth  = dec_handle->seq_header.color_config.bit_depth;
-    int                   use_highbd = (bit_depth > EB_8BIT || dec_handle->is_16bit_pipeline);
+    int                   use_highbd = (bit_depth > EB_EIGHT_BIT || dec_handle->is_16bit_pipeline);
     int                   w_y = 0, tile_stripe0 = 0;
     int                   tile_w_y   = tile_rect[AOM_PLANE_Y].right - tile_rect[AOM_PLANE_Y].left;
     int                   tile_h_y   = tile_rect[AOM_PLANE_Y].bottom - tile_rect[AOM_PLANE_Y].top;
     uint8_t               dst_stride = RESTORATION_PROC_UNIT_SIZE;
 
     volatile int32_t *sb_lr_completed_in_prev_row = NULL;
-    int32_t *         sb_lr_completed_in_row, nsync = 1;
-    EbBool            is_mt = dec_handle->dec_config.threads > 1;
+    int32_t          *sb_lr_completed_in_row, nsync = 1;
+    Bool              is_mt = dec_handle->dec_config.threads > 1;
 
     int32_t sb_row_idx = (is_mt == 0) ? 0 : sb_row;
     int32_t index      = lr_ctxt->is_thread_min ? thread_cnt : sb_row_idx;
@@ -477,7 +477,7 @@ void dec_av1_loop_restoration_filter_frame(EbDecHandle *dec_handle, int optimize
 
     assert(!dec_handle->frame_header.all_lossless);
     int32_t      y, sb_row;
-    uint8_t *    curr_blk_recon_buf[MAX_MB_PLANE];
+    uint8_t     *curr_blk_recon_buf[MAX_MB_PLANE];
     int32_t      curr_recon_stride[MAX_MB_PLANE];
     Av1PixelRect tile_rect[MAX_MB_PLANE];
 
@@ -486,7 +486,7 @@ void dec_av1_loop_restoration_filter_frame(EbDecHandle *dec_handle, int optimize
 
     lr_pad_pic(recon_picture_ptr, &dec_handle->frame_header, &dec_handle->seq_header.color_config);
 
-    LrCtxt * lr_ctxt = (LrCtxt *)dec_handle->pv_lr_ctxt;
+    LrCtxt  *lr_ctxt = (LrCtxt *)dec_handle->pv_lr_ctxt;
     uint8_t *dst     = lr_ctxt->dst;
 
     for (int32_t pli = 0; pli < num_planes; pli++) {
@@ -524,14 +524,14 @@ void dec_av1_loop_restoration_filter_frame(EbDecHandle *dec_handle, int optimize
 
 void dec_av1_loop_restoration_save_boundary_lines(EbDecHandle *dec_handle, int after_cdef) {
     const int num_planes = av1_num_planes(&dec_handle->seq_header.color_config);
-    const int use_highbd = (dec_handle->seq_header.color_config.bit_depth > EB_8BIT ||
+    const int use_highbd = (dec_handle->seq_header.color_config.bit_depth > EB_EIGHT_BIT ||
                             dec_handle->is_16bit_pipeline);
 
     for (int p = 0; p < num_planes; ++p) {
-        LrCtxt *   lr_ctxt    = (LrCtxt *)dec_handle->pv_lr_ctxt;
+        LrCtxt    *lr_ctxt    = (LrCtxt *)dec_handle->pv_lr_ctxt;
         FrameSize *frame_size = &dec_handle->frame_header.frame_size;
         int32_t    sx = 0, sy = 0;
-        uint8_t *  src;
+        uint8_t   *src;
         int32_t    stride;
         if (p) {
             sx = dec_handle->seq_header.color_config.subsampling_x;
