@@ -209,7 +209,7 @@ static INLINE const InterpFilterParams *av1_get_filter(int subpel_search) {
 }
 
 // Get pred block from up-sampled reference.
-void svt_aom_upsampled_pred_c(MacroBlockD *                 xd,
+void svt_aom_upsampled_pred_c(MacroBlockD                  *xd,
                               const struct AV1Common *const cm, //const AV1_COMMON *const cm,
                               int mi_row, int mi_col, const MV *const mv, uint8_t *comp_pred,
                               int width, int height, int subpel_x_q3, int subpel_y_q3,
@@ -270,7 +270,7 @@ void svt_aom_upsampled_pred_c(MacroBlockD *                 xd,
 // functions are from deleted file, associated with this macro
 // Moved from EbComputeVariance_C.c
 static void variance_c(const uint8_t *a, int a_stride, const uint8_t *b, int b_stride, int w, int h,
-    uint32_t *sse, int *sum) {
+                       uint32_t *sse, int *sum) {
     int i, j;
 
     *sum = 0;
@@ -291,11 +291,11 @@ static void variance_c(const uint8_t *a, int a_stride, const uint8_t *b, int b_s
 // Moved from EbComputeVariance_C.c
 // TODO: use or implement a simd version of this
 uint32_t variance_highbd_c(const uint16_t *a, int a_stride, const uint16_t *b, int b_stride, int w,
-    int h, uint32_t *sse) {
+                           int h, uint32_t *sse) {
     int i, j;
 
     int sad = 0;
-    *sse = 0;
+    *sse    = 0;
 
     for (i = 0; i < h; ++i) {
         for (j = 0; j < w; ++j) {
@@ -308,7 +308,7 @@ uint32_t variance_highbd_c(const uint16_t *a, int a_stride, const uint16_t *b, i
         b += b_stride;
     }
 
-    return *sse - (sad * sad) / (w * h);
+    return *sse - ((int64_t)sad * sad) / (w * h);
 }
 
 // Moved from EbComputeVariance_C.c
@@ -321,24 +321,28 @@ uint32_t variance_highbd_c(const uint16_t *a, int a_stride, const uint16_t *b, i
     }
 
 #define SUBPIX_VAR(W, H)                                                      \
-  uint32_t svt_aom_sub_pixel_variance##W##x##H##_c(                               \
-      const uint8_t *a, int a_stride, int xoffset, int yoffset,               \
-      const uint8_t *b, int b_stride, uint32_t *sse) {                        \
-    uint16_t fdata3[(H + 1) * W];                                             \
-    uint8_t temp2[H * W];                                                     \
+    uint32_t svt_aom_sub_pixel_variance##W##x##H##_c(const uint8_t *a,        \
+                                                     int            a_stride, \
+                                                     int            xoffset,  \
+                                                     int            yoffset,  \
+                                                     const uint8_t *b,        \
+                                                     int            b_stride, \
+                                                     uint32_t      *sse) {         \
+        uint16_t fdata3[(H + 1) * W];                                         \
+        uint8_t  temp2[H * W];                                                \
                                                                               \
-    aom_var_filter_block2d_bil_first_pass_c(a, fdata3, a_stride, 1, H + 1, W, \
-                                            bilinear_filters_2t[xoffset]);    \
-    aom_var_filter_block2d_bil_second_pass_c(fdata3, temp2, W, W, H, W,       \
-                                             bilinear_filters_2t[yoffset]);   \
+        aom_var_filter_block2d_bil_first_pass_c(                              \
+            a, fdata3, a_stride, 1, H + 1, W, bilinear_filters_2t[xoffset]);  \
+        aom_var_filter_block2d_bil_second_pass_c(                             \
+            fdata3, temp2, W, W, H, W, bilinear_filters_2t[yoffset]);         \
                                                                               \
-    return svt_aom_variance##W##x##H##_c(temp2, W, b, b_stride, sse);          \
-  }
+        return svt_aom_variance##W##x##H##_c(temp2, W, b, b_stride, sse);     \
+    }
 
 /* All the variance are available in the same sizes. */
 #define VARIANCES(W, H) \
-  VAR(W, H)             \
-  SUBPIX_VAR(W, H)
+    VAR(W, H)           \
+    SUBPIX_VAR(W, H)
 VARIANCES(128, 128)
 VARIANCES(128, 64)
 VARIANCES(64, 128)
@@ -355,15 +359,13 @@ VARIANCES(8, 8)
 VARIANCES(8, 4)
 VARIANCES(4, 8)
 VARIANCES(4, 4)
-VARIANCES(4, 2)
-VARIANCES(2, 4)
-VARIANCES(2, 2)
 VARIANCES(4, 16)
 VARIANCES(16, 4)
 VARIANCES(8, 32)
 VARIANCES(32, 8)
 VARIANCES(16, 64)
 VARIANCES(64, 16)
+
 static INLINE void obmc_variance(const uint8_t *pre, int pre_stride, const int32_t *wsrc,
                                  const int32_t *mask, int w, int h, unsigned int *sse, int *sum) {
     int i, j;
@@ -389,7 +391,7 @@ static INLINE void obmc_variance(const uint8_t *pre, int pre_stride, const int32
                                                     int            pre_stride, \
                                                     const int32_t *wsrc,       \
                                                     const int32_t *mask,       \
-                                                    unsigned int * sse) {       \
+                                                    unsigned int  *sse) {       \
         int sum;                                                               \
         obmc_variance(pre, pre_stride, wsrc, mask, W, H, sse, &sum);           \
         return *sse - (unsigned int)(((int64_t)sum * sum) / (W * H));          \
@@ -402,7 +404,7 @@ static INLINE void obmc_variance(const uint8_t *pre, int pre_stride, const int32
                                                               int            yoffset,    \
                                                               const int32_t *wsrc,       \
                                                               const int32_t *mask,       \
-                                                              unsigned int * sse) {       \
+                                                              unsigned int  *sse) {       \
         uint16_t fdata3[(H + 1) * W];                                                    \
         uint8_t  temp2[H * W];                                                           \
                                                                                          \
