@@ -19,51 +19,11 @@
 #include "EbCommonUtils.h"
 #include "EbEntropyCoding.h"
 #include "EbInterPrediction.h"
+#include "aom_dsp_rtcd.h"
 
 int svt_av1_allow_palette(int allow_palette, BlockSize sb_type);
 #define UNUSED_FUNC
 
-/** ScaleMV
-        is used to scale the motion vector in AMVP process.
- */
-/*
-static inline void scale_mv(
-    uint64_t    current_pic_poc,                // Iuput parameter, the POC of the current picture to be encoded.
-    uint64_t    target_ref_pic_poc,              // Iuput parameter, the POC of the reference picture where the inter coding is searching for.
-    uint64_t    col_pu_pic_poc,                  // Iuput parameter, the POC of picture where the co-located PU is.
-    uint64_t    col_pu_ref_pic_poc,               // Iuput parameter, the POC of the reference picture where the MV of the co-located PU points to.
-    int16_t    *mvx,                          // Output parameter,
-    int16_t    *mvy)                          // Output parameter,
-{
-    int16_t td = (int16_t)(col_pu_pic_poc - col_pu_ref_pic_poc);
-    int16_t tb = (int16_t)(current_pic_poc - target_ref_pic_poc);
-    int16_t scale_factor;
-    int16_t temp;
-
-    if (td != tb) {
-        tb = CLIP3(-128, 127, tb);
-        td = CLIP3(-128, 127, td);
-        temp = (int16_t)((0x4000 + ABS(td >> 1)) / td);
-        scale_factor = CLIP3(-4096, 4095, (tb * temp + 32) >> 6);
-
-        *mvx = CLIP3(-32768, 32767, (scale_factor * (*mvx) + 127 + (scale_factor * (*mvx) < 0)) >> 8);
-        *mvy = CLIP3(-32768, 32767, (scale_factor * (*mvy) + 127 + (scale_factor * (*mvy) < 0)) >> 8);
-    }
-
-    return;
-}
-*/
-static PartitionType from_shape_to_part[] = {PARTITION_NONE,
-                                             PARTITION_HORZ,
-                                             PARTITION_VERT,
-                                             PARTITION_HORZ_A,
-                                             PARTITION_HORZ_B,
-                                             PARTITION_VERT_A,
-                                             PARTITION_VERT_B,
-                                             PARTITION_HORZ_4,
-                                             PARTITION_VERT_4,
-                                             PARTITION_SPLIT};
-
 #define MVREF_ROWS 3
 #define MVREF_COLS 3
 
@@ -102,7 +62,7 @@ static INLINE void clamp_mv_ref(MV *mv, int32_t bw, int32_t bh, const MacroBlock
 static void add_ref_mv_candidate(const ModeInfo *const   candidate_mi,
                                  const MbModeInfo *const candidate, const MvReferenceFrame rf[2],
                                  uint8_t *refmv_count, uint8_t *ref_match_count,
-                                 uint8_t *   newmv_count,
+                                 uint8_t    *newmv_count,
                                  CandidateMv ref_mv_stack[MAX_REF_MV_STACK_SIZE], int32_t len,
                                  IntMv *gm_mv_candidates, const EbWarpedMotionParams *gm_params,
                                  int32_t col, int32_t weight) {
@@ -111,7 +71,6 @@ static void add_ref_mv_candidate(const ModeInfo *const   candidate_mi,
     assert(weight % 2 == 0);
 
     if (rf[1] == NONE_FRAME) {
-
         // single reference frame
         for (int32_t ref = 0; ref < 2; ++ref) {
             if (candidate->block_mi.ref_frame[ref] == rf[0]) {
@@ -140,7 +99,6 @@ static void add_ref_mv_candidate(const ModeInfo *const   candidate_mi,
             }
         }
     } else {
-
         // compound reference frame
         if (candidate->block_mi.ref_frame[0] == rf[0] &&
             candidate->block_mi.ref_frame[1] == rf[1]) {
@@ -298,8 +256,7 @@ static void scan_blk_mbmi(const MacroBlockD *xd, const int32_t mi_row, const int
                           const MvReferenceFrame rf[2], int32_t row_offset, int32_t col_offset,
                           CandidateMv ref_mv_stack[MAX_REF_MV_STACK_SIZE], uint8_t *ref_match_count,
                           uint8_t *newmv_count, IntMv *gm_mv_candidates,
-                          const EbWarpedMotionParams *gm_params,
-                          uint8_t *refmv_count) {
+                          const EbWarpedMotionParams *gm_params, uint8_t *refmv_count) {
     const TileInfo *const tile   = &xd->tile;
     Position              mi_pos = {row_offset, col_offset};
 
@@ -720,11 +677,7 @@ void setup_ref_mv_list(PictureControlSet *pcs_ptr, const Av1Common *cm, const Ma
                        int16_t *mode_context) {
     const int32_t bs     = AOMMAX(xd->n8_w, xd->n8_h);
     const int32_t has_tr = has_top_right(
-        ((SequenceControlSet *)pcs_ptr->scs_wrapper_ptr->object_ptr)->seq_header.sb_size,
-        xd,
-        mi_row,
-        mi_col,
-        bs);
+        pcs_ptr->scs_ptr->seq_header.sb_size, xd, mi_row, mi_col, bs);
     const TileInfo *const tile           = &xd->tile;
     int32_t               max_row_offset = 0, max_col_offset = 0;
     const int32_t         row_adj        = (xd->n8_h < mi_size_high[BLOCK_8X8]) && (mi_row & 0x01);
@@ -1118,8 +1071,8 @@ void init_xd(PictureControlSet *pcs_ptr, ModeDecisionContext *context_ptr) {
 
     int32_t       mi_row = context_ptr->blk_origin_y >> MI_SIZE_LOG2;
     int32_t       mi_col = context_ptr->blk_origin_x >> MI_SIZE_LOG2;
-    Av1Common *   cm     = pcs_ptr->parent_pcs_ptr->av1_cm;
-    MacroBlockD * xd     = context_ptr->blk_ptr->av1xd;
+    Av1Common    *cm     = pcs_ptr->parent_pcs_ptr->av1_cm;
+    MacroBlockD  *xd     = context_ptr->blk_ptr->av1xd;
     BlockSize     bsize  = context_ptr->blk_geom->bsize;
     const int32_t bw     = mi_size_wide[bsize];
     const int32_t bh     = mi_size_high[bsize];
@@ -1163,7 +1116,7 @@ void init_xd(PictureControlSet *pcs_ptr, ModeDecisionContext *context_ptr) {
             (xd->mi_stride >> pcs_ptr->disallow_4x4_all_frames) +
         (mi_col >> pcs_ptr->disallow_4x4_all_frames);
     pcs_ptr->mi_grid_base[offset] = pcs_ptr->mip + mip_offset;
-    xd->mi = pcs_ptr->mi_grid_base + offset;
+    xd->mi                        = pcs_ptr->mi_grid_base + offset;
 
     //ModeInfo *mi_ptr = xd->mi[-(xd->mi_stride)]; /*&xd->mi[-xd->mi_stride]->mbmi*/
     xd->above_mbmi = (xd->up_available) ? &xd->mi[-(xd->mi_stride)]->mbmi : NULL;
@@ -1208,7 +1161,7 @@ void generate_av1_mvp_table(ModeDecisionContext *context_ptr, BlkStruct *blk_ptr
                             PictureControlSet *pcs_ptr) {
     int32_t      mi_row  = blk_origin_y >> MI_SIZE_LOG2;
     int32_t      mi_col  = blk_origin_x >> MI_SIZE_LOG2;
-    Av1Common *  cm      = pcs_ptr->parent_pcs_ptr->av1_cm;
+    Av1Common   *cm      = pcs_ptr->parent_pcs_ptr->av1_cm;
     FrameHeader *frm_hdr = &pcs_ptr->parent_pcs_ptr->frm_hdr;
     MacroBlockD *xd      = blk_ptr->av1xd;
     BlockSize    bsize   = blk_geom->bsize;
@@ -1216,7 +1169,8 @@ void generate_av1_mvp_table(ModeDecisionContext *context_ptr, BlkStruct *blk_ptr
     uint8_t symteric_refs = 0;
     IntMv   mv_ref0[64];
     if (pcs_ptr->temporal_layer_index > 0)
-        if (pcs_ptr->parent_pcs_ptr->scs_ptr->static_config.pred_structure == EB_PRED_RANDOM_ACCESS)
+        if (pcs_ptr->parent_pcs_ptr->scs_ptr->static_config.pred_structure ==
+            SVT_AV1_PRED_RANDOM_ACCESS)
             if (tot_refs == 3 && ref_frames[0] == LAST_FRAME && ref_frames[1] == BWDREF_FRAME &&
                 ref_frames[2] == LAST_BWD_FRAME)
                 symteric_refs = 1;
@@ -1240,8 +1194,8 @@ void generate_av1_mvp_table(ModeDecisionContext *context_ptr, BlkStruct *blk_ptr
         // If block is intra bordered we only inject NEW unipred, so must generate MVPs
         // If there is only 1 ME candidate, generate MVPs because that candidate will be injected (even if unipred)
         if (context_ptr->cand_reduction_ctrls.reduce_unipred_candidates >= 3 &&
-            context_ptr->lpd1_ctrls.pd1_level > REGULAR_PD1 &&
-            !context_ptr->is_intra_bordered && frm_hdr->reference_mode != SINGLE_REFERENCE &&
+            context_ptr->lpd1_ctrls.pd1_level > REGULAR_PD1 && !context_ptr->is_intra_bordered &&
+            frm_hdr->reference_mode != SINGLE_REFERENCE &&
             !frm_hdr
                  ->use_ref_frame_mvs && //MFMV generation re-uses projection information when symetric references are used.
             //so could not be skipped, as BWD or LAST_BWD might reuse projection info from LAST
@@ -1372,20 +1326,20 @@ void get_av1_mv_pred_drl(ModeDecisionContext *context_ptr, BlkStruct *blk_ptr,
 void update_mi_map_enc_dec(BlkStruct *blk_ptr, ModeDecisionContext *md_ctx) {
     // Update only the data in the top left block of the partition, because all other mi_blocks
     // point to the top left mi block of the partition
-    blk_ptr->av1xd->mi[0]->mbmi.block_mi.skip      = blk_ptr->block_has_coeff ? EB_FALSE : EB_TRUE;
-    blk_ptr->av1xd->mi[0]->mbmi.block_mi.skip_mode = (int8_t)blk_ptr->skip_flag;
+    blk_ptr->av1xd->mi[0]->mbmi.block_mi.skip      = blk_ptr->block_has_coeff ? FALSE : TRUE;
+    blk_ptr->av1xd->mi[0]->mbmi.block_mi.skip_mode = (int8_t)blk_ptr->skip_mode;
 
     // update palette_colors mi map when input bit depth is 10bit and hbd mode decision is 0 (8bit MD)
     // palette_colors were scaled to 10bit in av1_encode_decode so here we need to update mi map for entropy coding
-    if (md_ctx->encoder_bit_depth > EB_8BIT && md_ctx->hbd_mode_decision == 0)
+    if (md_ctx->encoder_bit_depth > EB_EIGHT_BIT && md_ctx->hbd_mode_decision == 0)
         if (blk_ptr->av1xd->mi[0]->mbmi.palette_mode_info.palette_size)
             svt_memcpy(blk_ptr->av1xd->mi[0]->mbmi.palette_mode_info.palette_colors,
                        blk_ptr->palette_info->pmi.palette_colors,
                        sizeof(blk_ptr->av1xd->mi[0]->mbmi.palette_mode_info.palette_colors[0]) *
                            PALETTE_MAX_SIZE);
 }
-void copy_mi_map_grid(ModeInfo **mi_grid_ptr, uint32_t mi_stride, uint8_t num_rows,
-                      uint8_t num_cols) {
+void svt_copy_mi_map_grid_c(ModeInfo **mi_grid_ptr, uint32_t mi_stride, uint8_t num_rows,
+                            uint8_t num_cols) {
     ModeInfo *target = mi_grid_ptr[0];
     if (num_cols == 1) {
         for (uint8_t mi_y = 0; mi_y < num_rows; mi_y++) {
@@ -1435,11 +1389,11 @@ void update_mi_map(BlkStruct *blk_ptr, uint32_t blk_origin_x, uint32_t blk_origi
 
     ModeInfo *mi_ptr = *(pcs_ptr->mi_grid_base + offset);
     // use idx 0 as that's the first mbmmi in the block
-    MbModeInfo *      mbmi     = &mi_ptr[0].mbmi;
+    MbModeInfo       *mbmi     = &mi_ptr[0].mbmi;
     BlockModeInfoEnc *block_mi = &mi_ptr[0].mbmi.block_mi;
 
     // copy mbmi data
-    block_mi->tx_depth = blk_ptr->tx_depth;
+    block_mi->tx_depth       = blk_ptr->tx_depth;
     block_mi->comp_group_idx = blk_ptr->comp_group_idx;
     if (svt_av1_allow_palette(pcs_ptr->parent_pcs_ptr->palette_level, blk_geom->bsize)) {
         mbmi->palette_mode_info.palette_size = blk_ptr->palette_size[0];
@@ -1455,9 +1409,9 @@ void update_mi_map(BlkStruct *blk_ptr, uint32_t blk_origin_x, uint32_t blk_origi
              ? BLOCK_4X4
              : blk_geom->bsize;
     block_mi->mode         = blk_ptr->pred_mode;
-    block_mi->skip         = (blk_ptr->block_has_coeff) ? EB_FALSE : EB_TRUE;
+    block_mi->skip         = (blk_ptr->block_has_coeff) ? FALSE : TRUE;
     block_mi->partition    = from_shape_to_part[blk_geom->shape];
-    block_mi->skip_mode    = (int8_t)blk_ptr->skip_flag;
+    block_mi->skip_mode    = (int8_t)blk_ptr->skip_mode;
     block_mi->uv_mode      = blk_ptr->prediction_unit_array->intra_chroma_mode;
     block_mi->use_intrabc  = blk_ptr->use_intrabc;
     block_mi->ref_frame[0] = rf[0];
@@ -1482,10 +1436,10 @@ void update_mi_map(BlkStruct *blk_ptr, uint32_t blk_origin_x, uint32_t blk_origi
     // The data copied into each mi block is the same; therefore, copy the data from the blk_ptr only for the first block_mi
     // then use change the mi block pointers of the remaining blocks ot point to the first block_mi. All data that
     // is used from block_mi should be updated above.
-    copy_mi_map_grid((pcs_ptr->mi_grid_base + offset),
-                     mi_stride,
-                     (blk_geom->bheight >> MI_SIZE_LOG2),
-                     (blk_geom->bwidth >> MI_SIZE_LOG2));
+    svt_copy_mi_map_grid((pcs_ptr->mi_grid_base + offset),
+                         mi_stride,
+                         (blk_geom->bheight >> MI_SIZE_LOG2),
+                         (blk_geom->bwidth >> MI_SIZE_LOG2));
 }
 static INLINE void record_samples(MbModeInfo *mbmi, int *pts, int *pts_inref, int row_offset,
                                   int sign_r, int col_offset, int sign_c) {
@@ -1639,7 +1593,7 @@ int av1_find_samples(const Av1Common *cm, const BlockSize sb_size, MacroBlockD *
 void wm_count_samples(BlkStruct *blk_ptr, const BlockSize sb_size, const BlockGeom *blk_geom,
                       uint16_t blk_origin_x, uint16_t blk_origin_y, uint8_t ref_frame_type,
                       PictureControlSet *pcs_ptr, uint16_t *num_samples) {
-    Av1Common *  cm = pcs_ptr->parent_pcs_ptr->av1_cm;
+    Av1Common   *cm = pcs_ptr->parent_pcs_ptr->av1_cm;
     MacroBlockD *xd = blk_ptr->av1xd;
 
     int32_t mi_row = blk_origin_y >> MI_SIZE_LOG2;
@@ -1765,7 +1719,7 @@ void wm_count_samples(BlkStruct *blk_ptr, const BlockSize sb_size, const BlockGe
 uint16_t wm_find_samples(BlkStruct *blk_ptr, const BlockGeom *blk_geom, uint16_t blk_origin_x,
                          uint16_t blk_origin_y, MvReferenceFrame rf0, PictureControlSet *pcs_ptr,
                          int32_t *pts, int32_t *pts_inref) {
-    Av1Common *  cm = pcs_ptr->parent_pcs_ptr->av1_cm;
+    Av1Common   *cm = pcs_ptr->parent_pcs_ptr->av1_cm;
     MacroBlockD *xd = blk_ptr->av1xd;
 
     int32_t mi_row = blk_origin_y >> MI_SIZE_LOG2;
@@ -1775,23 +1729,16 @@ uint16_t wm_find_samples(BlkStruct *blk_ptr, const BlockGeom *blk_geom, uint16_t
     xd->n4_h = blk_geom->bheight >> MI_SIZE_LOG2;
 
     return (uint16_t)av1_find_samples(
-        cm,
-        ((SequenceControlSet *)pcs_ptr->scs_wrapper_ptr->object_ptr)->seq_header.sb_size,
-        xd,
-        mi_row,
-        mi_col,
-        rf0,
-        pts,
-        pts_inref);
+        cm, pcs_ptr->scs_ptr->seq_header.sb_size, xd, mi_row, mi_col, rf0, pts, pts_inref);
 }
 
-EbBool warped_motion_parameters(PictureControlSet *pcs_ptr, BlkStruct *blk_ptr, MvUnit *mv_unit,
-                                const BlockGeom *blk_geom, uint16_t blk_origin_x,
-                                uint16_t blk_origin_y, uint8_t ref_frame_type,
-                                EbWarpedMotionParams *wm_params, uint16_t *num_samples) {
+Bool warped_motion_parameters(PictureControlSet *pcs_ptr, BlkStruct *blk_ptr, MvUnit *mv_unit,
+                              const BlockGeom *blk_geom, uint16_t blk_origin_x,
+                              uint16_t blk_origin_y, uint8_t ref_frame_type,
+                              EbWarpedMotionParams *wm_params, uint16_t *num_samples) {
     MacroBlockD *xd       = blk_ptr->av1xd;
     BlockSize    bsize    = blk_geom->bsize;
-    EbBool       apply_wm = EB_FALSE;
+    Bool         apply_wm = FALSE;
 
     int     pts[SAMPLES_ARRAY_SIZE], pts_inref[SAMPLES_ARRAY_SIZE];
     int32_t mi_row = blk_origin_y >> MI_SIZE_LOG2;
@@ -1889,7 +1836,7 @@ int count_overlappable_nb_left(const Av1Common *cm, MacroBlockD *xd, int32_t mi_
 
 void svt_av1_count_overlappable_neighbors(const PictureControlSet *pcs_ptr, BlkStruct *blk_ptr,
                                           const BlockSize bsize, int32_t mi_row, int32_t mi_col) {
-    Av1Common *  cm                                             = pcs_ptr->parent_pcs_ptr->av1_cm;
+    Av1Common   *cm                                             = pcs_ptr->parent_pcs_ptr->av1_cm;
     MacroBlockD *xd                                             = blk_ptr->av1xd;
     blk_ptr->prediction_unit_array[0].overlappable_neighbors[0] = 0;
     blk_ptr->prediction_unit_array[0].overlappable_neighbors[1] = 0;
