@@ -20,7 +20,6 @@
 #include "EbPictureBufferDesc.h"
 #include "EbEncInterPrediction.h"
 #include "EbEntropyCoding.h"
-#include "EbTransQuantBuffers.h"
 #include "EbCodingUnit.h"
 #include "EbObject.h"
 
@@ -42,7 +41,6 @@ typedef struct EntropyCodingContext {
     uint32_t        blk_index;
     uint8_t         cu_depth;
     uint32_t        cu_size;
-    uint32_t        sb_sz;
     uint32_t        cu_size_log2;
     uint32_t        blk_origin_x;
     uint32_t        blk_origin_y;
