@@ -373,7 +373,7 @@ uint8_t get_update_cdf_level(EncMode enc_mode, SliceType is_islice, uint8_t is_b
     uint8_t update_cdf_level = 0;
     if (enc_mode <= ENC_M2)
         update_cdf_level = 1;
-    else if (enc_mode <= ENC_M6)
+    else if (enc_mode <= ENC_M5)
         update_cdf_level = is_base ? 1 : 3;
     else if (enc_mode <= ENC_M10)
         update_cdf_level = is_islice ? 1 : 0;
@@ -387,12 +387,10 @@ uint8_t svt_aom_get_chroma_level(EncMode enc_mode) {
     uint8_t chroma_level = 0;
     if (enc_mode <= ENC_MRS)
         chroma_level = 1;
-    else if (enc_mode <= ENC_M3)
+    else if (enc_mode <= ENC_M2)
         chroma_level = 2;
     else if (enc_mode <= ENC_M6)
         chroma_level = 3;
-    else if (enc_mode <= ENC_M7)
-        chroma_level = 4;
     else
         chroma_level = 5;
 
@@ -406,6 +404,7 @@ EbErrorType signal_derivation_mode_decision_config_kernel_oq(SequenceControlSet
     const EncMode            enc_mode            = pcs_ptr->enc_mode;
     const uint8_t            is_ref              = ppcs->is_used_as_reference_flag;
     const uint8_t            is_base             = ppcs->temporal_layer_index == 0;
+    const uint8_t            is_layer1           = ppcs->temporal_layer_index == 1;
     const EbInputResolution  input_resolution    = ppcs->input_resolution;
     const uint8_t            is_islice           = pcs_ptr->slice_type == I_SLICE;
     const SliceType          slice_type          = pcs_ptr->slice_type;
@@ -472,7 +471,7 @@ EbErrorType signal_derivation_mode_decision_config_kernel_oq(SequenceControlSet
     // 1                      | ON
     if (scs_ptr->filter_intra_level == DEFAULT) {
         if (scs_ptr->seq_header.filter_intra_level) {
-            if (pcs_ptr->enc_mode <= ENC_M5)
+            if (pcs_ptr->enc_mode <= ENC_M4)
                 pcs_ptr->pic_filter_intra_level = 1;
             else
                 pcs_ptr->pic_filter_intra_level = 0;
@@ -482,7 +481,7 @@ EbErrorType signal_derivation_mode_decision_config_kernel_oq(SequenceControlSet
         pcs_ptr->pic_filter_intra_level = scs_ptr->filter_intra_level;
 
     if (fast_decode == 0 || input_resolution <= INPUT_SIZE_360p_RANGE) {
-        if (pcs_ptr->enc_mode <= ENC_M4)
+        if (pcs_ptr->enc_mode <= ENC_M5)
             pcs_ptr->parent_pcs_ptr->partition_contexts = PARTITION_CONTEXTS;
         else
             pcs_ptr->parent_pcs_ptr->partition_contexts = 4;
@@ -505,13 +504,16 @@ EbErrorType signal_derivation_mode_decision_config_kernel_oq(SequenceControlSet
         if (fast_decode == 0 || input_resolution <= INPUT_SIZE_360p_RANGE) {
             if (enc_mode <= ENC_M3) {
                 pcs_ptr->wm_level = 1;
-            } else if (enc_mode <= ENC_M4) {
+            } else if (enc_mode <= ENC_M6) {
                 if (hierarchical_levels <= 3)
                     pcs_ptr->wm_level = is_base ? 1 : 0;
                 else
-                    pcs_ptr->wm_level = is_ref ? 1 : 0;
+                    pcs_ptr->wm_level = (is_base || is_layer1) ? 1 : 0;
             } else if (enc_mode <= ENC_M7) {
-                pcs_ptr->wm_level = is_base ? 1 : 0;
+                if (hierarchical_levels <= 4)
+                    pcs_ptr->wm_level = is_base ? 1 : 0;
+                else
+                    pcs_ptr->wm_level = (is_base || is_layer1) ? 1 : 0;
             } else if (enc_mode <= ENC_M10) {
                 if (input_resolution <= INPUT_SIZE_720p_RANGE)
                     pcs_ptr->wm_level = is_base ? 1 : 0;
@@ -557,7 +559,7 @@ EbErrorType signal_derivation_mode_decision_config_kernel_oq(SequenceControlSet
     //       > 1        | Faster level subject to possible constraints
     if (scs_ptr->obmc_level == DEFAULT) {
         if (fast_decode == 0 || input_resolution <= INPUT_SIZE_360p_RANGE) {
-            if (ppcs->enc_mode <= ENC_M3)
+            if (ppcs->enc_mode <= ENC_M2)
                 ppcs->pic_obmc_level = 1;
             else if (ppcs->enc_mode <= ENC_M5)
                 ppcs->pic_obmc_level = 2;
@@ -601,15 +603,20 @@ EbErrorType signal_derivation_mode_decision_config_kernel_oq(SequenceControlSet
         pcs_ptr->cand_reduction_level = 0;
     else if (enc_mode <= ENC_M5)
         pcs_ptr->cand_reduction_level = 1;
-    else if (enc_mode <= ENC_M9) {
+    else if (enc_mode <= ENC_M6) {
         if (pcs_ptr->coeff_lvl == LOW_LVL)
             pcs_ptr->cand_reduction_level = 1;
         else
             pcs_ptr->cand_reduction_level = 2;
+    } else if (enc_mode <= ENC_M9) {
+        if (pcs_ptr->coeff_lvl == LOW_LVL)
+            pcs_ptr->cand_reduction_level = 1;
+        else
+            pcs_ptr->cand_reduction_level = 3;
     } else
-        pcs_ptr->cand_reduction_level = 2;
+        pcs_ptr->cand_reduction_level = 3;
     if (scs_ptr->rc_stat_gen_pass_mode)
-        pcs_ptr->cand_reduction_level = 6;
+        pcs_ptr->cand_reduction_level = 7;
     // Set the level for the txt search
     pcs_ptr->txt_level = 0;
     if (enc_mode <= ENC_MR)
@@ -618,7 +625,7 @@ EbErrorType signal_derivation_mode_decision_config_kernel_oq(SequenceControlSet
         pcs_ptr->txt_level = 2;
     else if (enc_mode <= ENC_M2)
         pcs_ptr->txt_level = 3;
-    else if (enc_mode <= ENC_M5) {
+    else if (enc_mode <= ENC_M6) {
         if (pcs_ptr->coeff_lvl == LOW_LVL) {
             pcs_ptr->txt_level = 4;
         } else if (pcs_ptr->coeff_lvl == HIGH_LVL) {
@@ -660,6 +667,8 @@ EbErrorType signal_derivation_mode_decision_config_kernel_oq(SequenceControlSet
     pcs_ptr->tx_shortcut_level = 0;
     if (enc_mode <= ENC_M4)
         pcs_ptr->tx_shortcut_level = 0;
+    else if (enc_mode <= ENC_M5)
+        pcs_ptr->tx_shortcut_level = is_base ? 0 : 1;
     else if (enc_mode <= ENC_M10)
         pcs_ptr->tx_shortcut_level = is_islice ? 0 : 1;
     else
@@ -689,7 +698,7 @@ EbErrorType signal_derivation_mode_decision_config_kernel_oq(SequenceControlSet
             pcs_ptr->cfl_level = 1;
         else
             pcs_ptr->cfl_level = is_base ? 2 : 0;
-    } else if (enc_mode <= ENC_M5)
+    } else if (enc_mode <= ENC_M4)
         pcs_ptr->cfl_level = 1;
     else if (enc_mode <= ENC_M9)
         pcs_ptr->cfl_level = is_base ? 2 : 0;
@@ -712,7 +721,7 @@ EbErrorType signal_derivation_mode_decision_config_kernel_oq(SequenceControlSet
         pcs_ptr->new_nearest_near_comb_injection = scs_ptr->new_nearest_comb_inject;
 
     // Set the level for unipred3x3 injection
-    if (enc_mode <= ENC_M1)
+    if (enc_mode <= ENC_M0)
         pcs_ptr->unipred3x3_injection = 1;
     else
         pcs_ptr->unipred3x3_injection = 0;
@@ -721,7 +730,7 @@ EbErrorType signal_derivation_mode_decision_config_kernel_oq(SequenceControlSet
     if (scs_ptr->bipred_3x3_inject == DEFAULT) {
         if (enc_mode <= ENC_M0)
             pcs_ptr->bipred3x3_injection = 1;
-        else if (enc_mode <= ENC_M3)
+        else if (enc_mode <= ENC_M2)
             pcs_ptr->bipred3x3_injection = 2;
         else
             pcs_ptr->bipred3x3_injection = 0;
@@ -734,9 +743,9 @@ EbErrorType signal_derivation_mode_decision_config_kernel_oq(SequenceControlSet
         if (scs_ptr->compound_level == DEFAULT) {
             if (enc_mode <= ENC_MR)
                 pcs_ptr->inter_compound_mode = 1;
-            else if (enc_mode <= ENC_M2)
+            else if (enc_mode <= ENC_M1)
                 pcs_ptr->inter_compound_mode = 3;
-            else if (enc_mode <= ENC_M5)
+            else if (enc_mode <= ENC_M3)
                 pcs_ptr->inter_compound_mode = 4;
             else
                 pcs_ptr->inter_compound_mode = 0;
@@ -754,8 +763,6 @@ EbErrorType signal_derivation_mode_decision_config_kernel_oq(SequenceControlSet
             pcs_ptr->dist_based_ref_pruning = 1;
         else if (enc_mode <= ENC_M0)
             pcs_ptr->dist_based_ref_pruning = is_base ? 1 : 2;
-        else if (enc_mode <= ENC_M2)
-            pcs_ptr->dist_based_ref_pruning = is_base ? 1 : 4;
         else if (enc_mode <= ENC_M4)
             pcs_ptr->dist_based_ref_pruning = is_base ? 2 : 5;
         else if (enc_mode <= ENC_M5)
@@ -776,65 +783,14 @@ EbErrorType signal_derivation_mode_decision_config_kernel_oq(SequenceControlSet
     if (scs_ptr->spatial_sse_full_loop_level == DEFAULT)
         if (pcs_ptr->parent_pcs_ptr->sc_class1)
             pcs_ptr->spatial_sse_full_loop_level = 1;
-        else if (enc_mode <= ENC_M10)
+        else if (enc_mode <= ENC_M11)
             pcs_ptr->spatial_sse_full_loop_level = 1;
         else
             pcs_ptr->spatial_sse_full_loop_level = 0;
     else
         pcs_ptr->spatial_sse_full_loop_level = scs_ptr->spatial_sse_full_loop_level;
-
-    // Set the level for coeff-based NSQ accuracy reduction
-    pcs_ptr->parent_sq_coeff_area_based_cycles_reduction_level = 0;
-    if (enc_mode <= ENC_MRS)
-        pcs_ptr->parent_sq_coeff_area_based_cycles_reduction_level = 0;
-    else if (enc_mode <= ENC_MR)
-        pcs_ptr->parent_sq_coeff_area_based_cycles_reduction_level = is_islice ? 0 : 1;
-    else if (enc_mode <= ENC_M0)
-        pcs_ptr->parent_sq_coeff_area_based_cycles_reduction_level = is_islice ? 0 : 2;
-    else if (enc_mode <= ENC_M3)
-        pcs_ptr->parent_sq_coeff_area_based_cycles_reduction_level = is_islice ? 0
-            : is_base                                                          ? 2
-            : is_ref                                                           ? 4
-                                                                               : 7;
-    else
-        pcs_ptr->parent_sq_coeff_area_based_cycles_reduction_level = is_islice ? 5 : is_ref ? 6 : 7;
-    // Weighting (expressed as a percentage) applied to
-    // square shape costs for determining if a and b
-    // shapes should be skipped. Namely:
-    // skip HA, HB, and H4 if h_cost > (weighted sq_cost)
-    // skip VA, VB, and V4 if v_cost > (weighted sq_cost)
-    if (enc_mode <= ENC_MRS)
-        pcs_ptr->sq_weight = (uint32_t)~0;
-    else if (enc_mode <= ENC_M0)
-        pcs_ptr->sq_weight = 105;
-    else
-        pcs_ptr->sq_weight = 95;
-
-    // max_part0_to_part1_dev is used to:
-    // (1) skip the H_Path if the deviation between the Parent-SQ src-to-recon distortion of (1st quadrant + 2nd quadrant) and the Parent-SQ src-to-recon distortion of (3rd quadrant + 4th quadrant) is less than TH,
-    // (2) skip the V_Path if the deviation between the Parent-SQ src-to-recon distortion of (1st quadrant + 3rd quadrant) and the Parent-SQ src-to-recon distortion of (2nd quadrant + 4th quadrant) is less than TH.
-    if (enc_mode <= ENC_M3)
-        pcs_ptr->max_part0_to_part1_dev = 0;
-    else if (enc_mode <= ENC_M4) {
-        if (pcs_ptr->coeff_lvl == LOW_LVL)
-            pcs_ptr->max_part0_to_part1_dev = 0;
-        else if (pcs_ptr->coeff_lvl == HIGH_LVL)
-            pcs_ptr->max_part0_to_part1_dev = 60;
-        else // regular
-            pcs_ptr->max_part0_to_part1_dev = 40;
-    } else {
-        if (pcs_ptr->coeff_lvl == LOW_LVL)
-            pcs_ptr->max_part0_to_part1_dev = 80;
-        else if (pcs_ptr->coeff_lvl == HIGH_LVL)
-            pcs_ptr->max_part0_to_part1_dev = 140;
-        else // regular
-            pcs_ptr->max_part0_to_part1_dev = 120;
-    }
-    if (enc_mode <= ENC_M2)
-        pcs_ptr->skip_hv4_on_best_part = 0;
-    else
-        pcs_ptr->skip_hv4_on_best_part = 1;
-
+    //set the nsq_level
+    pcs_ptr->nsq_level = get_nsq_level(enc_mode, is_islice, is_base, pcs_ptr->coeff_lvl);
     // Set the level for enable_inter_intra
     // Block level switch, has to follow the picture level
     // inter intra pred                      Settings
@@ -846,7 +802,7 @@ EbErrorType signal_derivation_mode_decision_config_kernel_oq(SequenceControlSet
         scs_ptr->seq_header.enable_interintra_compound) {
         if (enc_mode <= ENC_M1)
             pcs_ptr->md_inter_intra_level = 1;
-        else if (enc_mode <= ENC_M3)
+        else if (enc_mode <= ENC_M2)
             pcs_ptr->md_inter_intra_level = transition_present ? 1 : (is_base ? 1 : 0);
         else if (enc_mode <= ENC_M11)
             pcs_ptr->md_inter_intra_level = transition_present ? 1 : 0;
@@ -859,10 +815,8 @@ EbErrorType signal_derivation_mode_decision_config_kernel_oq(SequenceControlSet
         pcs_ptr->txs_level = 1;
     else if (enc_mode <= ENC_MR)
         pcs_ptr->txs_level = 2;
-    else if (enc_mode <= ENC_M3)
+    else if (enc_mode <= ENC_M2)
         pcs_ptr->txs_level = is_base ? 2 : 3;
-    else if (enc_mode <= ENC_M5)
-        pcs_ptr->txs_level = is_base ? 2 : 4;
     else if (enc_mode <= ENC_M7)
         pcs_ptr->txs_level = is_base ? 2 : 0;
     else if (enc_mode <= ENC_M9)
@@ -880,7 +834,7 @@ EbErrorType signal_derivation_mode_decision_config_kernel_oq(SequenceControlSet
     // Set the level for nic
     pcs_ptr->nic_level = get_nic_level(enc_mode, is_base, hierarchical_levels);
     // Set the level for SQ me-search
-    if (enc_mode <= ENC_M2)
+    if (enc_mode <= ENC_M0)
         pcs_ptr->md_sq_mv_search_level = 1;
     else
         pcs_ptr->md_sq_mv_search_level = 0;
@@ -890,7 +844,6 @@ EbErrorType signal_derivation_mode_decision_config_kernel_oq(SequenceControlSet
         pcs_ptr->md_nsq_mv_search_level = 2;
     else
         pcs_ptr->md_nsq_mv_search_level = 4;
-
     // Set the level for PME search
     if (enc_mode <= ENC_MR)
         pcs_ptr->md_pme_level = 1;
@@ -901,7 +854,9 @@ EbErrorType signal_derivation_mode_decision_config_kernel_oq(SequenceControlSet
             pcs_ptr->md_pme_level = 6;
         else
             pcs_ptr->md_pme_level = 3;
-    } else
+    } else if (enc_mode <= ENC_M7)
+        pcs_ptr->md_pme_level = 5;
+    else
         pcs_ptr->md_pme_level = 6;
 
     // Set the level for mds0
@@ -923,13 +878,11 @@ EbErrorType signal_derivation_mode_decision_config_kernel_oq(SequenceControlSet
        Bypassing EncDec
     */
 
-    // TODO: Bypassing EncDec doesn't work if HVA_HVB_HV4 are enabled (for all bit depths; causes non-conformant bitstreams),
-    // or if NSQ is enabled for 10bit content (causes r2r).
+    // TODO: Bypassing EncDec doesn't work if NSQ is enabled for 10bit content (causes r2r).
     // TODO: This signal can only be modified per picture right now, not per SB.  Per SB requires
     // neighbour array updates at EncDec for all SBs, that are currently skipped if EncDec is bypassed.
     // TODO: Bypassing EncDec doesn't work if pcs_ptr->cdf_ctrl.update_coef is enabled for non-ISLICE frames (causes r2r)
-    if ((ppcs->disallow_HVA_HVB && ppcs->disallow_HV4) &&
-        (scs_ptr->static_config.encoder_bit_depth == EB_EIGHT_BIT || ppcs->disallow_nsq) &&
+    if ((scs_ptr->static_config.encoder_bit_depth == EB_EIGHT_BIT || !pcs_ptr->nsq_level) &&
         (!pcs_ptr->cdf_ctrl.update_coef || is_islice) &&
         !ppcs->frm_hdr.segmentation_params.segmentation_enabled) {
         pcs_ptr->pic_bypass_encdec = get_bypass_encdec(
@@ -940,9 +893,9 @@ EbErrorType signal_derivation_mode_decision_config_kernel_oq(SequenceControlSet
     /*
         set lpd0_level
     */
-    if (enc_mode <= ENC_M3)
+    if (enc_mode <= ENC_M2)
         pcs_ptr->pic_lpd0_lvl = 0;
-    else if (enc_mode <= ENC_M6)
+    else if (enc_mode <= ENC_M5)
         pcs_ptr->pic_lpd0_lvl = 1;
     else if (enc_mode <= ENC_M9) {
         if (pcs_ptr->coeff_lvl == LOW_LVL) {
@@ -1004,7 +957,7 @@ EbErrorType signal_derivation_mode_decision_config_kernel_oq(SequenceControlSet
                     pcs_ptr->pic_depth_removal_level = is_base ? 5 : 14;
                 }
             } else if (fast_decode == 0) {
-                if (enc_mode <= ENC_M2)
+                if (enc_mode <= ENC_M1)
                     pcs_ptr->pic_depth_removal_level = 0;
                 else if (enc_mode <= ENC_M5) {
                     if (input_resolution <= INPUT_SIZE_480p_RANGE)
@@ -1023,6 +976,18 @@ EbErrorType signal_derivation_mode_decision_config_kernel_oq(SequenceControlSet
                         else
                             pcs_ptr->pic_depth_removal_level = 2;
                     }
+                } else if (enc_mode <= ENC_M8) {
+                    if (pcs_ptr->coeff_lvl == LOW_LVL) {
+                        if (input_resolution <= INPUT_SIZE_480p_RANGE)
+                            pcs_ptr->pic_depth_removal_level = 1;
+                        else
+                            pcs_ptr->pic_depth_removal_level = 2;
+                    } else {
+                        if (input_resolution <= INPUT_SIZE_480p_RANGE)
+                            pcs_ptr->pic_depth_removal_level = 1;
+                        else
+                            pcs_ptr->pic_depth_removal_level = is_base ? 2 : 6;
+                    }
                 } else if (enc_mode <= ENC_M9) {
                     if (pcs_ptr->coeff_lvl == LOW_LVL) {
                         if (input_resolution <= INPUT_SIZE_480p_RANGE)
@@ -1039,7 +1004,7 @@ EbErrorType signal_derivation_mode_decision_config_kernel_oq(SequenceControlSet
                     }
                 } else if (enc_mode <= ENC_M11) {
                     if (input_resolution <= INPUT_SIZE_360p_RANGE)
-                        pcs_ptr->pic_depth_removal_level = is_base ? 2 : 4;
+                        pcs_ptr->pic_depth_removal_level = is_base ? 2 : 3;
                     else if (input_resolution <= INPUT_SIZE_480p_RANGE)
                         pcs_ptr->pic_depth_removal_level = is_base ? 2 : 5;
                     else if (input_resolution <= INPUT_SIZE_720p_RANGE)
@@ -1050,7 +1015,7 @@ EbErrorType signal_derivation_mode_decision_config_kernel_oq(SequenceControlSet
                         pcs_ptr->pic_depth_removal_level = is_base ? 9 : 14;
                 } else {
                     if (input_resolution <= INPUT_SIZE_360p_RANGE)
-                        pcs_ptr->pic_depth_removal_level = 7;
+                        pcs_ptr->pic_depth_removal_level = is_base ? 2 : 3;
                     else if (input_resolution <= INPUT_SIZE_480p_RANGE)
                         pcs_ptr->pic_depth_removal_level = is_base ? 9 : 11;
                     else
@@ -1109,24 +1074,11 @@ EbErrorType signal_derivation_mode_decision_config_kernel_oq(SequenceControlSet
             pcs_ptr->pic_block_based_depth_refinement_level = is_islice ? 7 : 12;
     } else if (enc_mode <= ENC_M2)
         pcs_ptr->pic_block_based_depth_refinement_level = 0;
-    else if (enc_mode <= ENC_M3)
-        pcs_ptr->pic_block_based_depth_refinement_level = is_base ? 0 : 2;
-    else if (enc_mode <= ENC_M4) {
+    else if (enc_mode <= ENC_M5) {
         if (pcs_ptr->coeff_lvl == LOW_LVL)
             pcs_ptr->pic_block_based_depth_refinement_level = is_base ? 0 : 2;
         else
             pcs_ptr->pic_block_based_depth_refinement_level = is_base ? 0 : 4;
-    } else if (enc_mode <= ENC_M5) {
-        if (pcs_ptr->coeff_lvl == LOW_LVL)
-            pcs_ptr->pic_block_based_depth_refinement_level = is_base ? 0 : 3;
-        else
-            pcs_ptr->pic_block_based_depth_refinement_level = is_base ? 0 : 4;
-    } else if (enc_mode <= ENC_M7) {
-        if (pcs_ptr->coeff_lvl == LOW_LVL) {
-            pcs_ptr->pic_block_based_depth_refinement_level = is_base ? 0 : 3;
-        } else { // regular
-            pcs_ptr->pic_block_based_depth_refinement_level = is_base ? 1 : 4;
-        }
     } else {
         if (pcs_ptr->coeff_lvl == LOW_LVL) {
             pcs_ptr->pic_block_based_depth_refinement_level = is_base ? 1 : 4;
@@ -1200,7 +1152,7 @@ EbErrorType signal_derivation_mode_decision_config_kernel_oq(SequenceControlSet
     // There is another check before PD1 is called; pred_depth_only is not checked here, because some modes
     // may force pred_depth_only at the light-pd1 detector
     if (pcs_ptr->pic_lpd1_lvl &&
-        !(ppcs->hbd_mode_decision == 0 && ppcs->disallow_nsq == TRUE &&
+        !(ppcs->hbd_mode_decision == 0 && !pcs_ptr->nsq_level &&
           pcs_ptr->pic_disallow_4x4 == TRUE && scs_ptr->super_block_size == 64)) {
         pcs_ptr->pic_lpd1_lvl = 0;
     }
@@ -1439,55 +1391,7 @@ static void av1_setup_motion_field(Av1Common *cm, PictureControlSet *pcs_ptr) {
         motion_field_projection(cm, pcs_ptr, LAST2_FRAME, 2);
 }
 EbErrorType svt_av1_hash_table_create(HashTable *p_hash_table);
-// intra_perc will be set to the % of intra area in two nearest ref frames
-void get_ref_intra_percentage(PictureControlSet *pcs_ptr, uint8_t *intra_perc) {
-    assert(intra_perc != NULL);
-    if (pcs_ptr->slice_type == I_SLICE) {
-        *intra_perc = 100;
-        return;
-    }
-
-    uint8_t iperc = 0;
-
-    EbReferenceObject *ref_obj_l0 =
-        (EbReferenceObject *)pcs_ptr->ref_pic_ptr_array[REF_LIST_0][0]->object_ptr;
-    iperc = ref_obj_l0->intra_coded_area;
-    if (pcs_ptr->slice_type == B_SLICE) {
-        EbReferenceObject *ref_obj_l1 =
-            (EbReferenceObject *)pcs_ptr->ref_pic_ptr_array[REF_LIST_1][0]->object_ptr;
-        iperc += ref_obj_l1->intra_coded_area;
-
-        // if have two frames, divide the iperc by 2 to get the avg skip area
-        iperc >>= 1;
-    }
-
-    *intra_perc = iperc;
-}
-
-// skip_area will be set to the % of skipped area in two nearest ref frames
-void get_ref_skip_percentage(PictureControlSet *pcs_ptr, uint8_t *skip_area) {
-    assert(skip_area != NULL);
-    if (pcs_ptr->slice_type == I_SLICE) {
-        *skip_area = 0;
-        return;
-    }
-
-    uint8_t            skip_perc = 0;
-    EbReferenceObject *ref_obj_l0 =
-        (EbReferenceObject *)pcs_ptr->ref_pic_ptr_array[REF_LIST_0][0]->object_ptr;
-    skip_perc = ref_obj_l0->skip_coded_area;
-    if (pcs_ptr->slice_type == B_SLICE) {
-        EbReferenceObject *ref_obj_l1 =
-            (EbReferenceObject *)pcs_ptr->ref_pic_ptr_array[REF_LIST_1][0]->object_ptr;
-        skip_perc += ref_obj_l1->skip_coded_area;
-
-        // if have two frames, divide the skip_perc by 2 to get the avg skip area
-        skip_perc >>= 1;
-    }
-
-    *skip_area = skip_perc;
-}
-void *rtime_alloc_block_hash_block_is_same(size_t size) { return malloc(size); }
+void       *rtime_alloc_block_hash_block_is_same(size_t size) { return malloc(size); }
 
 // Use me_8x8_distortion and QP to predict the coeff level per frame
 static void predict_frame_coeff_lvl(struct PictureControlSet *pcs) {
@@ -1584,11 +1488,6 @@ void *mode_decision_configuration_kernel(void *input_ptr) {
         }
 
         FrameHeader *frm_hdr = &pcs_ptr->parent_pcs_ptr->frm_hdr;
-        // Get intra % in ref frame
-        get_ref_intra_percentage(pcs_ptr, &pcs_ptr->ref_intra_percentage);
-
-        // Get skip % in ref frame
-        get_ref_skip_percentage(pcs_ptr, &pcs_ptr->ref_skip_percentage);
         // Mode Decision Configuration Kernel Signal(s) derivation
         if (scs_ptr->static_config.pass == ENC_FIRST_PASS)
             first_pass_signal_derivation_mode_decision_config_kernel(pcs_ptr);
