@@ -18,7 +18,6 @@
 #include "EbSystemResourceManager.h"
 #include "EbPictureBufferDesc.h"
 #include "EbEntropyCoding.h"
-#include "EbTransQuantBuffers.h"
 #include "EbReferenceObject.h"
 #include "EbNeighborArrays.h"
 #include "EbObject.h"
@@ -122,7 +121,8 @@ typedef struct InterCompCtrls {
     uint8_t do_near_near; // if true, test all compound types for near_near
     uint8_t do_nearest_near_new; // if true, test all compound types for nearest_near_new
     uint8_t do_3x3_bi; // if true, test all compound types for 3x3_bipred
-
+    uint8_t
+        skip_mvp_on_ref_info; // Skip MVP compound based on ref frame type and neighbour ref frame types
     uint8_t
             pred0_to_pred1_mult; // multiplier to the pred0_to_pred1_sad; 0: no pred0_to_pred1_sad-based pruning, >= 1: towards more inter-inter compound
     uint8_t use_rate; // if true, use rate @ compound params derivation
@@ -147,6 +147,10 @@ typedef struct TxtControls {
         early_exit_dist_th; // Per unit distortion TH; if best TX distortion is below the TH, skip remaining TX types (0 OFF, higher = more aggressive)
     uint32_t
         early_exit_coeff_th; // If best TX number of coeffs is less than the TH, skip remaining TX types (0 OFF, higher = more aggressive)
+    uint16_t
+        satd_early_exit_th_intra; // If dev. of satd of current tx_type to best is greater than TH, exit early from testing current tx_type. 0: off; larger value is safer
+    uint16_t
+        satd_early_exit_th_inter; // If dev. of satd of current tx_type to best is greater than TH, exit early from testing current tx_type. 0: off; larger value is safer
 } TxtControls;
 typedef struct TxsCycleRControls {
     uint8_t  enabled; // On/Off feature control
@@ -165,9 +169,9 @@ typedef struct RefPruningControls {
     uint8_t  enabled; // 0: OFF; 1: use inter to inter distortion deviation to derive best_refs
     uint32_t max_dev_to_best
         [TOT_INTER_GROUP]; // 0: OFF; 1: limit the injection to the best references based on distortion
-    uint32_t ref_idx_2_offset;
-    uint32_t ref_idx_3_offset;
-    uint8_t  closest_refs
+    uint8_t use_tpl_info_offset;
+    uint8_t check_closest_multiplier;
+    uint8_t closest_refs
         [TOT_INTER_GROUP]; // 0: OFF; 1: limit the injection to the closest references based on distance (LAST/BWD)
 } RefPruningControls;
 typedef struct DepthRemovalCtrls {
@@ -178,6 +182,8 @@ typedef struct DepthRemovalCtrls {
         disallow_below_32x32; // remove 16x16 blocks and below based on the sb_64x64 (me_distortion, variance)
     uint8_t
         disallow_below_16x16; // remove 8x8 blocks and below based on the sb_64x64 (me_distortion, variance)
+    uint8_t
+        disallow_4x4; // remove 8x8 blocks and below based on the sb_64x64 (me_distortion, variance)
 } DepthRemovalCtrls;
 typedef struct DepthCtrls {
     int8_t
@@ -201,6 +207,12 @@ typedef struct DepthRefinementCtrls {
     uint16_t max_cost_multiplier; // the max cost beyond which the decrement is ignored
     uint8_t  max_band_cnt; // the number of band(s)
     int64_t  decrement_per_band[MAX_RANGE_CNT]; // the offset per band
+    int64_t
+        limit_4x4_depth; // an offset (towards more aggressive pruning) when the child-depth is 4x4
+    unsigned int
+        sub_to_current_pd0_coeff_th; // If current depth has fewer than sub_to_current_pd0_coeff_th PD0 coeffs, subtract sub_to_current_pd0_coeff_offset from
+    // sub_to_current_th towards skipping child depths (doesn't work with very light PD0)
+    int sub_to_current_pd0_coeff_offset;
 } DepthRefinementCtrls;
 typedef struct SubresCtrls {
     uint8_t step; // Residual sub-sampling step (0:OFF)
@@ -369,10 +381,25 @@ typedef struct NicPruningCtrls {
     // mdsx_cand_th = base_th + sq_offset_th + intra_class_offset_th
 
     // Post mds0
-    uint64_t mds1_cand_base_th; // base_th
+    uint64_t mds1_cand_base_th_intra; // Post-MDS0 candidate pruning TH for intra classes
+    uint64_t mds1_cand_base_th_inter; // Post-MDS0 candidate pruning TH for inter classes
+
+    uint16_t
+        mds1_cand_th_rank_factor; // Use a more aggressive MDS0 candidate pruning TH based on how the candidate is ranked compared to others
+    // (2nd best candidate will use a safer pruning TH than the 3rd best, and so on).
+    // The new_th = mds1_cand_base_th / (mds1_cand_th_rank_factor * cand_count); where cand_count is the number of
+    // candidates with better cost than the current candidate. 0 is off. Higher is more aggressive.
 
     // Post mds1
     uint64_t mds2_cand_base_th;
+    uint16_t
+        mds2_cand_th_rank_factor; // Use a more aggressive MDS1 candidate pruning TH based on how the candidate is ranked compared to others
+    // (2nd best candidate will use a safer pruning TH than the 3rd best, and so on).
+    // The new_th = mds2_cand_base_th / (mds2_cand_th_rank_factor * cand_count); where cand_count is the number of
+    // candidates with better cost than the current candidate. 0 is off. Higher is more aggressive.
+    uint16_t
+        mds2_relative_dev_th; // Prune candidates based on the relative deviation compared to the previous candidate. Deviations are still computed
+    // compared to the best candidate. If dev > previous_dev + th then prune the candidate.
 
     // Post mds2
     uint64_t mds3_cand_base_th;
@@ -394,6 +421,26 @@ typedef struct CandEliminationCtlrs {
     uint8_t  inject_new_warp;
     uint8_t  th_multiplier; // factor to scale base TH by for distortion check
 } CandEliminationCtlrs;
+typedef struct NsqCtrls {
+    uint8_t enabled; // Enable or disable nsq signal. 0: disabled, 1: enabled
+    uint8_t
+        min_nsq_block_size; // Disables all nsq blocks for below a specified size. e.g. 8 = 8x8, 16 = 16x16
+    uint8_t allow_HV4; // Disallow H4/V4 when off. 0: OFF, 1: ON
+    uint8_t allow_HVA_HVB; // Disallow HA/HB/VA/VB NSQ blocks when off. 0: OFF, 1: ON
+    uint8_t
+        parent_sq_coeff_area_based_cycles_reduction_level; // Set the level for coeff-based NSQ accuracy reduction
+    // Weighting (expressed as a percentage) applied to
+    // square shape costs for determining if a and b
+    // shapes should be skipped. Namely:
+    // skip HA, HB, and H4 if h_cost > (weighted sq_cost)
+    // skip VA, VB, and V4 if v_cost > (weighted sq_cost)
+    uint32_t sq_weight;
+    // max_part0_to_part1_dev is used to:
+    // (1) skip the H_Path if the deviation between the Parent-SQ src-to-recon distortion of (1st quadrant + 2nd quadrant) and the Parent-SQ src-to-recon distortion of (3rd quadrant + 4th quadrant) is less than TH,
+    // (2) skip the V_Path if the deviation between the Parent-SQ src-to-recon distortion of (1st quadrant + 3rd quadrant) and the Parent-SQ src-to-recon distortion of (2nd quadrant + 4th quadrant) is less than TH.
+    uint32_t max_part0_to_part1_dev;
+    uint32_t skip_hv4_on_best_part;
+} NsqCtrls;
 typedef struct TxsControls {
     uint8_t  enabled;
     uint8_t  prev_depth_coeff_exit; // Skip current depth if previous depth has no coeff
@@ -408,7 +455,8 @@ typedef struct TxsControls {
 typedef struct WmCtrls {
     uint8_t enabled;
     uint8_t use_wm_for_mvp; // allow/disallow MW for MVP candidates
-    uint8_t num_new_mv_refinement; // [0-12] number of refinement positions around NEW_MVs to use
+    uint8_t
+        refinement_iterations; // Number of iterations to use in the refinement search; each iteration searches the cardinal neighbours around the best-so-far position; 0 is no refinement
 } WmCtrls;
 typedef struct UvCtrls {
     uint8_t enabled;
@@ -555,8 +603,17 @@ typedef struct CandReductionCtrls {
     UseNeighbouringModeCtrls use_neighbouring_mode_ctrls;
     CandEliminationCtlrs     cand_elimination_ctrls;
     uint8_t                  reduce_unipred_candidates;
-
+    uint8_t                  mds0_reduce_intra;
 } CandReductionCtrls;
+typedef struct Skip4x4DepthCtrls {
+    uint8_t enabled;
+    float
+        min_distortion_cost_ratio; // the distortion-to-cost ratio under wich the quad_deviation_th is zeroed out (feature is disabled)
+    float
+        quad_deviation_th; // do not perform sub_depth if std_deviation of the 4 quadrants src-to-rec dist is less than std_deviation_th
+    uint8_t
+        skip_all; // whether to skip all or only next depth; 0: skip only next depth; 1: skip all lower depths
+} Skip4x4DepthCtrls;
 typedef struct ModeDecisionContext {
     EbDctor dctor;
 
@@ -573,6 +630,7 @@ typedef struct ModeDecisionContext {
     BlkStruct                    *md_blk_arr_nsq;
     uint8_t                      *avail_blk_flag;
     uint8_t                      *tested_blk_flag; //tells whether this CU is tested in MD.
+    uint8_t                      *do_not_process_blk;
     MdcSbData                    *mdc_sb_array;
 
     NeighborArrayUnit *intra_luma_mode_neighbor_array;
@@ -594,13 +652,11 @@ typedef struct ModeDecisionContext {
         tx_search_luma_dc_sign_level_coeff_neighbor_array; // Stored per 4x4. 8 bit: lower 6 bits (COEFF_CONTEXT_BITS), shows if there is at least one Coef. Top 2 bit store the sign of DC as follow: 0->0,1->-1,2-> 1
     NeighborArrayUnit *
         cr_dc_sign_level_coeff_neighbor_array; // Stored per 4x4. 8 bit: lower 6 bits(COEFF_CONTEXT_BITS), shows if there is at least one Coef. Top 2 bit store the sign of DC as follow: 0->0,1->-1,2-> 1
-    NeighborArrayUnit                *
+    NeighborArrayUnit                   *
         cb_dc_sign_level_coeff_neighbor_array; // Stored per 4x4. 8 bit: lower 6 bits(COEFF_CONTEXT_BITS), shows if there is at least one Coef. Top 2 bit store the sign of DC as follow: 0->0,1->-1,2-> 1
-    NeighborArrayUnit *txfm_context_array;
-    NeighborArrayUnit *leaf_partition_neighbor_array;
-    NeighborArrayUnit *skip_coeff_neighbor_array;
-    // Transform and Quantization Buffers
-    EbTransQuantBuffers  *trans_quant_buffers_ptr;
+    NeighborArrayUnit    *txfm_context_array;
+    NeighborArrayUnit    *leaf_partition_neighbor_array;
+    NeighborArrayUnit    *skip_coeff_neighbor_array;
     struct EncDecContext *enc_dec_context_ptr;
 
     uint64_t *fast_cost_array;
@@ -634,6 +690,7 @@ typedef struct ModeDecisionContext {
     uint8_t          hbd_mode_decision;
     uint8_t          encoder_bit_depth;
     uint8_t          qp_index;
+    uint8_t          me_q_index;
     uint64_t         three_quad_energy;
     uint32_t         txb_1d_offset;
     Bool             uv_intra_comp_only;
@@ -745,6 +802,9 @@ typedef struct ModeDecisionContext {
     uint32_t max_part0_to_part1_dev;
     uint32_t
         skip_hv4_on_best_part; // if true, skip H4/V4 shapes when best partition so far is not H/V
+    uint8_t
+        md_depth_early_exit_th; // Skip testing remaining blocks at the current depth if (curr_cost * 100 > pic_depth_early_exit_th * parent_cost)
+    // [0-100], 0 is OFF, lower percentage is more aggressive
     IntraCtrls        intra_ctrls;
     MdRateEstCtrls    rate_est_ctrls;
     uint8_t           shut_fast_rate; // use coeff rate and slipt flag rate only (no MVP derivation)
@@ -759,6 +819,7 @@ typedef struct ModeDecisionContext {
     DepthRemovalCtrls depth_removal_ctrls;
     DepthCtrls        depth_ctrls; // control which depths can be considered in PD1
     DepthRefinementCtrls depth_refinement_ctrls;
+    Skip4x4DepthCtrls    skip_4x4_depth_ctrls;
     int64_t              parent_to_current_deviation;
     int64_t              child_to_current_deviation;
     SubresCtrls          subres_ctrls;
@@ -784,6 +845,7 @@ typedef struct ModeDecisionContext {
     TxsControls                                txs_ctrls;
     TxtControls                                txt_ctrls;
     CandReductionCtrls                         cand_reduction_ctrls;
+    NsqCtrls                                   nsq_ctrls;
     RdoqCtrls                                  rdoq_ctrls;
     uint8_t                                    disallow_4x4;
     uint8_t                                    md_disallow_nsq;
@@ -792,6 +854,8 @@ typedef struct ModeDecisionContext {
     EbPictureBufferDesc                       *recon_coeff_ptr[TX_TYPES];
     EbPictureBufferDesc                       *recon_ptr[TX_TYPES];
     EbPictureBufferDesc                       *quant_coeff_ptr[TX_TYPES];
+    EbPictureBufferDesc *tx_coeffs; // buffer used to store transformed coeffs during TX/Q/IQ.
+        // TX'd coeffs are only needed temporarily, so no need to save for each TX type.
 
     uint8_t              skip_intra;
     EbPictureBufferDesc *temp_residual_ptr;
@@ -911,7 +975,7 @@ extern void reset_mode_decision(SequenceControlSet *scs_ptr, ModeDecisionContext
                                 uint32_t segment_index);
 
 extern void mode_decision_configure_sb(ModeDecisionContext *context_ptr, PictureControlSet *pcs_ptr,
-                                       uint8_t sb_qp);
+                                       uint8_t sb_qp, uint8_t me_sb_qp);
 extern void md_cfl_rd_pick_alpha(PictureControlSet           *pcs_ptr,
                                  ModeDecisionCandidateBuffer *candidate_buffer,
                                  ModeDecisionContext         *context_ptr,
