@@ -178,7 +178,12 @@ void set_me_search_params(SequenceControlSet *scs_ptr, PictureParentControlSet *
     } else if (pcs_ptr->enc_mode <= ENC_M2) {
         me_context_ptr->me_sa.sa_min = (SearchArea){64, 64};
         me_context_ptr->me_sa.sa_max = (SearchArea){128, 128};
-    } else if (pcs_ptr->enc_mode <= ENC_M4) {
+    }
+    else if (pcs_ptr->enc_mode <= ENC_M3) {
+        me_context_ptr->me_sa.sa_min = (SearchArea){16, 16};
+        me_context_ptr->me_sa.sa_max = (SearchArea){128, 128};
+    }
+    else if (pcs_ptr->enc_mode <= ENC_M4) {
         me_context_ptr->me_sa.sa_min = (SearchArea){16, 16};
         me_context_ptr->me_sa.sa_max = (SearchArea){64, 64};
     }
@@ -507,12 +512,6 @@ EbErrorType signal_derivation_me_kernel_oq(SequenceControlSet *       scs_ptr,
     {
         if (enc_mode <= ENC_M10)
             prehme_level = 1;
-        else if (enc_mode <= ENC_M11) {
-            if (hierarchical_levels <= 3)
-                prehme_level = 3;
-            else
-                prehme_level = 1;
-        }
         else
             prehme_level = 3;
     }
@@ -534,9 +533,9 @@ EbErrorType signal_derivation_me_kernel_oq(SequenceControlSet *       scs_ptr,
     } else {
         if (enc_mode <= ENC_MRS)
             set_me_hme_ref_prune_ctrls(context_ptr->me_context_ptr, 0);
-        else if (enc_mode <= ENC_M1)
+        else if (enc_mode <= ENC_M0)
             set_me_hme_ref_prune_ctrls(context_ptr->me_context_ptr, 2);
-        else if (enc_mode <= ENC_M2) {
+        else if (enc_mode <= ENC_M1) {
             if (pcs_ptr->temporal_layer_index == 0)
                 set_me_hme_ref_prune_ctrls(context_ptr->me_context_ptr, 2);
             else
@@ -559,11 +558,11 @@ EbErrorType signal_derivation_me_kernel_oq(SequenceControlSet *       scs_ptr,
             set_me_sr_adjustment_ctrls(context_ptr->me_context_ptr, 5);
     else if (enc_mode <= ENC_MRS)
         set_me_sr_adjustment_ctrls(context_ptr->me_context_ptr, 0);
-    else if (enc_mode <= ENC_M4)
+    else if (enc_mode <= ENC_M2)
         set_me_sr_adjustment_ctrls(context_ptr->me_context_ptr, 1);
     else
         set_me_sr_adjustment_ctrls(context_ptr->me_context_ptr, 3);
-    if (enc_mode <= ENC_M4)
+    if (enc_mode <= ENC_M2)
         context_ptr->me_context_ptr->prune_me_candidates_th = 0;
     else
         context_ptr->me_context_ptr->prune_me_candidates_th = 65;
