@@ -36,16 +36,16 @@ EbErrorType neighbor_array_unit_ctor32(NeighborArrayUnit32 *na_unit_ptr, uint32_
     na_unit_ptr->granularity_normal        = (uint8_t)(granularity_normal);
     na_unit_ptr->granularity_normal_log2   = (uint8_t)(svt_log2f(na_unit_ptr->granularity_normal));
     na_unit_ptr->granularity_top_left      = (uint8_t)(granularity_top_left);
-    na_unit_ptr->granularity_top_left_log2 = (uint8_t)(
-        svt_log2f(na_unit_ptr->granularity_top_left));
-    na_unit_ptr->left_array_size     = (uint16_t)((type_mask & NEIGHBOR_ARRAY_UNIT_LEFT_MASK)
-                                                      ? max_picture_height >>
+    na_unit_ptr->granularity_top_left_log2 = (uint8_t)(svt_log2f(
+        na_unit_ptr->granularity_top_left));
+    na_unit_ptr->left_array_size           = (uint16_t)((type_mask & NEIGHBOR_ARRAY_UNIT_LEFT_MASK)
+                                                            ? max_picture_height >>
                                                       na_unit_ptr->granularity_normal_log2
-                                                      : 0);
-    na_unit_ptr->top_array_size      = (uint16_t)((type_mask & NEIGHBOR_ARRAY_UNIT_TOP_MASK)
-                                                      ? max_picture_width >>
+                                                            : 0);
+    na_unit_ptr->top_array_size            = (uint16_t)((type_mask & NEIGHBOR_ARRAY_UNIT_TOP_MASK)
+                                                            ? max_picture_width >>
                                                      na_unit_ptr->granularity_normal_log2
-                                                      : 0);
+                                                            : 0);
     na_unit_ptr->top_left_array_size = (uint16_t)((type_mask & NEIGHBOR_ARRAY_UNIT_TOPLEFT_MASK)
                                                       ? (max_picture_width + max_picture_height) >>
                                                           na_unit_ptr->granularity_top_left_log2
@@ -82,8 +82,8 @@ EbErrorType neighbor_array_unit_ctor(NeighborArrayUnit *na_unit_ptr, uint32_t ma
     na_unit_ptr->granularity_normal        = (uint8_t)(granularity_normal);
     na_unit_ptr->granularity_normal_log2   = (uint8_t)(svt_log2f(na_unit_ptr->granularity_normal));
     na_unit_ptr->granularity_top_left      = (uint8_t)(granularity_top_left);
-    na_unit_ptr->granularity_top_left_log2 = (uint8_t)(
-        svt_log2f(na_unit_ptr->granularity_top_left));
+    na_unit_ptr->granularity_top_left_log2 = (uint8_t)(svt_log2f(
+        na_unit_ptr->granularity_top_left));
 
     na_unit_ptr->max_pic_h = max_picture_height;
 
