@@ -389,6 +389,7 @@ typedef struct PictureControlSet {
              disallow_4x4_all_frames; // true if 4x4 blocks are disallowed for all frames, and NSQ is disabled (since granularity is needed for 8x8 NSQ blocks).  Used to compute the offset for mip.
     uint8_t  wm_level; //warped motion level
     uint8_t  cand_reduction_level;
+    uint8_t  nsq_level;
     uint8_t  txt_level;
     uint8_t  tx_shortcut_level;
     uint8_t  interpolation_search_level;
@@ -424,7 +425,6 @@ typedef struct PictureControlSet {
     uint8_t          pic_lpd0_lvl; // lpd0_lvl signal set at the picture level
     uint8_t          pic_lpd1_lvl; // lpd1_lvl signal set at the picture level
     Bool             pic_bypass_encdec;
-    RefList          colocated_pu_ref_list;
     EncMode          enc_mode;
     InputCoeffLvl    coeff_lvl;
     int32_t          cdef_preset[MAX_TILE_CNTS][4];
@@ -554,8 +554,6 @@ typedef struct TplControls {
     uint8_t
         synth_blk_size; //syntheszier block size, support 8x8 and 16x16 for now. NOTE: this field must be
     //modified inside the get_ function, as it is linked to memory allocation at init time
-    // Calculated qindex based on r0 using qstep calculation
-    bool qstep_based_q_calc; // 0: OFF; 1: ON
     SUBPEL_FORCE_STOP
     subpel_depth; // max subpel depth to search for TPL; FULL_PEL corresponds to subpel off in TPL, QUARTER_PEL is the max precision for TPL subpel
 } TplControls;
@@ -698,15 +696,21 @@ typedef struct PictureParentControlSet {
     uint8_t   picture_qp;
     uint64_t  picture_number;
     uint32_t  cur_order_hint;
-    uint32_t  ref_order_hint[7];
+    uint32_t  ref_order_hint[INTER_REFS_PER_FRAME];
     SliceType slice_type;
     uint8_t   pred_struct_index;
     uint8_t   temporal_layer_index;
     uint64_t  decode_order;
-    Bool      is_used_as_reference_flag;
-    uint8_t   reference_released; // status of PA reference 0: Not release; 1: Released
-    uint8_t   ref_list0_count;
-    uint8_t   ref_list1_count;
+    /* clang-format off */
+    uint64_t released_pics[REF_FRAMES +  1]; // Each picture can release up to 8 references from the DPB (8 is the max number
+                                             // of entries in the DPB). Each frame may also release itself at EOS, which
+                                             // is only done in the encoder to satisfy CI unit tests for MacOS.
+    /* clang-format on */
+    uint8_t released_pics_count;
+    Bool    is_used_as_reference_flag;
+    uint8_t reference_released; // status of PA reference 0: Not release; 1: Released
+    uint8_t ref_list0_count;
+    uint8_t ref_list1_count;
     uint8_t
         ref_list0_count_try; //The number of references to try (in ME / MD) in list0.Should be <= ref_list0_count.
     uint8_t
@@ -741,7 +745,6 @@ typedef struct PictureParentControlSet {
     uint16_t       **variance;
     uint32_t         pre_assignment_buffer_count;
     uint16_t         pic_avg_variance;
-    Bool             scene_transition_flag[MAX_NUM_OF_REF_PIC_LIST];
 
     uint32_t ***picture_histogram;
     uint64_t    average_intensity_per_region[MAX_NUMBER_OF_REGIONS_IN_WIDTH]
@@ -780,17 +783,6 @@ typedef struct PictureParentControlSet {
     uint8_t             hierarchical_levels;
     Bool                init_pred_struct_position_flag;
     int8_t              hierarchical_layers_diff;
-    //Dep-Cnt Clean up is done using 2 mechanism
-    //1: a triggering picture that will clean up all previous pictures;
-    //2: a picture does a self clean up
-    int32_t
-        self_updated_links; // if negative: number of pic not dependent on curr; usefull for pictures in current MG which have a dec order > Base-Intra
-    //due to I frame Insertion
-    DepCntPicInfo updated_links_arr
-        [UPDATED_LINKS]; //if not empty, this picture is a depn-cnt-cleanUp triggering picture (I frame; or MG size change )
-    //this array will store all others pictures needing a dep-cnt clean up.
-    uint32_t
-        other_updated_links_cnt; //how many other pictures in the above array needing a dep-cnt clean-up
     // HME Flags
     Bool enable_hme_flag;
     Bool enable_hme_level0_flag;
@@ -807,29 +799,14 @@ typedef struct PictureParentControlSet {
     EncMode enc_mode;
     // Multi-modes signal(s)
     MultiPassPdLevel multi_pass_pd_level;
-    Bool             disallow_nsq;
-    Bool             disallow_all_nsq_blocks_below_8x8;
-    Bool             disallow_all_nsq_blocks_below_16x16;
-    Bool             disallow_all_non_hv_nsq_blocks_below_16x16;
-    Bool             disallow_all_h4_v4_blocks_below_16x16;
-
-    Bool     disallow_all_nsq_blocks_below_64x64; //disallow nsq in 64x64 and below
-    Bool     disallow_all_nsq_blocks_below_32x32; //disallow nsq in 32x32 and below
-    Bool     disallow_all_nsq_blocks_above_64x64; //disallow nsq in 64x64 and above
-    Bool     disallow_all_nsq_blocks_above_32x32; //disallow nsq in 32x32 and above
-    Bool     disallow_all_nsq_blocks_above_16x16; //disallow nsq in 16x16 and above
-    Bool     disallow_HV4; //disallow H4/V4
-    Bool     disallow_HVA_HVB; // Disallow HA/HB/VA/VB NSQ blocks
-    DlfCtrls dlf_ctrls;
-    uint8_t  intra_pred_mode;
-    uint8_t  frame_end_cdf_update_mode; // mm-signal: 0: OFF, 1:ON
+    DlfCtrls         dlf_ctrls;
+    uint8_t          intra_pred_mode;
+    uint8_t          frame_end_cdf_update_mode; // mm-signal: 0: OFF, 1:ON
     //**********************************************************************************************************//
     Av1RpsNode av1_ref_signal;
     Bool       has_show_existing;
     int32_t    ref_frame_map[REF_FRAMES]; /* maps fb_idx to reference slot */
-    int32_t    is_skip_mode_allowed;
-    int32_t    skip_mode_flag;
-    uint32_t   pic_index; //index of picture in the mg
+    uint32_t   pic_idx_in_mg; //index of picture in the mg
     // Flag for a frame used as a reference - not written to the Bitstream
     int32_t is_reference_frame;
 
@@ -1067,7 +1044,7 @@ typedef struct PictureParentControlSet {
     int8_t   tf_motion_direction; //motion direction in TF   -1:invalid   0:horz  1:vert
     uint8_t  adjust_under_shoot_gf;
     int32_t  is_noise_level;
-
+    bool     r0_based_qps_qpm;
     uint32_t dpb_order_hint[REF_FRAMES]; // spec 6.8.2. ref_order_hint[]
 } PictureParentControlSet;
 
