@@ -46,25 +46,6 @@ typedef struct ReferenceList {
     uint32_t reference_list_count;
 } ReferenceList;
 
-/************************************************
-     * Dependent List
-     *
-     *   list_count - Contains count of how
-     *     deep into list should be used
-     *     depending on how many references are
-     *     being used in the prediction structure.
-     *
-     *   list - Contains the deltaPOCs of
-     *     pictures that reference the current picture.
-     *     The dependent list pictures must be grouped
-     *     by the referenceCount group in ascending
-     *     order.  The grouping is not display order!
-     ************************************************/
-typedef struct DependentList {
-    int32_t *list;
-    uint32_t list_count;
-} DependentList;
-
 /************************************************
      * Prediction Structure Config
      *   Contains a collection of basic control data
@@ -84,11 +65,11 @@ typedef struct PredictionStructureConfig {
 typedef struct PredictionStructureEntry {
     ReferenceList ref_list0;
     ReferenceList ref_list1;
-    DependentList dep_list0;
-    DependentList dep_list1;
+    uint32_t      dep_list0_count;
+    uint32_t      dep_list1_count;
     uint32_t      temporal_layer_index;
     uint32_t      decode_order;
-    EbBool        is_referenced;
+    Bool          is_referenced;
 } PredictionStructureEntry;
 
 /************************************************
@@ -100,13 +81,12 @@ typedef struct PredictionStructure {
     EbDctor                    dctor;
     uint32_t                   pred_struct_entry_count;
     PredictionStructureEntry **pred_struct_entry_ptr_array;
-    EbPred                     pred_type;
+    SvtAv1PredStructure        pred_type;
     uint32_t                   temporal_layer_count;
     uint32_t                   pred_struct_period;
     uint32_t                   maximum_extent;
 
     // Section Indices
-    uint32_t leading_pic_index;
     uint32_t init_pic_index;
     uint32_t steady_state_index;
 } PredictionStructure;
@@ -120,7 +100,7 @@ typedef struct PredictionStructureGroup {
     EbDctor               dctor;
     PredictionStructure **prediction_structure_ptr_array;
     uint32_t              prediction_structure_count;
-    void *                priv; /* private member*/
+    void                 *priv; /* private member*/
     uint8_t               ref_count_used;
 } PredictionStructureGroup;
 
@@ -131,7 +111,7 @@ typedef struct PredictionStructureGroup {
 //   PredictionStructureGroup* pred_struct_group_ptr,
 //   struct SequenceControlSet* scs_ptr);
 extern PredictionStructure *get_prediction_structure(
-    PredictionStructureGroup *prediction_structure_group_ptr, EbPred pred_structure,
+    PredictionStructureGroup *prediction_structure_group_ptr, SvtAv1PredStructure pred_structure,
     uint32_t number_of_references, uint32_t levels_of_hierarchy);
 typedef enum {
     LAST  = 0,
