@@ -24,6 +24,13 @@
 extern "C" {
 #endif
 
+extern const int16_t      av1_down2_symeven_half_filter[4];
+extern const int16_t      av1_down2_symodd_half_filter[4];
+extern const InterpKernel av1_filteredinterp_filters500[(1 << RS_SUBPEL_BITS)];
+extern const InterpKernel av1_filteredinterp_filters625[(1 << RS_SUBPEL_BITS)];
+extern const InterpKernel av1_filteredinterp_filters750[(1 << RS_SUBPEL_BITS)];
+extern const InterpKernel av1_filteredinterp_filters875[(1 << RS_SUBPEL_BITS)];
+
 typedef struct {
     uint16_t encoding_width;
     uint16_t encoding_height;
@@ -36,27 +43,38 @@ void scale_source_references(SequenceControlSet *scs_ptr, PictureParentControlSe
 void scale_rec_references(PictureControlSet *pcs_ptr, EbPictureBufferDesc *input_picture_ptr,
                           uint8_t hbd_mode_decision);
 
-void use_scaled_rec_refs_if_needed(PictureControlSet *  pcs_ptr,
+void use_scaled_rec_refs_if_needed(PictureControlSet   *pcs_ptr,
                                    EbPictureBufferDesc *input_picture_ptr,
                                    EbReferenceObject *ref_obj, EbPictureBufferDesc **ref_pic,
                                    uint8_t hbd_mode_decision);
 
 void use_scaled_source_refs_if_needed(PictureParentControlSet *pcs_ptr,
-                                      EbPictureBufferDesc *    input_picture_ptr,
-                                      EbPaReferenceObject *    ref_obj,
-                                      EbPictureBufferDesc **   ref_pic_ptr,
-                                      EbPictureBufferDesc **   quarter_ref_pic_ptr,
-                                      EbPictureBufferDesc **   sixteenth_ref_pic_ptr);
+                                      EbPictureBufferDesc     *input_picture_ptr,
+                                      EbPaReferenceObject     *ref_obj,
+                                      EbPictureBufferDesc    **ref_pic_ptr,
+                                      EbPictureBufferDesc    **quarter_ref_pic_ptr,
+                                      EbPictureBufferDesc    **sixteenth_ref_pic_ptr);
 
 void scale_pcs_params(SequenceControlSet *scs_ptr, PictureParentControlSet *pcs_ptr,
                       superres_params_type spr_params, uint16_t source_width,
                       uint16_t source_height);
 
+// resize picture for both super-res and scaling-ref
 void init_resize_picture(SequenceControlSet *scs_ptr, PictureParentControlSet *pcs_ptr);
 
 void reset_resized_picture(SequenceControlSet *scs_ptr, PictureParentControlSet *pcs_ptr,
                            EbPictureBufferDesc *input_picture_ptr);
 
+uint8_t get_denom_idx(uint8_t scale_denom);
+
+EbErrorType downscaled_source_buffer_desc_ctor(EbPictureBufferDesc **picture_ptr,
+                                               EbPictureBufferDesc  *picture_ptr_for_reference,
+                                               superres_params_type  spr_params);
+
+EbErrorType av1_resize_frame(const EbPictureBufferDesc *src, EbPictureBufferDesc *dst, int bd,
+                             const int num_planes, const uint32_t ss_x, const uint32_t ss_y,
+                             uint8_t is_packed, uint32_t buffer_enable_mask, uint8_t is_2bcompress);
+
 static INLINE int coded_to_superres_mi(int mi_col, int denom) {
     return (mi_col * denom + SCALE_NUMERATOR / 2) / SCALE_NUMERATOR;
 }
