@@ -433,18 +433,26 @@ void speed_buffer_control(ResourceCoordinationContext *context_ptr,
     svt_release_mutex(scs_ptr->encode_context_ptr->sc_buffer_mutex);
     context_ptr->prev_enc_mod = scs_ptr->encode_context_ptr->enc_mode;
 }
+// Film grain (assigning the random-seed)
+static void assign_film_grain_random_seed(PictureParentControlSet *pcs) {
+    uint16_t *fgn_random_seed_ptr              = &pcs->scs_ptr->film_grain_random_seed;
+    pcs->frm_hdr.film_grain_params.random_seed = *fgn_random_seed_ptr;
+    *fgn_random_seed_ptr += 3381; // Changing random seed for film grain
+    if (!(*fgn_random_seed_ptr)) // Random seed should not be zero
+        *fgn_random_seed_ptr += 7391;
+}
 static EbErrorType reset_pcs_av1(PictureParentControlSet *pcs_ptr) {
     FrameHeader *frm_hdr = &pcs_ptr->frm_hdr;
     Av1Common   *cm      = pcs_ptr->av1_cm;
 
     pcs_ptr->gf_interval = 0;
 
-    pcs_ptr->reference_released   = 0;
-    pcs_ptr->is_skip_mode_allowed = 0;
-    pcs_ptr->skip_mode_flag       = 0;
-    frm_hdr->frame_type           = KEY_FRAME;
-    frm_hdr->show_frame           = 1;
-    frm_hdr->showable_frame       = 1; // frame can be used as show existing frame in future
+    pcs_ptr->reference_released                 = 0;
+    frm_hdr->skip_mode_params.skip_mode_allowed = 0;
+    frm_hdr->skip_mode_params.skip_mode_flag    = 0;
+    frm_hdr->frame_type                         = KEY_FRAME;
+    frm_hdr->show_frame                         = 1;
+    frm_hdr->showable_frame = 1; // frame can be used as show existing frame in future
     // Flag for a frame used as a reference - not written to the Bitstream
     pcs_ptr->is_reference_frame = 0;
     // Flag signaling that the frame is encoded using only INTRA modes.
@@ -511,7 +519,7 @@ static EbErrorType reset_pcs_av1(PictureParentControlSet *pcs_ptr) {
     pcs_ptr->frame_context_idx = 0; /* Context to use/update */
     for (int32_t i = 0; i < REF_FRAMES; i++) pcs_ptr->fb_of_context_type[i] = 0;
     frm_hdr->primary_ref_frame = PRIMARY_REF_NONE;
-    if (pcs_ptr->scs_ptr->static_config.rate_control_mode == 2 &&
+    if (pcs_ptr->scs_ptr->static_config.rate_control_mode == SVT_AV1_RC_MODE_CBR &&
         pcs_ptr->scs_ptr->static_config.intra_period_length != -1) {
         pcs_ptr->frame_offset = pcs_ptr->picture_number %
             (pcs_ptr->scs_ptr->static_config.intra_period_length + 1);
@@ -562,12 +570,14 @@ static EbErrorType reset_pcs_av1(PictureParentControlSet *pcs_ptr) {
 
     pcs_ptr->me_segments_total_count = (uint16_t)(pcs_ptr->me_segments_column_count *
                                                   pcs_ptr->me_segments_row_count);
-    pcs_ptr->sb_total_count_pix      = pcs_ptr->sb_total_count;
     pcs_ptr->tpl_disp_coded_sb_count = 0;
 
     pcs_ptr->tpl_src_data_ready  = 0;
     pcs_ptr->tf_motion_direction = -1;
 
+    // Assign the film-grain random-seed
+    assign_film_grain_random_seed(pcs_ptr);
+
     return EB_ErrorNone;
 }
 /***********************************************
@@ -703,9 +713,10 @@ void setup_two_pass(SequenceControlSet *scs_ptr) {
             scs_ptr->twopass.stats_buf_ctx->stats_in_end =
                 &scs_ptr->twopass.stats_buf_ctx->stats_in_start[packets - 1];
             svt_av1_init_second_pass(scs_ptr);
+            //less than 200 frames or gop_constraint_rc, used in VBR and set in multipass encode
             scs_ptr->is_short_clip = scs_ptr->twopass.stats_buf_ctx->total_stats->count < 200
                 ? 1
-                : 0; //less than 200 frames, used in VBR and set in multipass encode
+                : scs_ptr->is_short_clip;
         }
     } else if (scs_ptr->lap_rc)
         svt_av1_init_single_pass_lap(scs_ptr);
@@ -715,14 +726,12 @@ extern EbErrorType first_pass_signal_derivation_pre_analysis_pcs(PictureParentCo
 extern EbErrorType first_pass_signal_derivation_pre_analysis_scs(SequenceControlSet *scs_ptr);
 
 static EbErrorType realloc_sb_param(SequenceControlSet *scs_ptr, PictureParentControlSet *pcs_ptr) {
-    EB_FREE_ARRAY(pcs_ptr->sb_params_array);
-    EB_MALLOC_ARRAY(pcs_ptr->sb_params_array, scs_ptr->sb_total_count);
-    memcpy(pcs_ptr->sb_params_array,
-           scs_ptr->sb_params_array,
-           sizeof(SbParams) * scs_ptr->sb_total_count);
+    EB_FREE_ARRAY(pcs_ptr->b64_geom);
+    EB_MALLOC_ARRAY(pcs_ptr->b64_geom, scs_ptr->b64_total_count);
+    memcpy(pcs_ptr->b64_geom, scs_ptr->b64_geom, sizeof(B64Geom) * scs_ptr->b64_total_count);
     EB_FREE_ARRAY(pcs_ptr->sb_geom);
-    EB_MALLOC_ARRAY(pcs_ptr->sb_geom, scs_ptr->sb_tot_cnt);
-    memcpy(pcs_ptr->sb_geom, scs_ptr->sb_geom, sizeof(SbGeom) * scs_ptr->sb_tot_cnt);
+    EB_MALLOC_ARRAY(pcs_ptr->sb_geom, scs_ptr->sb_total_count);
+    memcpy(pcs_ptr->sb_geom, scs_ptr->sb_geom, sizeof(SbGeom) * scs_ptr->sb_total_count);
     pcs_ptr->is_pcs_sb_params = TRUE;
     return EB_ErrorNone;
 }
@@ -832,7 +841,7 @@ void *resource_coordination_kernel(void *input_ptr) {
                 scs_ptr->max_input_luma_height;
             derive_input_resolution(&scs_ptr->input_resolution, input_size);
 
-            sb_params_init(scs_ptr);
+            b64_geom_init(scs_ptr);
             sb_geom_init(scs_ptr);
 
             // sf_identity
@@ -876,13 +885,13 @@ void *resource_coordination_kernel(void *input_ptr) {
                 scs_ptr->static_config.resize_mode > RESIZE_NONE)
                 realloc_sb_param(scs_ptr, pcs_ptr);
             else {
-                pcs_ptr->sb_params_array  = scs_ptr->sb_params_array;
+                pcs_ptr->b64_geom         = scs_ptr->b64_geom;
                 pcs_ptr->sb_geom          = scs_ptr->sb_geom;
                 pcs_ptr->is_pcs_sb_params = FALSE;
             }
             pcs_ptr->input_resolution  = scs_ptr->input_resolution;
-            pcs_ptr->picture_sb_width  = scs_ptr->pic_width_in_sb;
-            pcs_ptr->picture_sb_height = scs_ptr->picture_height_in_sb;
+            pcs_ptr->picture_sb_width  = scs_ptr->pic_width_in_b64;
+            pcs_ptr->picture_sb_height = scs_ptr->pic_height_in_b64;
 
             pcs_ptr->overlay_ppcs_ptr   = NULL;
             pcs_ptr->is_alt_ref         = 0;
@@ -967,9 +976,10 @@ void *resource_coordination_kernel(void *input_ptr) {
             }
             // Set Picture Control Flags
             pcs_ptr->idr_flag          = scs_ptr->encode_context_ptr->initial_picture;
+            pcs_ptr->cra_flag          = 0;
             pcs_ptr->scene_change_flag = FALSE;
             pcs_ptr->qp_on_the_fly     = FALSE;
-            pcs_ptr->sb_total_count    = scs_ptr->sb_total_count;
+            pcs_ptr->b64_total_count   = scs_ptr->b64_total_count;
             if (scs_ptr->speed_control_flag) {
                 speed_buffer_control(context_ptr, pcs_ptr, scs_ptr);
             } else
@@ -1034,23 +1044,17 @@ void *resource_coordination_kernel(void *input_ptr) {
             EbPictureBufferDesc *input_padded_picture_ptr =
                 (EbPictureBufferDesc *)pa_ref_obj->input_padded_picture_ptr;
             input_padded_picture_ptr->buffer_y = buff_y8b;
-            // Since overlay pictures are not added to PA_Reference queue in PD and not released there, the life count is only set to 1
-            if (pcs_ptr->is_overlay)
-                // Give the new Reference a nominal live_count of 1
-                svt_object_inc_live_count(pcs_ptr->pa_reference_picture_wrapper_ptr, 1);
-            else
-                svt_object_inc_live_count(pcs_ptr->pa_reference_picture_wrapper_ptr, 2);
+            svt_object_inc_live_count(pcs_ptr->pa_reference_picture_wrapper_ptr, 1);
             if (pcs_ptr->eb_y8b_wrapper_ptr) {
                 // y8b follows longest life cycle of pa ref and input. so it needs to build on top of live count of pa ref
-                svt_object_inc_live_count(pcs_ptr->eb_y8b_wrapper_ptr, 2);
+                svt_object_inc_live_count(pcs_ptr->eb_y8b_wrapper_ptr, 1);
             }
             if (scs_ptr->static_config.restricted_motion_vector) {
                 struct PictureParentControlSet *ppcs_ptr = pcs_ptr;
                 Av1Common *const                cm       = ppcs_ptr->av1_cm;
-                uint8_t pic_width_in_sb = (uint8_t)((pcs_ptr->aligned_width + scs_ptr->sb_size_pix -
-                                                     1) /
-                                                    scs_ptr->sb_size_pix);
-                int     tile_row, tile_col;
+                uint8_t                         pic_width_in_sb =
+                    (uint8_t)((pcs_ptr->aligned_width + scs_ptr->sb_size - 1) / scs_ptr->sb_size);
+                int       tile_row, tile_col;
                 uint32_t  x_sb_index, y_sb_index;
                 const int tile_cols = cm->tiles_info.tile_cols;
                 const int tile_rows = cm->tiles_info.tile_rows;
@@ -1075,16 +1079,14 @@ void *resource_coordination_kernel(void *input_ptr) {
                                   ((uint32_t)cm->tiles_info.tile_col_start_mi[tile_col + 1] >>
                                    sb_size_log2));
                                  x_sb_index++) {
-                                int sb_index = (uint16_t)(x_sb_index +
+                                int sb_index                             = (uint16_t)(x_sb_index +
                                                           y_sb_index * pic_width_in_sb);
-                                scs_ptr->sb_params_array[sb_index].tile_start_x = 4 *
+                                scs_ptr->b64_geom[sb_index].tile_start_x = 4 *
                                     tile_info.mi_col_start;
-                                scs_ptr->sb_params_array[sb_index].tile_end_x = 4 *
-                                    tile_info.mi_col_end;
-                                scs_ptr->sb_params_array[sb_index].tile_start_y = 4 *
+                                scs_ptr->b64_geom[sb_index].tile_end_x   = 4 * tile_info.mi_col_end;
+                                scs_ptr->b64_geom[sb_index].tile_start_y = 4 *
                                     tile_info.mi_row_start;
-                                scs_ptr->sb_params_array[sb_index].tile_end_y = 4 *
-                                    tile_info.mi_row_end;
+                                scs_ptr->b64_geom[sb_index].tile_end_y = 4 * tile_info.mi_row_end;
                             }
                         }
                     }
