@@ -18,6 +18,13 @@
 #ifdef __cplusplus
 extern "C" {
 #endif
+
+typedef struct InputCommand {
+    EbDctor          dctor;
+    EbObjectWrapper *eb_input_wrapper_ptr;
+    EbObjectWrapper *eb_y8b_wrapper_ptr;
+} InputCommand;
+
 /**************************************
      * Process Results
      **************************************/
