@@ -18,10 +18,12 @@
 /***************************************
  * Extern Function Declaration
  ***************************************/
-EbErrorType  tpl_disp_context_ctor(EbThreadContext *  thread_context_ptr,
+EbErrorType  tpl_disp_context_ctor(EbThreadContext   *thread_context_ptr,
                                    const EbEncHandle *enc_handle_ptr, int index, int tasks_index);
 extern void *tpl_disp_kernel(void *input_ptr);
-EbErrorType  source_based_operations_context_ctor(EbThreadContext *  thread_context_ptr,
+void         generate_lambda_scaling_factor(PictureParentControlSet *pcs, int64_t mc_dep_cost_base);
+void         generate_r0beta(PictureParentControlSet *pcs);
+EbErrorType  source_based_operations_context_ctor(EbThreadContext   *thread_context_ptr,
                                                   const EbEncHandle *enc_handle_ptr, int tpl_index,
                                                   int index);
 
