@@ -131,8 +131,8 @@ extern int32_t av1_quantize_inv_quantize(
     int32_t segmentation_qp_offset, uint32_t width, uint32_t height, TxSize txsize, uint16_t *eob,
     uint32_t *y_count_non_zero_coeffs, uint32_t component_type, uint32_t bit_increment,
     TxType tx_type, ModeDecisionCandidateBuffer *candidate_buffer, int16_t txb_skip_context,
-    int16_t dc_sign_context, PredictionMode pred_mode, EbBool is_intra_bc, uint32_t lambda,
-    EbBool is_encode_pass);
+    int16_t dc_sign_context, PredictionMode pred_mode, Bool is_intra_bc, uint32_t lambda,
+    Bool is_encode_pass);
 
 int32_t av1_quantize_inv_quantize_light(PictureControlSet *pcs_ptr, int32_t *coeff,
                                         int32_t *quant_coeff, int32_t *recon_coeff, uint32_t qindex,
