@@ -69,7 +69,6 @@ static gboolean gst_svtav1enc_propose_allocation (GstVideoEncoder * encoder,
 static gboolean gst_svtav1enc_flush (GstVideoEncoder * encoder);
 
 /* helpers */
-void set_default_svt_configuration (EbSvtAv1EncConfiguration * svt_config);
 gint compare_video_code_frame_and_pts (const void *video_codec_frame_ptr,
     const void *pts_ptr);
 
@@ -191,8 +190,8 @@ gst_svtav1enc_class_init (GstSvtAv1EncClass * klass)
       g_param_spec_uint ("speed", "speed (Encoder Mode)",
           "Quality vs density tradeoff point"
           " that the encoding is to be performed at"
-          " (0 is the highest quality, 8 is the highest speed) ",
-          0, 8, PROP_ENCMODE_DEFAULT,
+          " (0 is the highest quality, 12 is the highest speed) ",
+          0, 12, PROP_ENCMODE_DEFAULT,
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
   g_object_class_install_property (gobject_class, PROP_B_PYRAMID,
@@ -309,7 +308,6 @@ gst_svtav1enc_init (GstSvtAv1Enc * svtav1enc)
     return;
   }
   /* setting configuration here since svt_av1_enc_init_handle overrides it */
-  set_default_svt_configuration (svtav1enc->svt_config);
   GST_OBJECT_UNLOCK (svtav1enc);
 }
 
@@ -491,6 +489,7 @@ gst_svtav1enc_allocate_svt_buffers (GstSvtAv1Enc * svtav1enc)
   svtav1enc->input_buf->size = sizeof (EbBufferHeaderType);
   svtav1enc->input_buf->p_app_private = NULL;
   svtav1enc->input_buf->pic_type = EB_AV1_INVALID_PICTURE;
+  svtav1enc->input_buf->metadata = NULL;
 
   return TRUE;
 }
@@ -521,15 +520,11 @@ gst_svtav1enc_configure_svt (GstSvtAv1Enc * svtav1enc)
   svtav1enc->svt_config->source_height = GST_VIDEO_INFO_HEIGHT (info);
   svtav1enc->svt_config->frame_rate_numerator = GST_VIDEO_INFO_FPS_N (info)> 0 ? GST_VIDEO_INFO_FPS_N (info) : 1;
   svtav1enc->svt_config->frame_rate_denominator = GST_VIDEO_INFO_FPS_D (info) > 0 ? GST_VIDEO_INFO_FPS_D (info) : 1;
-  svtav1enc->svt_config->frame_rate =
-      svtav1enc->svt_config->frame_rate_numerator /
-      svtav1enc->svt_config->frame_rate_denominator;
-
-  if (svtav1enc->svt_config->frame_rate < 1000) {
-      svtav1enc->svt_config->frame_rate = svtav1enc->svt_config->frame_rate << 16;
-  }
-
-  GST_LOG_OBJECT(svtav1enc, "width %d, height %d, framerate %d", svtav1enc->svt_config->source_width, svtav1enc->svt_config->source_height, svtav1enc->svt_config->frame_rate);
+  GST_LOG_OBJECT(svtav1enc,
+                "width %d, height %d, framerate %d",
+                svtav1enc->svt_config->source_width,
+                svtav1enc->svt_config->source_height,
+                svtav1enc->svt_config->frame_rate_numerator / svtav1enc->svt_config->frame_rate_denominator);
 
   /* TODO: better handle HDR metadata when GStreamer will have such support
    * https://gitlab.freedesktop.org/gstreamer/gst-plugins-base/issues/400 */
@@ -561,80 +556,6 @@ gst_svtav1enc_start_svt (GstSvtAv1Enc * svtav1enc)
   return TRUE;
 }
 
-void
-set_default_svt_configuration (EbSvtAv1EncConfiguration * svt_config)
-{
-  memset(svt_config, 0, sizeof(EbSvtAv1EncConfiguration));
-  svt_config->source_width = 0;
-  svt_config->source_height = 0;
-  svt_config->intra_period_length = PROP_GOP_SIZE_DEFAULT - 1;
-  svt_config->intra_refresh_type = PROP_INTRA_REFRESH_DEFAULT;
-  svt_config->enc_mode = PROP_ENCMODE_DEFAULT;
-  svt_config->frame_rate = 25;
-  svt_config->frame_rate_denominator = 1;
-  svt_config->frame_rate_numerator = 25;
-  svt_config->hierarchical_levels = PROP_HIERARCHICAL_LEVEL_DEFAULT;
-  svt_config->pred_structure = PROP_PRED_STRUCTURE_DEFAULT;
-  svt_config->scene_change_detection = PROP_SCD_DEFAULT;
-  svt_config->rate_control_mode = PROP_RC_MODE_DEFAULT; // todo: add CVBR
-  svt_config->target_bit_rate = PROP_BITRATE_DEFAULT;
-  svt_config->max_qp_allowed = PROP_QP_MAX_DEFAULT;
-  svt_config->min_qp_allowed = PROP_QP_MIN_DEFAULT;
-  svt_config->screen_content_mode = FALSE;
-  svt_config->enable_adaptive_quantization = FALSE;
-  svt_config->qp = PROP_QP_DEFAULT;
-  svt_config->use_qp_file = FALSE;
-  svt_config->enable_dlf_flag = (PROP_DEBLOCKING_DEFAULT == TRUE);
-  svt_config->film_grain_denoise_strength = FALSE;
-  svt_config->cdef_level = -1;
-  svt_config->enable_restoration_filtering = -1;
-  svt_config->enable_mfmv = -1;
-  // HME parameters
-  svt_config->channel_id = 0;
-  svt_config->active_channel_count = 1;
-  svt_config->recon_enabled = FALSE;
-
-  // thread affinity
-  svt_config->logical_processors = PROP_CORES_DEFAULT;
-  svt_config->target_socket = PROP_SOCKET_DEFAULT;
-  svt_config->pin_threads = 0;
-
-  // tile based encoding
-  svt_config->tile_columns = 0;
-  svt_config->tile_rows = 0;
-  svt_config->restricted_motion_vector = FALSE;
-
-  // alt-ref
-  svt_config->enable_tf = TRUE;
-  svt_config->enable_overlays = FALSE;
-
-  // super resolution
-  svt_config->superres_mode = FALSE; // SUPERRES_NONE
-  svt_config->superres_denom = 8;
-  svt_config->superres_kf_denom = 8;
-  svt_config->superres_qthres = 43;
-
-  // latency
-
-  // Annex A
-  svt_config->profile = 0;
-  svt_config->tier = 0;
-  svt_config->level = 0;
-
-  svt_config->stat_report = FALSE;
-  svt_config->high_dynamic_range_input = FALSE;
-  svt_config->encoder_bit_depth = 8;
-  svt_config->encoder_color_format = 1; // todo. Only 420 for now.
-  svt_config->compressed_ten_bit_format = FALSE;
-  svt_config->use_cpu_flags = CPU_FLAGS_ALL;
-
-  // color description
-  svt_config->color_range = 0;
-  svt_config->color_primaries = 2;
-  svt_config->transfer_characteristics = 2;
-  svt_config->matrix_coefficients = 2;
-}
-
 GstFlowReturn
 gst_svtav1enc_encode (GstSvtAv1Enc * svtav1enc, GstVideoCodecFrame * frame)
 {
@@ -644,6 +565,7 @@ gst_svtav1enc_encode (GstSvtAv1Enc * svtav1enc, GstVideoCodecFrame * frame)
   EbSvtIOFormat *input_picture_buffer =
       (EbSvtIOFormat *) svtav1enc->input_buf->p_buffer;
   GstVideoFrame video_frame;
+  EbPrivDataNode private_data;
 
   if (!gst_video_frame_map (&video_frame, &svtav1enc->state->info,
           frame->input_buffer, GST_MAP_READ)) {
@@ -669,7 +591,12 @@ gst_svtav1enc_encode (GstSvtAv1Enc * svtav1enc, GstVideoCodecFrame * frame)
 
   /* Fill in Buffers Header control data */
   input_buffer->flags = 0;
-  input_buffer->p_app_private = (void *) frame;
+  // private data is copied in svt_av1_enc_send_picture
+  private_data.node_type = PRIVATE_DATA;
+  private_data.size = sizeof (GstVideoCodecFrame);
+  private_data.data = (void *) frame;
+  private_data.next = NULL;
+  input_buffer->p_app_private = (void *) &private_data;
   input_buffer->pts = frame->pts;
   input_buffer->pic_type = EB_AV1_INVALID_PICTURE;
 
@@ -677,6 +604,8 @@ gst_svtav1enc_encode (GstSvtAv1Enc * svtav1enc, GstVideoCodecFrame * frame)
     input_buffer->pic_type = EB_AV1_KEY_PICTURE;
   }
 
+  input_buffer->metadata = NULL;
+
   res = svt_av1_enc_send_picture(svtav1enc->svt_encoder, input_buffer);
   if (res != EB_ErrorNone) {
     GST_ELEMENT_ERROR (svtav1enc, LIBRARY, ENCODE, (NULL), ("error in sending picture to encoder"));
@@ -699,6 +628,7 @@ gst_svtav1enc_send_eos (GstSvtAv1Enc * svtav1enc)
   input_buffer.p_app_private = NULL;
   input_buffer.flags = EB_BUFFERFLAG_EOS;
   input_buffer.p_buffer = NULL;
+  input_buffer.metadata = NULL;
 
   ret = svt_av1_enc_send_picture(svtav1enc->svt_encoder, &input_buffer);
 
@@ -758,7 +688,8 @@ gst_svtav1enc_dequeue_encoded_frames (GstSvtAv1Enc * svtav1enc,
        * it's not currently the case with SVT-AV1
        * so we fallback on using its PTS to find it back */
       if (output_buf->p_app_private) {
-        frame = (GstVideoCodecFrame *) output_buf->p_app_private;
+        EbPrivDataNode *private_data = (EbPrivDataNode *) output_buf->p_app_private;
+        frame = (GstVideoCodecFrame *) private_data->data;
       } else {
         pending_frames = gst_video_encoder_get_frames (GST_VIDEO_ENCODER
             (svtav1enc));
@@ -907,17 +838,19 @@ gst_svtav1enc_set_format (GstVideoEncoder * encoder,
   gst_svtav1enc_allocate_svt_buffers (svtav1enc);
   gst_svtav1enc_start_svt (svtav1enc);
 
-  uint32_t fps = (uint32_t)((svtav1enc->svt_config->frame_rate > 1000) ?
-      svtav1enc->svt_config->frame_rate >> 16 : svtav1enc->svt_config->frame_rate);
-  fps = fps > 120 ? 120 : fps;
-  fps = fps < 24 ? 24 : fps;
+  uint32_t fps = svtav1enc->svt_config->frame_rate_numerator /
+                    svtav1enc->svt_config->frame_rate_denominator;
+  fps          = fps > 120 ? 120 : fps;
+  fps          = fps < 24 ? 24 : fps;
 
-  min_latency_frames =  ((fps * 5) >> 2);
+  min_latency_frames = ((fps * 5) >> 2);
 
   /* TODO: find a better value for max_latency */
-  gst_video_encoder_set_latency (encoder,
-      min_latency_frames * GST_SECOND / svtav1enc->svt_config->frame_rate,
-      3 * GST_SECOND);
+  gst_video_encoder_set_latency(encoder,
+                                min_latency_frames * GST_SECOND /
+                                    (svtav1enc->svt_config->frame_rate_numerator /
+                                     svtav1enc->svt_config->frame_rate_denominator),
+                                3 * GST_SECOND);
 
   src_caps =
       gst_static_pad_template_get_caps (&gst_svtav1enc_src_pad_template);
