@@ -44,6 +44,7 @@
 #include "random.h"
 #include "convolve.h"
 #include "util.h"
+#include "EbEncInterPrediction.h"
 
 using std::make_tuple;
 using svt_av1_test_tool::SVTRandom;
@@ -270,6 +271,9 @@ TEST_P(LbdCompBlendD16Test, BlendA64MaskD16) {
 INSTANTIATE_TEST_CASE_P(
     BLEND, LbdCompBlendD16Test,
     ::testing::ValuesIn({make_tuple(svt_aom_lowbd_blend_a64_d16_mask_c,
+                                    svt_aom_lowbd_blend_a64_d16_mask_sse4_1,
+                                    "svt_aom_lowbd_blend_a64_d16_mask_sse4_1"),
+                         make_tuple(svt_aom_lowbd_blend_a64_d16_mask_c,
                                     svt_aom_lowbd_blend_a64_d16_mask_avx2,
                                     "svt_aom_lowbd_blend_a64_d16_mask_avx2")}));
 
@@ -292,13 +296,18 @@ class LbdCompBlendHMaskTest
     void run_blend(int subw, int subh) override {
         (void)subw;
         (void)subh;
+
+        if (w_ > 32)
+            return;
+        const uint8_t *const mask = svt_av1_get_obmc_mask(w_);
+
         func_ref_(ref_dst_,
                   dst_stride_,
                   src0_,
                   src_stride_,
                   src1_,
                   src_stride_,
-                  mask_,
+                  mask,
                   w_,
                   h_);
         func_tst_(tst_dst_,
@@ -307,7 +316,7 @@ class LbdCompBlendHMaskTest
                   src_stride_,
                   src1_,
                   src_stride_,
-                  mask_,
+                  mask,
                   w_,
                   h_);
     }
@@ -319,9 +328,11 @@ TEST_P(LbdCompBlendHMaskTest, BlendA64Mask) {
 
 INSTANTIATE_TEST_CASE_P(
     BLEND, LbdCompBlendHMaskTest,
-    ::testing::ValuesIn({make_tuple(svt_aom_blend_a64_hmask_c,
-                                    svt_aom_blend_a64_hmask_sse4_1,
-                                    "svt_aom_blend_a64_hmask_sse4_1")}));
+    ::testing::ValuesIn(
+        {make_tuple(svt_aom_blend_a64_hmask_c, svt_aom_blend_a64_hmask_sse4_1,
+                    "svt_aom_blend_a64_hmask_sse4_1"),
+         make_tuple(svt_aom_blend_a64_hmask_c, svt_av1_blend_a64_hmask_avx2,
+                    "svt_dav1d_blend_a64_hmask_avx2")}));
 
 using LbdBlendA64VMaskFunc = void (*)(uint8_t *, uint32_t, const uint8_t *,
                                       uint32_t, const uint8_t *, uint32_t,
@@ -342,13 +353,18 @@ class LbdCompBlendVMaskTest
     void run_blend(int subw, int subh) override {
         (void)subw;
         (void)subh;
+
+        if (h_ > 32)
+            return;
+        const uint8_t *const mask = svt_av1_get_obmc_mask(h_);
+
         func_ref_(ref_dst_,
                   dst_stride_,
                   src0_,
                   src_stride_,
                   src1_,
                   src_stride_,
-                  mask_,
+                  mask,
                   w_,
                   h_);
         func_tst_(tst_dst_,
@@ -357,7 +373,7 @@ class LbdCompBlendVMaskTest
                   src_stride_,
                   src1_,
                   src_stride_,
-                  mask_,
+                  mask,
                   w_,
                   h_);
     }
@@ -369,9 +385,11 @@ TEST_P(LbdCompBlendVMaskTest, BlendA64Mask) {
 
 INSTANTIATE_TEST_CASE_P(
     BLEND, LbdCompBlendVMaskTest,
-    ::testing::ValuesIn({make_tuple(svt_aom_blend_a64_vmask_c,
-                                    svt_aom_blend_a64_vmask_sse4_1,
-                                    "svt_aom_blend_a64_vmask_sse4_1")}));
+    ::testing::ValuesIn(
+        {make_tuple(svt_aom_blend_a64_vmask_c, svt_aom_blend_a64_vmask_sse4_1,
+                    "svt_aom_blend_a64_vmask_sse4_1"),
+         make_tuple(svt_aom_blend_a64_vmask_c, svt_av1_blend_a64_vmask_avx2,
+                    "svt_dav1d_blend_a64_vmask_avx2")}));
 
 using HbdBlendA64MaskFunc = void (*)(uint8_t *, uint32_t, const uint8_t *,
                                      uint32_t, const uint8_t *, uint32_t,
@@ -499,11 +517,15 @@ TEST_P(HbdCompBlendD16Test, BlendA64MaskD16) {
     run_hbd_test(12);
 }
 
-INSTANTIATE_TEST_CASE_P(BLEND, HbdCompBlendD16Test,
-                        ::testing::ValuesIn({make_tuple(
-                            svt_aom_highbd_blend_a64_d16_mask_c,
-                            svt_aom_highbd_blend_a64_d16_mask_avx2,
-                            "svt_aom_highbd_blend_a64_d16_mask_avx2")}));
+INSTANTIATE_TEST_CASE_P(
+    BLEND, HbdCompBlendD16Test,
+    ::testing::ValuesIn(
+        {make_tuple(svt_aom_highbd_blend_a64_d16_mask_c,
+                    svt_aom_highbd_blend_a64_d16_mask_sse4_1,
+                    "svt_aom_highbd_blend_a64_d16_mask_sse4_1"),
+         make_tuple(svt_aom_highbd_blend_a64_d16_mask_c,
+                    svt_aom_highbd_blend_a64_d16_mask_avx2,
+                    "svt_aom_highbd_blend_a64_d16_mask_avx2")}));
 
 using HbdBlendA64HMaskFunc = void (*)(uint8_t *, uint32_t, const uint8_t *,
                                       uint32_t, const uint8_t *, uint32_t,
@@ -588,13 +610,18 @@ class EbHbdCompBlendHMaskTest
     void run_blend(int subw, int subh) override {
         (void)subw;
         (void)subh;
+
+        if (w_ > 32)
+            return;
+        const uint8_t *const mask = svt_av1_get_obmc_mask(w_);
+
         func_ref_((uint16_t *)ref_dst_,
                   dst_stride_,
                   (uint16_t *)src0_,
                   src_stride_,
                   (uint16_t *)src1_,
                   src_stride_,
-                  mask_,
+                  mask,
                   w_,
                   h_,
                   bd_);
@@ -604,7 +631,7 @@ class EbHbdCompBlendHMaskTest
                   src_stride_,
                   (uint16_t *)src1_,
                   src_stride_,
-                  mask_,
+                  mask,
                   w_,
                   h_,
                   bd_);
@@ -617,11 +644,15 @@ TEST_P(EbHbdCompBlendHMaskTest, BlendA64Mask) {
     run_hbd_test(12);
 }
 
-INSTANTIATE_TEST_CASE_P(BLEND, EbHbdCompBlendHMaskTest,
-                        ::testing::ValuesIn({make_tuple(
-                            svt_aom_highbd_blend_a64_hmask_16bit_c,
-                            svt_aom_highbd_blend_a64_hmask_16bit_sse4_1,
-                            "svt_aom_highbd_blend_a64_hmask_16bit_sse4_1")}));
+INSTANTIATE_TEST_CASE_P(
+    BLEND, EbHbdCompBlendHMaskTest,
+    ::testing::ValuesIn(
+        {make_tuple(svt_aom_highbd_blend_a64_hmask_16bit_c,
+                    svt_aom_highbd_blend_a64_hmask_16bit_sse4_1,
+                    "svt_aom_highbd_blend_a64_hmask_16bit_sse4_1"),
+         make_tuple(svt_aom_highbd_blend_a64_hmask_16bit_c,
+                    svt_av1_highbd_blend_a64_hmask_16bit_avx2,
+                    "svt_dav1d_highbd_blend_a64_hmask_16bit_avx2")}));
 
 using HbdBlendA64VMaskFunc = void (*)(uint8_t *, uint32_t, const uint8_t *,
                                       uint32_t, const uint8_t *, uint32_t,
@@ -706,13 +737,18 @@ class EbHbdCompBlendVMaskTest
     void run_blend(int subw, int subh) override {
         (void)subw;
         (void)subh;
+
+        if (h_ > 32)
+            return;
+        const uint8_t *const mask = svt_av1_get_obmc_mask(h_);
+
         func_ref_((uint16_t *)ref_dst_,
                   dst_stride_,
                   (uint16_t *)src0_,
                   src_stride_,
                   (uint16_t *)src1_,
                   src_stride_,
-                  mask_,
+                  mask,
                   w_,
                   h_,
                   bd_);
@@ -722,7 +758,7 @@ class EbHbdCompBlendVMaskTest
                   src_stride_,
                   (uint16_t *)src1_,
                   src_stride_,
-                  mask_,
+                  mask,
                   w_,
                   h_,
                   bd_);
@@ -735,11 +771,15 @@ TEST_P(EbHbdCompBlendVMaskTest, BlendA64Mask) {
     run_hbd_test(12);
 }
 
-INSTANTIATE_TEST_CASE_P(BLEND, EbHbdCompBlendVMaskTest,
-                        ::testing::ValuesIn({make_tuple(
-                            svt_aom_highbd_blend_a64_vmask_16bit_c,
-                            svt_aom_highbd_blend_a64_vmask_16bit_sse4_1,
-                            "svt_aom_highbd_blend_a64_vmask_16bit_sse4_1")}));
+INSTANTIATE_TEST_CASE_P(
+    BLEND, EbHbdCompBlendVMaskTest,
+    ::testing::ValuesIn(
+        {make_tuple(svt_aom_highbd_blend_a64_vmask_16bit_c,
+                    svt_aom_highbd_blend_a64_vmask_16bit_sse4_1,
+                    "svt_aom_highbd_blend_a64_vmask_16bit_sse4_1"),
+         make_tuple(svt_aom_highbd_blend_a64_vmask_16bit_c,
+                    svt_av1_highbd_blend_a64_vmask_16bit_avx2,
+                    "svt_dav1d_highbd_blend_a64_vmask_16bit_avx2")}));
 
 typedef void (*BuildCompDiffwtdMaskedFunc)(uint8_t *mask,
                                            DIFFWTD_MASK_TYPE mask_type,
@@ -803,7 +843,8 @@ INSTANTIATE_TEST_CASE_P(
     CompUtilTest, BuildCompDiffwtdMaskTest,
     ::testing::Combine(
         ::testing::Range(BLOCK_4X4, BlockSizeS_ALL),
-        ::testing::Values(svt_av1_build_compound_diffwtd_mask_avx2)));
+        ::testing::Values(svt_av1_build_compound_diffwtd_mask_sse4_1,
+                          svt_av1_build_compound_diffwtd_mask_avx2)));
 
 typedef void (*BuildCompDiffwtdMaskedHighbdFunc)(
     uint8_t *mask, DIFFWTD_MASK_TYPE mask_type, const uint8_t *src0,
@@ -981,7 +1022,8 @@ INSTANTIATE_TEST_CASE_P(
     SSE4_1, BuildCompDiffwtdMaskD16Test,
     ::testing::Combine(
         ::testing::Range(8, 13, 2),
-        ::testing::Values(svt_av1_build_compound_diffwtd_mask_d16_avx2),
+        ::testing::Values(svt_av1_build_compound_diffwtd_mask_d16_sse4_1,
+                          svt_av1_build_compound_diffwtd_mask_d16_avx2),
         ::testing::Range(BLOCK_4X4, BlockSizeS_ALL)));
 
 typedef int64_t (*AomSseFunc)(const uint8_t *, int, const uint8_t *, int, int,
@@ -1048,11 +1090,28 @@ class AomSseHighbdTest : public ::testing::TestWithParam<AomSseParam> {
     void run_test() {
         const int block_size = TEST_GET_PARAM(0);
         AomSseFunc test_impl = TEST_GET_PARAM(1);
-        const int width = block_size_wide[block_size];
-        const int height = block_size_high[block_size];
+        int run_times = 100;
+        int width;
+        int height;
+        if (block_size < BlockSizeS_ALL) {
+            width = block_size_wide[block_size];
+            height = block_size_high[block_size];
+        } else {
+            run_times = 10;
+            // unusual sizes
+            if (block_size > BlockSizeS_ALL) {
+                // block_size == BlockSizeS_ALL +1
+                width = 36;
+                height = 36;
+            } else {
+                // block_size == BlockSizeS_ALL
+                width = 40;
+                height = 40;
+            }
+        }
+
         DECLARE_ALIGNED(16, uint16_t, a_[MAX_SB_SQUARE]);
         DECLARE_ALIGNED(16, uint16_t, b_[MAX_SB_SQUARE]);
-        const int run_times = 100;
         for (int i = 0; i < run_times; ++i) {
             memset(a_, 0, sizeof(a_));
             memset(b_, 0, sizeof(b_));
@@ -1083,6 +1142,12 @@ INSTANTIATE_TEST_CASE_P(
     ::testing::Combine(::testing::Range(BLOCK_4X4, BlockSizeS_ALL),
                        ::testing::Values(svt_aom_highbd_sse_avx2)));
 
+INSTANTIATE_TEST_CASE_P(
+    SSETEST_unusula_sizes, AomSseHighbdTest,
+    ::testing::Combine(::testing::Range(BlockSizeS_ALL,
+                                        (BlockSize)(BlockSizeS_ALL + 2)),
+                       ::testing::Values(svt_aom_highbd_sse_avx2)));
+
 typedef void (*AomSubstractBlockFunc)(int, int, int16_t *, ptrdiff_t,
                                       const uint8_t *, ptrdiff_t,
                                       const uint8_t *, ptrdiff_t);
