@@ -124,10 +124,10 @@ uint32_t svt_create_random_aligned_stride(const uint32_t width,
  * Compare Data
  ***************************************/
 #define BUF_COMPARE_FUNCTION(name, type)                         \
-    EbBool name(const type *const buf1,                          \
-                const type *const buf2,                          \
-                const size_t bufSize) {                          \
-        EbBool result = EB_TRUE;                                 \
+    Bool name(const type *const buf1,                            \
+              const type *const buf2,                            \
+              const size_t bufSize) {                            \
+        Bool result = TRUE;                                      \
                                                                  \
         for (uint32_t i = 0; i < bufSize; i++) {                 \
             if (buf1[i] != buf2[i]) {                            \
@@ -136,7 +136,7 @@ uint32_t svt_create_random_aligned_stride(const uint32_t width,
                        buf1[i],                                  \
                        i,                                        \
                        buf2[i]);                                 \
-                result = EB_FALSE;                               \
+                result = FALSE;                                  \
             }                                                    \
         }                                                        \
                                                                  \
