@@ -364,7 +364,7 @@ class DenoiseModelRunTest : public ::testing::Test {
         EbPictureBufferDescInitData pbd_init_data;
         pbd_init_data.max_width = width_;
         pbd_init_data.max_height = height_;
-        pbd_init_data.bit_depth = EB_8BIT;
+        pbd_init_data.bit_depth = EB_EIGHT_BIT;
         // allocate all the components
         pbd_init_data.buffer_enable_mask = PICTURE_BUFFER_DESC_FULL_MASK;
         pbd_init_data.left_padding = 0;
@@ -372,7 +372,7 @@ class DenoiseModelRunTest : public ::testing::Test {
         pbd_init_data.top_padding = 0;
         pbd_init_data.bot_padding = 0;
         pbd_init_data.color_format = EB_YUV420;
-        pbd_init_data.split_mode = EB_FALSE;
+        pbd_init_data.split_mode = FALSE;
 
         subsampling_x_ = (pbd_init_data.color_format == EB_YUV444 ? 1 : 2) - 1;
         subsampling_y_ = (pbd_init_data.color_format >= EB_YUV422 ? 1 : 2) - 1;
@@ -383,7 +383,7 @@ class DenoiseModelRunTest : public ::testing::Test {
 
         // create the denoise and noise model
         DenoiseAndModelInitData fg_init_data;
-        fg_init_data.encoder_bit_depth = EB_8BIT;
+        fg_init_data.encoder_bit_depth = EB_EIGHT_BIT;
         fg_init_data.encoder_color_format = EB_YUV420;
         fg_init_data.noise_level = 4;  // TODO: check the range;
         fg_init_data.width = width_;
@@ -409,25 +409,17 @@ class DenoiseModelRunTest : public ::testing::Test {
         data_ptr_[2] = in_pic_.buffer_cr;
 
         memset(&output_film_grain, 0, sizeof(output_film_grain));
-        // initialize the global function variables since
-        // svt_aom_wiener_denoise_2d will use these vars;
-        {
-            svt_aom_fft2x2_float = svt_aom_fft2x2_float_c;
-            svt_aom_fft4x4_float = svt_aom_fft4x4_float_c;
-            svt_aom_fft16x16_float = svt_aom_fft16x16_float_c;
-            svt_aom_fft32x32_float = svt_aom_fft32x32_float_c;
-            svt_aom_fft8x8_float = svt_aom_fft8x8_float_c;
 
-            svt_aom_ifft16x16_float = svt_aom_ifft16x16_float_avx2;
-            svt_aom_ifft32x32_float = svt_aom_ifft32x32_float_avx2;
-            svt_aom_ifft8x8_float = svt_aom_ifft8x8_float_avx2;
-            svt_aom_ifft2x2_float = svt_aom_ifft2x2_float_c;
-            svt_aom_ifft4x4_float = svt_aom_ifft4x4_float_sse2;
-        }
+#ifdef ARCH_X86_64
+        EbCpuFlags cpu_flags = get_cpu_flags_to_use();
+#else
+        EbCpuFlags cpu_flags = 0;
+#endif
+        setup_rtcd_internal(cpu_flags);
     }
 
     void init_data() {
-        const int shift = EB_8BIT - 8;
+        const int shift = EB_EIGHT_BIT - 8;
         for (int y = 0; y < height_; ++y) {
             for (int x = 0; x < width_; ++x) {
                 data_ptr_[0][y * width_ + x] =
