@@ -52,15 +52,24 @@ namespace {
 using FwdTxfm2dAsmParam = std::tuple<int, int>;
 
 static const FwdTxfm2dFunc fwd_txfm_2d_avx2_func[TX_SIZES_ALL] = {
-    svt_av1_fwd_txfm2d_4x4_sse4_1, svt_av1_fwd_txfm2d_8x8_avx2,
-    svt_av1_fwd_txfm2d_16x16_avx2, svt_av1_fwd_txfm2d_32x32_avx2,
-    svt_av1_fwd_txfm2d_64x64_avx2, svt_av1_fwd_txfm2d_4x8_avx2,
-    svt_av1_fwd_txfm2d_8x4_avx2,   svt_av1_fwd_txfm2d_8x16_avx2,
-    svt_av1_fwd_txfm2d_16x8_avx2,  svt_av1_fwd_txfm2d_16x32_avx2,
-    svt_av1_fwd_txfm2d_32x16_avx2, svt_av1_fwd_txfm2d_32x64_avx2,
-    svt_av1_fwd_txfm2d_64x32_avx2, svt_av1_fwd_txfm2d_4x16_avx2,
-    svt_av1_fwd_txfm2d_16x4_avx2,  svt_av1_fwd_txfm2d_8x32_avx2,
-    svt_av1_fwd_txfm2d_32x8_avx2,  svt_av1_fwd_txfm2d_16x64_avx2,
+    NULL,
+    svt_av1_fwd_txfm2d_8x8_avx2,
+    svt_av1_fwd_txfm2d_16x16_avx2,
+    svt_av1_fwd_txfm2d_32x32_avx2,
+    svt_av1_fwd_txfm2d_64x64_avx2,
+    svt_av1_fwd_txfm2d_4x8_avx2,
+    svt_av1_fwd_txfm2d_8x4_avx2,
+    svt_av1_fwd_txfm2d_8x16_avx2,
+    svt_av1_fwd_txfm2d_16x8_avx2,
+    svt_av1_fwd_txfm2d_16x32_avx2,
+    svt_av1_fwd_txfm2d_32x16_avx2,
+    svt_av1_fwd_txfm2d_32x64_avx2,
+    svt_av1_fwd_txfm2d_64x32_avx2,
+    svt_av1_fwd_txfm2d_4x16_avx2,
+    svt_av1_fwd_txfm2d_16x4_avx2,
+    svt_av1_fwd_txfm2d_8x32_avx2,
+    svt_av1_fwd_txfm2d_32x8_avx2,
+    svt_av1_fwd_txfm2d_16x64_avx2,
     svt_av1_fwd_txfm2d_64x16_avx2,
 };
 
@@ -77,32 +86,76 @@ static const FwdTxfm2dFunc fwd_txfm_2d_sse4_1_func[TX_SIZES_ALL] = {
     svt_av1_fwd_txfm2d_64x16_sse4_1,
 };
 
-static const FwdTxfm2dFunc fwd_txfm_2d_N2_asm_func[TX_SIZES_ALL] = {
-    svt_av1_fwd_txfm2d_4x4_N2_sse4_1, svt_av1_fwd_txfm2d_8x8_N2_avx2,
-    svt_av1_fwd_txfm2d_16x16_N2_avx2, svt_av1_fwd_txfm2d_32x32_N2_avx2,
-    svt_av1_fwd_txfm2d_64x64_N2_avx2, svt_av1_fwd_txfm2d_4x8_N2_avx2,
-    svt_av1_fwd_txfm2d_8x4_N2_avx2,   svt_av1_fwd_txfm2d_8x16_N2_avx2,
-    svt_av1_fwd_txfm2d_16x8_N2_avx2,  svt_av1_fwd_txfm2d_16x32_N2_avx2,
-    svt_av1_fwd_txfm2d_32x16_N2_avx2, svt_av1_fwd_txfm2d_32x64_N2_avx2,
-    svt_av1_fwd_txfm2d_64x32_N2_avx2, svt_av1_fwd_txfm2d_4x16_N2_avx2,
-    svt_av1_fwd_txfm2d_16x4_N2_avx2,  svt_av1_fwd_txfm2d_8x32_N2_avx2,
-    svt_av1_fwd_txfm2d_32x8_N2_avx2,  svt_av1_fwd_txfm2d_16x64_N2_avx2,
+static const FwdTxfm2dFunc fwd_txfm_2d_N2_avx2_func[TX_SIZES_ALL] = {
+    NULL,
+    svt_av1_fwd_txfm2d_8x8_N2_avx2,
+    svt_av1_fwd_txfm2d_16x16_N2_avx2,
+    svt_av1_fwd_txfm2d_32x32_N2_avx2,
+    svt_av1_fwd_txfm2d_64x64_N2_avx2,
+    svt_av1_fwd_txfm2d_4x8_N2_avx2,
+    svt_av1_fwd_txfm2d_8x4_N2_avx2,
+    svt_av1_fwd_txfm2d_8x16_N2_avx2,
+    svt_av1_fwd_txfm2d_16x8_N2_avx2,
+    svt_av1_fwd_txfm2d_16x32_N2_avx2,
+    svt_av1_fwd_txfm2d_32x16_N2_avx2,
+    svt_av1_fwd_txfm2d_32x64_N2_avx2,
+    svt_av1_fwd_txfm2d_64x32_N2_avx2,
+    svt_av1_fwd_txfm2d_4x16_N2_avx2,
+    svt_av1_fwd_txfm2d_16x4_N2_avx2,
+    svt_av1_fwd_txfm2d_8x32_N2_avx2,
+    svt_av1_fwd_txfm2d_32x8_N2_avx2,
+    svt_av1_fwd_txfm2d_16x64_N2_avx2,
     svt_av1_fwd_txfm2d_64x16_N2_avx2,
 };
 
-static const FwdTxfm2dFunc fwd_txfm_2d_N4_asm_func[TX_SIZES_ALL] = {
-    svt_av1_fwd_txfm2d_4x4_N4_sse4_1, svt_av1_fwd_txfm2d_8x8_N4_avx2,
-    svt_av1_fwd_txfm2d_16x16_N4_avx2, svt_av1_fwd_txfm2d_32x32_N4_avx2,
-    svt_av1_fwd_txfm2d_64x64_N4_avx2, svt_av1_fwd_txfm2d_4x8_N4_avx2,
-    svt_av1_fwd_txfm2d_8x4_N4_avx2,   svt_av1_fwd_txfm2d_8x16_N4_avx2,
-    svt_av1_fwd_txfm2d_16x8_N4_avx2,  svt_av1_fwd_txfm2d_16x32_N4_avx2,
-    svt_av1_fwd_txfm2d_32x16_N4_avx2, svt_av1_fwd_txfm2d_32x64_N4_avx2,
-    svt_av1_fwd_txfm2d_64x32_N4_avx2, svt_av1_fwd_txfm2d_4x16_N4_avx2,
-    svt_av1_fwd_txfm2d_16x4_N4_avx2,  svt_av1_fwd_txfm2d_8x32_N4_avx2,
-    svt_av1_fwd_txfm2d_32x8_N4_avx2,  svt_av1_fwd_txfm2d_16x64_N4_avx2,
+static const FwdTxfm2dFunc fwd_txfm_2d_N4_avx2_func[TX_SIZES_ALL] = {
+    NULL,
+    svt_av1_fwd_txfm2d_8x8_N4_avx2,
+    svt_av1_fwd_txfm2d_16x16_N4_avx2,
+    svt_av1_fwd_txfm2d_32x32_N4_avx2,
+    svt_av1_fwd_txfm2d_64x64_N4_avx2,
+    svt_av1_fwd_txfm2d_4x8_N4_avx2,
+    svt_av1_fwd_txfm2d_8x4_N4_avx2,
+    svt_av1_fwd_txfm2d_8x16_N4_avx2,
+    svt_av1_fwd_txfm2d_16x8_N4_avx2,
+    svt_av1_fwd_txfm2d_16x32_N4_avx2,
+    svt_av1_fwd_txfm2d_32x16_N4_avx2,
+    svt_av1_fwd_txfm2d_32x64_N4_avx2,
+    svt_av1_fwd_txfm2d_64x32_N4_avx2,
+    svt_av1_fwd_txfm2d_4x16_N4_avx2,
+    svt_av1_fwd_txfm2d_16x4_N4_avx2,
+    svt_av1_fwd_txfm2d_8x32_N4_avx2,
+    svt_av1_fwd_txfm2d_32x8_N4_avx2,
+    svt_av1_fwd_txfm2d_16x64_N4_avx2,
     svt_av1_fwd_txfm2d_64x16_N4_avx2,
 };
 
+static const FwdTxfm2dFunc fwd_txfm_2d_N2_sse4_1_func[TX_SIZES_ALL] = {
+    svt_av1_fwd_txfm2d_4x4_N2_sse4_1,   svt_av1_fwd_txfm2d_8x8_N2_sse4_1,
+    svt_av1_fwd_txfm2d_16x16_N2_sse4_1, svt_av1_fwd_txfm2d_32x32_N2_sse4_1,
+    svt_av1_fwd_txfm2d_64x64_N2_sse4_1, svt_av1_fwd_txfm2d_4x8_N2_sse4_1,
+    svt_av1_fwd_txfm2d_8x4_N2_sse4_1,   svt_av1_fwd_txfm2d_8x16_N2_sse4_1,
+    svt_av1_fwd_txfm2d_16x8_N2_sse4_1,  svt_av1_fwd_txfm2d_16x32_N2_sse4_1,
+    svt_av1_fwd_txfm2d_32x16_N2_sse4_1, svt_av1_fwd_txfm2d_32x64_N2_sse4_1,
+    svt_av1_fwd_txfm2d_64x32_N2_sse4_1, svt_av1_fwd_txfm2d_4x16_N2_sse4_1,
+    svt_av1_fwd_txfm2d_16x4_N2_sse4_1,  svt_av1_fwd_txfm2d_8x32_N2_sse4_1,
+    svt_av1_fwd_txfm2d_32x8_N2_sse4_1,  svt_av1_fwd_txfm2d_16x64_N2_sse4_1,
+    svt_av1_fwd_txfm2d_64x16_N2_sse4_1,
+};
+
+static const FwdTxfm2dFunc fwd_txfm_2d_N4_sse4_1_func[TX_SIZES_ALL] = {
+    svt_av1_fwd_txfm2d_4x4_N4_sse4_1,   svt_av1_fwd_txfm2d_8x8_N4_sse4_1,
+    svt_av1_fwd_txfm2d_16x16_N4_sse4_1, svt_av1_fwd_txfm2d_32x32_N4_sse4_1,
+    svt_av1_fwd_txfm2d_64x64_N4_sse4_1, svt_av1_fwd_txfm2d_4x8_N4_sse4_1,
+    svt_av1_fwd_txfm2d_8x4_N4_sse4_1,   svt_av1_fwd_txfm2d_8x16_N4_sse4_1,
+    svt_av1_fwd_txfm2d_16x8_N4_sse4_1,  svt_av1_fwd_txfm2d_16x32_N4_sse4_1,
+    svt_av1_fwd_txfm2d_32x16_N4_sse4_1, svt_av1_fwd_txfm2d_32x64_N4_sse4_1,
+    svt_av1_fwd_txfm2d_64x32_N4_sse4_1, svt_av1_fwd_txfm2d_4x16_N4_sse4_1,
+    svt_av1_fwd_txfm2d_16x4_N4_sse4_1,  svt_av1_fwd_txfm2d_8x32_N4_sse4_1,
+    svt_av1_fwd_txfm2d_32x8_N4_sse4_1,  svt_av1_fwd_txfm2d_16x64_N4_sse4_1,
+    svt_av1_fwd_txfm2d_64x16_N4_sse4_1,
+};
+
 static const FwdTxfm2dFunc fwd_txfm_2d_N2_c_func[TX_SIZES_ALL] = {
     av1_transform_two_d_4x4_N2_c,   av1_transform_two_d_8x8_N2_c,
     av1_transform_two_d_16x16_N2_c, av1_transform_two_d_32x32_N2_c,
@@ -130,6 +183,28 @@ static const FwdTxfm2dFunc fwd_txfm_2d_N4_c_func[TX_SIZES_ALL] = {
 };
 
 #if EN_AVX512_SUPPORT
+static const FwdTxfm2dFunc fwd_txfm_2d_avx512_func[TX_SIZES_ALL] = {
+    NULL,
+    NULL,
+    av1_fwd_txfm2d_16x16_avx512,
+    av1_fwd_txfm2d_32x32_avx512,
+    av1_fwd_txfm2d_64x64_avx512,
+    NULL,
+    NULL,
+    NULL,
+    NULL,
+    av1_fwd_txfm2d_16x32_avx512,
+    av1_fwd_txfm2d_32x16_avx512,
+    av1_fwd_txfm2d_32x64_avx512,
+    av1_fwd_txfm2d_64x32_avx512,
+    NULL,
+    NULL,
+    NULL,
+    NULL,
+    av1_fwd_txfm2d_16x64_avx512,
+    av1_fwd_txfm2d_64x16_avx512,
+};
+
 static const FwdTxfm2dFunc fwd_txfm_2d_N2_asm512_func[TX_SIZES_ALL] = {
     NULL,
     NULL,
@@ -212,42 +287,70 @@ class FwdTxfm2dAsmTest : public ::testing::TestWithParam<FwdTxfm2dAsmParam> {
         execute_test(test_func, ref_func, DEFAULT_SHAPE);
     }
 
+#if EN_AVX512_SUPPORT
+    void run_match_test_avx512() {
+        FwdTxfm2dFunc test_func = fwd_txfm_2d_avx512_func[tx_size_];
+        FwdTxfm2dFunc ref_func = fwd_txfm_2d_avx2_func[tx_size_];
+        execute_test(test_func, ref_func, DEFAULT_SHAPE);
+    }
+#endif
+
     void run_match_test_sse4_1() {
         FwdTxfm2dFunc test_func = fwd_txfm_2d_sse4_1_func[tx_size_];
         FwdTxfm2dFunc ref_func = fwd_txfm_2d_c_func[tx_size_];
         execute_test(test_func, ref_func, DEFAULT_SHAPE);
     }
 
-    void run_match_test_N2() {
-        FwdTxfm2dFunc test_func_asm = fwd_txfm_2d_N2_asm_func[tx_size_];
+    void run_match_test_avx2_N2() {
+        FwdTxfm2dFunc test_func_avx2 = fwd_txfm_2d_N2_avx2_func[tx_size_];
         FwdTxfm2dFunc test_func_c = fwd_txfm_2d_N2_c_func[tx_size_];
         FwdTxfm2dFunc ref_func = fwd_txfm_2d_c_func[tx_size_];
-        execute_test(test_func_asm, ref_func, N2_SHAPE);
+        execute_test(test_func_avx2, ref_func, N2_SHAPE);
         execute_test(test_func_c, ref_func, N2_SHAPE);
     }
 
-    void run_match_test_N4() {
-        FwdTxfm2dFunc test_func_asm = fwd_txfm_2d_N4_asm_func[tx_size_];
+    void run_match_test_avx2_N4() {
+        FwdTxfm2dFunc test_func_avx2 = fwd_txfm_2d_N4_avx2_func[tx_size_];
         FwdTxfm2dFunc test_func_c = fwd_txfm_2d_N4_c_func[tx_size_];
         FwdTxfm2dFunc ref_func = fwd_txfm_2d_c_func[tx_size_];
-        execute_test(test_func_asm, ref_func, N4_SHAPE);
+        execute_test(test_func_avx2, ref_func, N4_SHAPE);
+        execute_test(test_func_c, ref_func, N4_SHAPE);
+    }
+
+    void run_match_test_sse4_1_N2() {
+        FwdTxfm2dFunc test_func_sse4_1 = fwd_txfm_2d_N2_sse4_1_func[tx_size_];
+        FwdTxfm2dFunc test_func_c = fwd_txfm_2d_N2_c_func[tx_size_];
+        FwdTxfm2dFunc ref_func = fwd_txfm_2d_c_func[tx_size_];
+        execute_test(test_func_sse4_1, ref_func, N2_SHAPE);
+        execute_test(test_func_c, ref_func, N2_SHAPE);
+    }
+
+    void run_match_test_sse4_1_N4() {
+        FwdTxfm2dFunc test_func_sse4_1 = fwd_txfm_2d_N4_sse4_1_func[tx_size_];
+        FwdTxfm2dFunc test_func_c = fwd_txfm_2d_N4_c_func[tx_size_];
+        FwdTxfm2dFunc ref_func = fwd_txfm_2d_c_func[tx_size_];
+        execute_test(test_func_sse4_1, ref_func, N4_SHAPE);
         execute_test(test_func_c, ref_func, N4_SHAPE);
     }
 
     void speed_test_avx2() {
         FwdTxfm2dFunc test_func = fwd_txfm_2d_avx2_func[tx_size_];
         FwdTxfm2dFunc ref_func = fwd_txfm_2d_c_func[tx_size_];
-        run_speed_test("C   AND ASM", test_func, ref_func);
+        run_speed_test("C    AND AVX2", test_func, ref_func);
         run_speed_test(
-            "ASM AND N2 ", fwd_txfm_2d_N2_asm_func[tx_size_], test_func);
+            "AVX2 AND N2  ", fwd_txfm_2d_N2_avx2_func[tx_size_], test_func);
         run_speed_test(
-            "ASM AND N4 ", fwd_txfm_2d_N4_asm_func[tx_size_], test_func);
+            "AVX2 AND N4  ", fwd_txfm_2d_N4_avx2_func[tx_size_], test_func);
     }
 
     void speed_test_sse4_1() {
         FwdTxfm2dFunc test_func = fwd_txfm_2d_sse4_1_func[tx_size_];
         FwdTxfm2dFunc ref_func = fwd_txfm_2d_c_func[tx_size_];
-        run_speed_test("C   AND ASM", test_func, ref_func);
+        run_speed_test("C    AND SSE4", test_func, ref_func);
+        run_speed_test(
+            "SSE4 AND N2  ", fwd_txfm_2d_N2_sse4_1_func[tx_size_], test_func);
+        run_speed_test(
+            "SSE4 AND N4  ", fwd_txfm_2d_N4_sse4_1_func[tx_size_], test_func);
     }
 #if EN_AVX512_SUPPORT
     void run_match_test_N2_512() {
@@ -264,13 +367,13 @@ class FwdTxfm2dAsmTest : public ::testing::TestWithParam<FwdTxfm2dAsmParam> {
 
     void speed_test_512() {
         FwdTxfm2dFunc test_func = fwd_txfm_2d_N2_asm512_func[tx_size_];
-        FwdTxfm2dFunc ref_func = fwd_txfm_2d_N2_asm_func[tx_size_];
+        FwdTxfm2dFunc ref_func = fwd_txfm_2d_N2_avx2_func[tx_size_];
         if (test_func && ref_func) {
             run_speed_test("N2 AVX512 AVX2 ", test_func, ref_func);
         }
 
         test_func = fwd_txfm_2d_N4_asm512_func[tx_size_];
-        ref_func = fwd_txfm_2d_N4_asm_func[tx_size_];
+        ref_func = fwd_txfm_2d_N2_avx2_func[tx_size_];
         if (test_func && ref_func) {
             run_speed_test("N4 AVX512 AVX2", test_func, ref_func);
         }
@@ -446,16 +549,30 @@ TEST_P(FwdTxfm2dAsmTest, match_test_avx2) {
     run_match_test_avx2();
 }
 
+#if EN_AVX512_SUPPORT
+TEST_P(FwdTxfm2dAsmTest, match_test_avx512) {
+    run_match_test_avx512();
+}
+#endif
+
 TEST_P(FwdTxfm2dAsmTest, match_test_sse4_1) {
     run_match_test_sse4_1();
 }
 
-TEST_P(FwdTxfm2dAsmTest, match_test_N2) {
-    run_match_test_N2();
+TEST_P(FwdTxfm2dAsmTest, match_test_avx2_N2) {
+    run_match_test_avx2_N2();
 }
 
-TEST_P(FwdTxfm2dAsmTest, match_test_N4) {
-    run_match_test_N4();
+TEST_P(FwdTxfm2dAsmTest, match_test_avx2_N4) {
+    run_match_test_avx2_N4();
+}
+
+TEST_P(FwdTxfm2dAsmTest, match_test_sse4_1_N2) {
+    run_match_test_sse4_1_N2();
+}
+
+TEST_P(FwdTxfm2dAsmTest, match_test_sse4_1_N4) {
+    run_match_test_sse4_1_N4();
 }
 
 TEST_P(FwdTxfm2dAsmTest, DISABLED_speed_test_avx2) {
@@ -468,19 +585,19 @@ TEST_P(FwdTxfm2dAsmTest, DISABLED_speed_test_sse4_1) {
 
 #if EN_AVX512_SUPPORT
 TEST_P(FwdTxfm2dAsmTest, match_test_N2_512) {
-    if (CPU_FLAGS_AVX512F & get_cpu_flags_to_use()) {
+    if (EB_CPU_FLAGS_AVX512F & get_cpu_flags_to_use()) {
         run_match_test_N2_512();
     }
 }
 
 TEST_P(FwdTxfm2dAsmTest, match_test_N4_512) {
-    if (CPU_FLAGS_AVX512F & get_cpu_flags_to_use()) {
+    if (EB_CPU_FLAGS_AVX512F & get_cpu_flags_to_use()) {
         run_match_test_N4_512();
     }
 }
 
 TEST_P(FwdTxfm2dAsmTest, DISABLED_speed_test_512) {
-    if (CPU_FLAGS_AVX512F & get_cpu_flags_to_use()) {
+    if (EB_CPU_FLAGS_AVX512F & get_cpu_flags_to_use()) {
         speed_test_512();
     }
 }
@@ -489,6 +606,6 @@ INSTANTIATE_TEST_CASE_P(
     TX, FwdTxfm2dAsmTest,
     ::testing::Combine(::testing::Range(static_cast<int>(TX_4X4),
                                         static_cast<int>(TX_SIZES_ALL), 1),
-                       ::testing::Values(static_cast<int>(AOM_BITS_8),
-                                         static_cast<int>(AOM_BITS_10))));
+                       ::testing::Values(static_cast<int>(EB_EIGHT_BIT),
+                                         static_cast<int>(EB_TEN_BIT))));
 }  // namespace
