@@ -422,6 +422,9 @@ static const HbdVarianceParam HbdTestVector[] = {
     HbdVarianceParam(64, 16, 10, svt_aom_highbd_10_variance64x16_sse2),
     HbdVarianceParam(64, 32, 10, svt_aom_highbd_10_variance64x32_sse2),
     HbdVarianceParam(64, 64, 10, svt_aom_highbd_10_variance64x64_sse2),
+    HbdVarianceParam(64, 128, 10, svt_aom_highbd_10_variance64x128_sse2),
+    HbdVarianceParam(128, 64, 10, svt_aom_highbd_10_variance128x64_sse2),
+    HbdVarianceParam(128, 128, 10, svt_aom_highbd_10_variance128x128_sse2),
     HbdVarianceParam(8, 8, 10, svt_aom_highbd_10_variance8x8_avx2),
     HbdVarianceParam(8, 16, 10, svt_aom_highbd_10_variance8x16_avx2),
     HbdVarianceParam(8, 32, 10, svt_aom_highbd_10_variance8x32_avx2),
@@ -592,6 +595,7 @@ TEST_P(HbdSquareVarianceNoRoundTest, MatchTest) {
 INSTANTIATE_TEST_CASE_P(
     Variance, HbdSquareVarianceNoRoundTest,
     ::testing::Combine(::testing::Values(16, 32),
-                       ::testing::Values(variance_highbd_avx2)));
+                       ::testing::Values(variance_highbd_sse4_1,
+                                         variance_highbd_avx2)));
 
 }  // namespace
