@@ -43,10 +43,11 @@
 #include "aom_dsp_rtcd.h"
 #include "util.h"
 #include "random.h"
+#include "EbQMatrices.h"
 
 namespace QuantizeAsmTest {
 extern "C" void svt_av1_build_quantizer(
-    AomBitDepth bit_depth, int32_t y_dc_delta_q, int32_t u_dc_delta_q,
+    EbBitDepth bit_depth, int32_t y_dc_delta_q, int32_t u_dc_delta_q,
     int32_t u_ac_delta_q, int32_t v_dc_delta_q, int32_t v_ac_delta_q,
     Quants *const quants, Dequants *const deq);
 
@@ -63,6 +64,7 @@ using QuantizeFunc = void (*)(const TranLow *coeff_ptr, intptr_t n_coeffs,
 using QuantizeParam = std::tuple<int, int, QuantizeFunc>;
 
 using svt_av1_test_tool::SVTRandom;  // to generate the random
+class QuantizeBQmTest;
 /**
  * @brief Unit test for quantize avx2 functions:
  * - svt_aom_highbd_quantize_b_avx2
@@ -89,7 +91,7 @@ class QuantizeBTest : public ::testing::TestWithParam<QuantizeParam> {
   protected:
     QuantizeBTest()
         : tx_size_(static_cast<TxSize>(TEST_GET_PARAM(0))),
-          bd_(static_cast<AomBitDepth>(TEST_GET_PARAM(1))),
+          bd_(static_cast<EbBitDepth>(TEST_GET_PARAM(1))),
           log_scale(0) {
         n_coeffs_ = av1_get_max_eob(tx_size_);
         coeff_min_ = -(1 << (7 + bd_));
@@ -131,13 +133,13 @@ class QuantizeBTest : public ::testing::TestWithParam<QuantizeParam> {
      * @brief setup reference and target function ptrs
      * @see setup_rtcd_internal() in aom_dsp_rtcd.h
      */
-    void setup_func_ptrs() {
-        if (bd_ == AOM_BITS_8) {
+    virtual void setup_func_ptrs() {
+        if (bd_ == EB_EIGHT_BIT) {
             quant_ref_ = svt_aom_quantize_b_c_ii;
             quant_test_ = TEST_GET_PARAM(2);
         } else {
             quant_ref_ = svt_aom_highbd_quantize_b_c;
-            quant_test_ = svt_aom_highbd_quantize_b_avx2;
+            quant_test_ = TEST_GET_PARAM(2);
         }
         if (tx_size_ == TX_32X32) {
             log_scale = 1;
@@ -152,7 +154,7 @@ class QuantizeBTest : public ::testing::TestWithParam<QuantizeParam> {
      * @brief run quantize with the same input data, then check whether output
      * quant/dequant/eob are exactly same between C output and avx2 outptu
      */
-    void run_quantize(int q) {
+    virtual void run_quantize(int q) {
         const ScanOrder *const sc = &av1_scan_orders[tx_size_][DCT_DCT];
         const int16_t *zbin = qtab_quants_.y_zbin[q];
         const int16_t *round = qtab_quants_.y_round[q];
@@ -232,7 +234,7 @@ class QuantizeBTest : public ::testing::TestWithParam<QuantizeParam> {
     QuantizeFunc quant_ref_;  /**< reference quantize function */
     QuantizeFunc quant_test_; /**< test target quantize function */
     const TxSize tx_size_;    /**< input param tx_size */
-    const AomBitDepth bd_;    /**< input param 8bit or 10bit */
+    const EbBitDepth bd_;     /**< input param 8bit or 10bit */
     int n_coeffs_;            /**< coeff number */
     int32_t log_scale;
     uint16_t eob_ref_;  /**< output ref eob */
@@ -245,6 +247,126 @@ class QuantizeBTest : public ::testing::TestWithParam<QuantizeParam> {
     TranLow *dqcoeff_test_;
 };
 
+class QuantizeBQmTest : public QuantizeBTest {
+  protected:
+    QuantizeBQmTest() : QuantizeBTest() {
+        qm_level_ = 8;
+        init_qm();
+    }
+
+    virtual ~QuantizeBQmTest() = default;
+
+    void run_quantize(int q) override {
+        const ScanOrder *const sc = &av1_scan_orders[tx_size_][DCT_DCT];
+        const int16_t *zbin = qtab_quants_.y_zbin[q];
+        const int16_t *round = qtab_quants_.y_round[q];
+        const int16_t *quant = qtab_quants_.y_quant[q];
+        const int16_t *quant_shift = qtab_quants_.y_quant_shift[q];
+        const int16_t *dequant = qtab_deq_.y_dequant_qtx[q];
+
+        const TxSize qm_tx_size = av1_get_adjusted_tx_size(tx_size_);
+        const QmVal *qm_ptr = qmatrix_[qm_level_][0][qm_tx_size];
+        const QmVal *iqm_ptr = iqmatrix_[qm_level_][0][qm_tx_size];
+
+        memset(qcoeff_ref_, 0, MAX_TX_SQUARE * sizeof(TranLow));
+        memset(dqcoeff_ref_, 0, MAX_TX_SQUARE * sizeof(TranLow));
+        memset(qcoeff_test_, 0, MAX_TX_SQUARE * sizeof(TranLow));
+        memset(dqcoeff_test_, 0, MAX_TX_SQUARE * sizeof(TranLow));
+
+        quant_ref_(coeff_in_,
+                   n_coeffs_,
+                   zbin,
+                   round,
+                   quant,
+                   quant_shift,
+                   qcoeff_ref_,
+                   dqcoeff_ref_,
+                   dequant,
+                   &eob_ref_,
+                   sc->scan,
+                   sc->iscan,
+                   qm_ptr,
+                   iqm_ptr,
+                   log_scale);
+
+        quant_test_(coeff_in_,
+                    n_coeffs_,
+                    zbin,
+                    round,
+                    quant,
+                    quant_shift,
+                    qcoeff_test_,
+                    dqcoeff_test_,
+                    dequant,
+                    &eob_test_,
+                    sc->scan,
+                    sc->iscan,
+                    qm_ptr,
+                    iqm_ptr,
+                    log_scale);
+
+        for (int j = 0; j < n_coeffs_; ++j) {
+            ASSERT_EQ(qcoeff_ref_[j], qcoeff_test_[j])
+                << "Q mismatch at position: " << j << ", Q: " << q
+                << " coeff: " << coeff_in_[j];
+        }
+
+        for (int j = 0; j < n_coeffs_; ++j) {
+            ASSERT_EQ(dqcoeff_ref_[j], dqcoeff_test_[j])
+                << "Dq mismatch at position: " << j << ", Q: " << q
+                << " coeff: " << coeff_in_[j];
+        }
+
+        ASSERT_EQ(eob_ref_, eob_test_) << "eobs mismatch, Q: " << q;
+    }
+
+  private:
+    TxSize av1_get_adjusted_tx_size(TxSize tx_size) {
+        switch (tx_size) {
+        case TX_64X64:
+        case TX_64X32:
+        case TX_32X64: return TX_32X32;
+        case TX_64X16: return TX_32X16;
+        case TX_16X64: return TX_16X32;
+        default: return tx_size;
+        }
+    }
+
+    void init_qm() {
+        const uint8_t num_planes = 1;
+        uint8_t q, c, t;
+        int32_t current;
+        for (q = 0; q < NUM_QM_LEVELS; ++q) {
+            for (c = 0; c < num_planes; ++c) {
+                current = 0;
+                for (t = 0; t < TX_SIZES_ALL; ++t) {
+                    const int32_t size = tx_size_2d[t];
+                    const TxSize qm_tx_size =
+                        av1_get_adjusted_tx_size(static_cast<TxSize>(t));
+                    if (q == NUM_QM_LEVELS - 1) {
+                        qmatrix_[q][c][t] = NULL;
+                        iqmatrix_[q][c][t] = NULL;
+                    } else if (t !=
+                               qm_tx_size) {  // Reuse matrices for 'qm_tx_size'
+                        qmatrix_[q][c][t] = qmatrix_[q][c][qm_tx_size];
+                        iqmatrix_[q][c][t] = iqmatrix_[q][c][qm_tx_size];
+                    } else {
+                        assert(current + size <= QM_TOTAL_SIZE);
+                        qmatrix_[q][c][t] = &wt_matrix_ref[q][c >= 1][current];
+                        iqmatrix_[q][c][t] =
+                            &iwt_matrix_ref[q][c >= 1][current];
+                        current += size;
+                    }
+                }
+            }
+        }
+    }
+
+    const QmVal *iqmatrix_[NUM_QM_LEVELS][3][TX_SIZES_ALL];
+    const QmVal *qmatrix_[NUM_QM_LEVELS][3][TX_SIZES_ALL];
+    int qm_level_;
+};
+
 /**
  * @brief AVX2/QuantizeBTest.input_zero_all
  *
@@ -256,6 +378,10 @@ TEST_P(QuantizeBTest, input_zero_all) {
     fill_coeff_const(0, n_coeffs_, 0);
     run_quantize(0);
 }
+TEST_P(QuantizeBQmTest, input_zero_all) {
+    fill_coeff_const(0, n_coeffs_, 0);
+    run_quantize(0);
+}
 
 /**
  * @brief AVX2/QuantizeBTest.input_dcac_minmax_q_n
@@ -281,6 +407,23 @@ TEST_P(QuantizeBTest, input_dcac_minmax_q_n) {
         run_quantize(q);
     }
 }
+TEST_P(QuantizeBQmTest, input_dcac_minmax_q_n) {
+    fill_coeff_const(2, n_coeffs_, 0);
+    for (int q = 0; q < QINDEX_RANGE; q += 25) {
+        fill_coeff_const(0, 1, coeff_min_);
+        fill_coeff_const(1, 2, coeff_min_);
+        run_quantize(q);
+        fill_coeff_const(0, 1, coeff_min_);
+        fill_coeff_const(1, 2, coeff_max_);
+        run_quantize(q);
+        fill_coeff_const(0, 1, coeff_max_);
+        fill_coeff_const(1, 2, coeff_min_);
+        run_quantize(q);
+        fill_coeff_const(0, 1, coeff_max_);
+        fill_coeff_const(1, 2, coeff_max_);
+        run_quantize(q);
+    }
+}
 
 /**
  * @brief AVX2/QuantizeBTest.input_random_dc_only
@@ -294,6 +437,11 @@ TEST_P(QuantizeBTest, input_random_dc_only) {
     fill_coeff_random(0, 1);
     run_quantize(0);
 }
+TEST_P(QuantizeBQmTest, input_random_dc_only) {
+    fill_coeff_const(1, n_coeffs_, 0);
+    fill_coeff_random(0, 1);
+    run_quantize(0);
+}
 
 /**
  * @brief AVX2/QuantizeBTest.input_random_all_q_all
@@ -311,24 +459,54 @@ TEST_P(QuantizeBTest, input_random_all_q_all) {
         }
     }
 }
+TEST_P(QuantizeBQmTest, input_random_all_q_all) {
+    const int num_tests = 10;
+    for (int q = 0; q < QINDEX_RANGE; ++q) {
+        for (int i = 0; i < num_tests; ++i) {
+            fill_coeff_random(0, n_coeffs_);
+            run_quantize(q);
+        }
+    }
+}
 
 #ifndef FULL_UNIT_TEST
 INSTANTIATE_TEST_CASE_P(
-    Quant, QuantizeBTest,
+    QuantLBD, QuantizeBTest,
     ::testing::Combine(::testing::Values(static_cast<int>(TX_16X16),
                                          static_cast<int>(TX_32X32),
                                          static_cast<int>(TX_64X64)),
-                       ::testing::Values(static_cast<int>(AOM_BITS_8),
-                                         static_cast<int>(AOM_BITS_10)),
+                       ::testing::Values(static_cast<int>(EB_EIGHT_BIT)),
                        ::testing::Values(svt_aom_quantize_b_sse4_1,
                                          svt_aom_quantize_b_avx2)));
+INSTANTIATE_TEST_CASE_P(
+    QuantHBD, QuantizeBTest,
+    ::testing::Combine(::testing::Values(static_cast<int>(TX_16X16),
+                                         static_cast<int>(TX_32X32),
+                                         static_cast<int>(TX_64X64)),
+                       ::testing::Values(static_cast<int>(EB_TEN_BIT)),
+                       ::testing::Values(svt_aom_highbd_quantize_b_sse4_1,
+                                         svt_aom_highbd_quantize_b_avx2)));
+INSTANTIATE_TEST_CASE_P(
+    QuantLBD, QuantizeBQmTest,
+    ::testing::Combine(::testing::Values(static_cast<int>(TX_16X16),
+                                         static_cast<int>(TX_32X32),
+                                         static_cast<int>(TX_64X64)),
+                       ::testing::Values(static_cast<int>(EB_EIGHT_BIT)),
+                       ::testing::Values(svt_av1_quantize_b_qm_avx2)));
+INSTANTIATE_TEST_CASE_P(
+    QuantHBD, QuantizeBQmTest,
+    ::testing::Combine(::testing::Values(static_cast<int>(TX_16X16),
+                                         static_cast<int>(TX_32X32),
+                                         static_cast<int>(TX_64X64)),
+                       ::testing::Values(static_cast<int>(EB_TEN_BIT)),
+                       ::testing::Values(svt_av1_highbd_quantize_b_qm_avx2)));
 #else
 INSTANTIATE_TEST_CASE_P(
     Quant, QuantizeBTest,
     ::testing::Combine(::testing::Range(static_cast<int>(TX_4X4),
                                         static_cast<int>(TX_SIZES_ALL), 1),
-                       ::testing::Values(static_cast<int>(AOM_BITS_8),
-                                         static_cast<int>(AOM_BITS_10))));
+                       ::testing::Values(static_cast<int>(EB_EIGHT_BIT),
+                                         static_cast<int>(EB_TEN_BIT))));
 #endif  // FULL_UNIT_TEST
 
 }  // namespace QuantizeAsmTest
