@@ -25,11 +25,17 @@
  * encoder */
 void setup_test_env() {
 #ifdef ARCH_X86_64
-    CPU_FLAGS cpu_flags = get_cpu_flags_to_use();
+    EbCpuFlags cpu_flags = get_cpu_flags_to_use();
 #else
-    CPU_FLAGS cpu_flags = 0;
+    EbCpuFlags cpu_flags = 0;
 #endif
     setup_common_rtcd_internal(cpu_flags);
 
     setup_rtcd_internal(cpu_flags);
 }
+
+void reset_test_env() {
+    EbCpuFlags cpu_flags = 0;
+    setup_common_rtcd_internal(cpu_flags);
+    setup_rtcd_internal(cpu_flags);
+}
