@@ -1,13 +1,14 @@
 /*
-* Copyright(c) 2019 Netflix, Inc.
-*
-* This source code is subject to the terms of the BSD 2 Clause License and
-* the Alliance for Open Media Patent License 1.0. If the BSD 2 Clause License
-* was not distributed with this source code in the LICENSE file, you can
-* obtain it at https://www.aomedia.org/license/software-license. If the Alliance for Open
-* Media Patent License 1.0 was not distributed with this source code in the
-* PATENTS file, you can obtain it at https://www.aomedia.org/license/patent-license.
-*/
+ * Copyright(c) 2019 Netflix, Inc.
+ *
+ * This source code is subject to the terms of the BSD 2 Clause License and
+ * the Alliance for Open Media Patent License 1.0. If the BSD 2 Clause License
+ * was not distributed with this source code in the LICENSE file, you can
+ * obtain it at https://www.aomedia.org/license/software-license. If the
+ * Alliance for Open Media Patent License 1.0 was not distributed with this
+ * source code in the PATENTS file, you can obtain it at
+ * https://www.aomedia.org/license/patent-license.
+ */
 
 /******************************************************************************
  * @file intrapred_test.cc
@@ -287,7 +288,7 @@ const HBD_PARAMS HighbdIntraPredTestVectorAsm[] = {
     hbd_entry(paeth, 8, 4, avx2),      hbd_entry(paeth, 8, 8, avx2),
     hbd_entry(paeth, 8, 16, avx2),     hbd_entry(paeth, 8, 32, avx2),
     hbd_entry(paeth, 4, 4, avx2),      hbd_entry(paeth, 4, 8, avx2),
-    hbd_entry(paeth, 4, 16, avx2),     hbd_entry(paeth, 2, 2, avx2),
+    hbd_entry(paeth, 4, 16, avx2),
 };
 
 INSTANTIATE_TEST_CASE_P(intrapred, HighbdIntraPredTest,
